(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    350649,       8104]*)
(*NotebookOutlinePosition[    351883,       8143]*)
(*  CellTagsIndexPosition[    351705,       8135]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Needs[\"Rayica`Rayica`\"]", "Input"],

Cell["+++++++++++++++++++++++++", "Print"],

Cell[BoxData[
    \("Rayica 2.0 was loaded in 19 s and needs 7120 kilobytes of memory on \
top of 4762 kilobytes already used"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Optimization of Aspheric Components", "Section"],

Cell[TextData[{
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " can be used to optimize nearly every optical set-up. Such optimization \
can involve aspheric components. Rayica has built-in functions for modelling \
both aspheric and toriodal lenses and mirrors. In this example, we will \
examine how to use ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  " for optimizing the design of an aspheric lens. The ",
  StyleBox["AsphericLens", "Input"],
  " function is used to model aspheric lenses in ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  ". You can get an overview of the use of ",
  StyleBox["AsphericLens", "Input"],
  " with the ?",
  StyleBox["AsphericLens", "Input"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell["?AsphericLens", "Input",
  CellLabel->"In[46]:=",
  FormatType->InputForm],

Cell[BoxData[
    \("AsphericLens[{curvature1, conic1, \
polynomialcoefficients1,insideaperture1}, {curvature2, conic2, \
polynomialcoefficients2, insideaperture2}, aperture, thickness, label, \
options] designates a double-surfaced lens both having aspherical surfaces. \n\
\nThe centerline curvature, conicconstant, and aspheric \
polynomialcoefficients for an aspheric lens prescription are all required. An \
optional specification for an insideaperture to each surface may also be \
given. AsphericLens uses the EvenFunction->True option to indicate the use of \
even power polynomial terms as coefficients, starting with the second order \
term. Otherwise, both even and odd power terms will be used. AsphericLens is \
created with its first surface centered about the origin and its second \
surface positioned down the positive x axis. The aperture argument may denote \
a circle, rectangle, or polygon depending on the number and type of elements \
listed by it. The user-named label parameter is optional and can be omitted. \
When it is present, its text content is used to identify the object in both \
the rendered graphics and the output cell expression. When it is omitted, \
Rayica uses the default setting of the Labels option with the rendered \
graphics. (Inspired by William Cottingame, UCLA.) \n\nSee also: \
AsphericLensSurface, AsphericMirror, ToroidalLensSurface, ToroidalLens, and \
ToroidalMirror."\)], "Print",
  CellTags->"Info3334666517-6198462"]
}, Open  ]],

Cell[TextData[{
  "In order to get started, we can use the ",
  StyleBox["DataToRayica[AsphericLens]", "Input"],
  " in order to pull a typical aspheric lens system from ",
  StyleBox["Rayica",
    FontSlant->"Italic"],
  "'s built-in database of catalog elements."
}], "Text"],

Cell[CellGroupData[{

Cell["DataToRayica[AsphericLens]", "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \("Loading database ..."\)], "Print",
  CellLabel->"From In[52]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            
            TagBox[\(AsphericLens[{0.9`, \(-0.696917`\), 0, 
                  0, \(-0.0869628`\), \(-0.01333039999999999`\), \
\(-0.1533519999999999`\), 1.3`}, {\(-0.9`\), \(-6.995294999999999`\), 0, 
                  0, \(-0.1718929999999999`\), \(-0.0409008`\), 0.0885435`, 
                  1.129999999999999`}, 2.399999999999999`, 
                1.03`, {ComponentMedium \[Rule] CO550}]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            
            TagBox[\(Move[Window[1.129999999999999`, 0.3`], 
                1.5924999999999994`]\),
              HoldForm],
            FontColor->RGBColor[0, 0.392187, 0]],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["\<\
Below is a plot of the reported system. Note that there is a second \
window present present in addition to the aspheric lens. This element models \
the effects of an optical window used with many laser diodes. For our further \
work, however, this element will be omitted.\
\>", "Text"],

Cell[CellGroupData[{

Cell["ShowSystem[%];", "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.20759 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.10848 1.28275 2.22045e-16 1.28275 [
[ 0 0 0 0 ]
[ 1 1.20759 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.20759 L
0 1.20759 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.48693 .71301 m
.46292 .63355 L
s
.46292 .63355 m
.63525 .5775 L
s
.46292 .63355 m
.43091 .55804 L
s
.40745 .66428 m
.46292 .63355 L
s
.50181 .79277 m
.48693 .71301 L
s
.48693 .71301 m
.66017 .6592 L
s
.42111 .70963 m
.48693 .71301 L
s
.43091 .55804 m
.60345 .49942 L
s
.43091 .55804 m
.39223 .49008 L
s
.38903 .62142 m
.43091 .55804 L
s
.5066 .86908 m
.50181 .79277 L
s
.50181 .79277 m
.67704 .74081 L
s
.42924 .75495 m
.50181 .79277 L
s
.39223 .49008 m
.56609 .42861 L
s
.39223 .49008 m
.34852 .43334 L
s
.36682 .58346 m
.39223 .49008 L
s
.68487 .81853 m
.5066 .86908 L
s
.5006 .93793 m
.5066 .86908 L
s
.66017 .6592 m
.63525 .5775 L
s
.63525 .5775 m
.57979 .61077 L
s
.63525 .5775 m
.60345 .49942 L
s
.67704 .74081 m
.66017 .6592 L
s
.66017 .6592 m
.59224 .65171 L
s
.60345 .49942 m
.56372 .57188 L
s
.60345 .49942 m
.56609 .42861 L
s
.68487 .81853 m
.67704 .74081 L
s
.34852 .43334 m
.52474 .36885 L
s
.34852 .43334 m
.30178 .39149 L
s
.48339 .99508 m
.5006 .93793 L
s
.5006 .93793 m
.68281 .88831 L
s
.42699 .83526 m
.5006 .93793 L
s
.56609 .42861 m
.54491 .53727 L
s
.56609 .42861 m
.52474 .36885 L
s
.42111 .70963 m
.40745 .66428 L
s
.40745 .66428 m
.38903 .62142 L
s
.42924 .75495 m
.42111 .70963 L
s
.68281 .88831 m
.68487 .81853 L
s
.38903 .62142 m
.36682 .58346 L
s
.30178 .39149 m
.48133 .32395 L
s
.30178 .39149 m
.25447 .36815 L
s
.316 .53126 m
.30178 .39149 L
s
.656 .751 .92 r
.37484 .77552 m .60359 .73041 L .43129 .79767 L F
0 g
.42699 .83526 m
.43129 .79767 L
s
.42924 .75495 m
.42971 .7647 L
s
.43129 .79767 m
.5066 .86908 L
s
.52474 .36885 m
.48133 .32395 L
s
.544 .324 .532 r
.34201 .55271 m .54022 .54763 L .31442 .61049 L F
.34201 .55271 m .5244 .50907 L .54022 .54763 L F
0 g
.34201 .55271 m
.34852 .43334 L
s
.53683 .53936 m
.54491 .53727 L
s
.5244 .50907 m
.52474 .36885 L
s
.45505 1.03614 m
.48339 .99508 L
s
.48339 .99508 m
.67029 .94582 L
s
.41635 .86524 m
.48339 .99508 L
s
.67029 .94582 m
.68281 .88831 L
s
.656 .751 .92 r
.37484 .77552 m .59388 .69763 L .60359 .73041 L F
0 g
.60166 .76353 m
.68281 .88831 L
s
.60035 .69237 m
.67704 .74081 L
s
.60359 .73041 m
.68487 .81853 L
s
.656 .751 .92 r
.32627 .7499 m .59388 .69763 L .37484 .77552 L F
0 g
.37484 .77552 m
.43129 .79767 L
s
.41635 .86524 m
.42699 .83526 L
s
.544 .324 .532 r
.31442 .61049 m .55126 .58912 L .29557 .66636 L F
0 g
.42111 .70963 m
.59224 .65171 L
s
.40745 .66428 m
.57979 .61077 L
s
.544 .324 .532 r
.31442 .61049 m .54022 .54763 L .55126 .58912 L F
0 g
.54787 .57637 m
.56372 .57188 L
s
.31442 .61049 m
.34201 .55271 L
s
.316 .53126 m
.34201 .55271 L
s
.34201 .55271 m
.5244 .50907 L
s
.316 .53126 m
.50338 .48918 L
s
.316 .53126 m
.29036 .52084 L
s
.57979 .61077 m
.59224 .65171 L
s
.56372 .57188 m
.57979 .61077 L
s
.656 .751 .92 r
.32627 .7499 m .57852 .66531 L .59388 .69763 L F
0 g
.59224 .65171 m
.60035 .69237 L
s
.59271 .69516 m
.60035 .69237 L
s
.656 .751 .92 r
.28687 .72014 m .57852 .66531 L .32627 .7499 L F
0 g
.43129 .79767 m
.60359 .73041 L
s
.32627 .7499 m
.37484 .77552 L
s
.54491 .53727 m
.56372 .57188 L
s
.39977 .88536 m
.41635 .86524 L
s
.60035 .69237 m
.60359 .73041 L
s
.544 .324 .532 r
.29557 .66636 m .55568 .63408 L .28687 .72014 L F
.29557 .66636 m .55126 .58912 L .55568 .63408 L F
0 g
.29557 .66636 m
.31442 .61049 L
s
.25447 .36815 m
.43819 .29773 L
s
.25447 .36815 m
.20955 .36653 L
s
.29036 .52084 m
.25447 .36815 L
s
.48133 .32395 m
.50338 .48918 L
s
.48133 .32395 m
.43819 .29773 L
s
.5244 .50907 m
.54491 .53727 L
s
.60166 .76353 m
.60359 .73041 L
s
.59388 .69763 m
.60359 .73041 L
s
.64714 .98661 m
.67029 .94582 L
s
.67029 .94582 m
.59451 .78951 L
s
.29036 .52084 m
.48316 .47918 L
s
.29036 .52084 m
.2668 .52269 L
s
.41639 1.05687 m
.45505 1.03614 L
s
.45505 1.03614 m
.64714 .98661 L
s
.39977 .88536 m
.45505 1.03614 L
s
.544 .324 .532 r
.28687 .72014 m .55174 .68294 L .28863 .77206 L F
0 g
.42699 .83526 m
.60166 .76353 L
s
.656 .751 .92 r
.28687 .72014 m .55568 .63408 L .57852 .66531 L F
.544 .324 .532 r
.28687 .72014 m .55568 .63408 L .55174 .68294 L F
.656 .751 .92 r
.25683 .68589 m .55568 .63408 L .28687 .72014 L F
0 g
.29344 .67954 m
.29557 .66636 L
s
.5244 .50907 m
.54022 .54763 L
s
.50338 .48918 m
.5244 .50907 L
s
.37804 .89378 m
.39977 .88536 L
s
.59451 .78951 m
.60166 .76353 L
s
.77246 .59488 m
.75954 .55276 L
s
.75954 .55276 m
.84241 .52602 L
s
.75954 .55276 m
.7436 .51251 L
s
.78165 .63649 m
.77246 .59488 L
s
.77246 .59488 m
.85556 .56868 L
s
.57852 .66531 m
.59388 .69763 L
s
.7436 .51251 m
.82655 .48514 L
s
.7436 .51251 m
.72553 .47644 L
s
.2668 .52269 m
.24706 .53735 L
s
.2668 .52269 m
.46511 .48018 L
s
.20955 .36653 m
.2668 .52269 L
s
.48316 .47918 m
.50338 .48918 L
s
.544 .324 .532 r
.28863 .77206 m .54062 .73521 L .30141 .82231 L F
0 g
.41635 .86524 m
.59451 .78951 L
s
.544 .324 .532 r
.28863 .77206 m .55174 .68294 L .54062 .73521 L F
0 g
.28687 .72014 m
.28863 .77206 L
s
.78165 .63649 m
.86526 .61072 L
s
.54022 .54763 m
.55126 .58912 L
s
.656 .751 .92 r
.25683 .68589 m .52361 .60457 L .55568 .63408 L F
.23657 .64669 m .52361 .60457 L .25683 .68589 L F
0 g
.25683 .68589 m
.28687 .72014 L
s
.43819 .29773 m
.48316 .47918 L
s
.43819 .29773 m
.39807 .29365 L
s
.59451 .78951 m
.58237 .80641 L
s
.20955 .36653 m
.17043 .38893 L
s
.39807 .29365 m
.20955 .36653 L
s
.35243 .88925 m
.37804 .89378 L
s
.37804 .89378 m
.41639 1.05687 L
s
.84241 .52602 m
.85556 .56868 L
s
.82655 .48514 m
.84241 .52602 L
s
.656 .751 .92 r
.76288 .64563 m .8709 .64974 L .78651 .67521 L F
0 g
.78651 .67521 m
.78666 .70868 L
s
.78165 .63649 m
.78289 .64639 L
s
.85556 .56868 m
.86526 .61072 L
s
.80885 .44838 m
.82655 .48514 L
s
.61383 1.00632 m
.64714 .98661 L
s
.64714 .98661 m
.58237 .80641 L
s
.55568 .63408 m
.57852 .66531 L
s
.36916 1.0537 m
.41639 1.05687 L
s
.41639 1.05687 m
.61383 1.00632 L
s
.46511 .48018 m
.48316 .47918 L
s
.544 .324 .532 r
.70634 .44673 m .79372 .46262 L .70861 .49116 L F
.70634 .44673 m .7903 .41797 L .79372 .46262 L F
0 g
.79304 .45371 m
.80885 .44838 L
s
.70634 .44673 m
.7903 .41797 L
s
.68714 .42539 m
.70634 .44673 L
s
.55126 .58912 m
.55568 .63408 L
s
.24706 .53735 m
.45059 .49263 L
s
.24706 .53735 m
.23279 .56441 L
s
.24706 .53735 m
.17043 .38893 L
s
.544 .324 .532 r
.30141 .82231 m .52371 .79032 L .32462 .87146 L F
.30141 .82231 m .54062 .73521 L .52371 .79032 L F
0 g
.39977 .88536 m
.58237 .80641 L
s
.28863 .77206 m
.30141 .82231 L
s
.37804 .89378 m
.56583 .81268 L
s
.30141 .82231 m
.32462 .87146 L
s
.7903 .41797 m
.80885 .44838 L
s
.58237 .80641 m
.56583 .81268 L
s
.78192 .73468 m
.78666 .70868 L
s
.78666 .70868 m
.87205 .68337 L
s
.32462 .87146 m
.35243 .88925 L
s
.35243 .88925 m
.54584 .80737 L
s
.35243 .88925 m
.36916 1.0537 L
s
.656 .751 .92 r
.76288 .64563 m .84828 .61935 L .8709 .64974 L F
0 g
.8709 .64974 m
.87205 .68337 L
s
.86526 .61072 m
.8709 .64974 L
s
.78651 .67521 m
.8709 .64974 L
s
.656 .751 .92 r
.23657 .64669 m .48349 .5765 L .52361 .60457 L F
.22533 .60241 m .48349 .5765 L .23657 .64669 L F
0 g
.23657 .64669 m
.25683 .68589 L
s
.656 .751 .92 r
.7385 .61511 m .84828 .61935 L .76288 .64563 L F
0 g
.76288 .64563 m
.78651 .67521 L
s
.544 .324 .532 r
.70861 .49116 m .79723 .50848 L .71094 .53677 L F
.70861 .49116 m .79372 .46262 L .79723 .50848 L F
0 g
.70634 .44673 m
.70861 .49116 L
s
.68714 .42539 m
.77199 .39593 L
s
.68714 .42539 m
.66915 .41409 L
s
.7903 .41797 m
.79372 .46262 L
s
.77199 .39593 m
.7903 .41797 L
s
.55174 .68294 m
.55568 .63408 L
s
.52361 .60457 m
.55568 .63408 L
s
.46511 .48018 m
.39807 .29365 L
s
.45059 .49263 m
.46511 .48018 L
s
.87205 .68337 m
.86848 .70936 L
s
.77239 .75124 m
.78192 .73468 L
s
.78192 .73468 m
.86848 .70936 L
s
.56583 .81268 m
.54584 .80737 L
s
.61383 1.00632 m
.56583 .81268 L
s
.39807 .29365 m
.36413 .31429 L
s
.17043 .38893 m
.36413 .31429 L
s
.17043 .38893 m
.14073 .43603 L
s
.32462 .87146 m
.52371 .79032 L
s
.31627 1.0245 m
.32462 .87146 L
s
.29667 .84116 m
.32462 .87146 L
s
.656 .751 .92 r
.7385 .61511 m .82494 .58798 L .84828 .61935 L F
0 g
.84828 .61935 m
.8709 .64974 L
s
.656 .751 .92 r
.71334 .5836 m .82494 .58798 L .7385 .61511 L F
0 g
.7385 .61511 m
.76288 .64563 L
s
.544 .324 .532 r
.71094 .53677 m .80083 .55559 L .71334 .5836 L F
.71094 .53677 m .79723 .50848 L .80083 .55559 L F
0 g
.70861 .49116 m
.71094 .53677 L
s
.54062 .73521 m
.55174 .68294 L
s
.79372 .46262 m
.79723 .50848 L
s
.75508 .38401 m
.77199 .39593 L
s
.66915 .41409 m
.75508 .38401 L
s
.66915 .41409 m
.6536 .41404 L
s
.36413 .31429 m
.45059 .49263 L
s
.44081 .51616 m
.45059 .49263 L
s
.656 .751 .92 r
.22533 .60241 m .43671 .54949 L .48349 .5765 L F
0 g
.12385 .50619 m
.22533 .60241 L
s
.22533 .60241 m
.22557 .64879 L
s
.22533 .60241 m
.43671 .54949 L
s
.48349 .5765 m
.52361 .60457 L
s
.14073 .43603 m
.23279 .56441 L
s
.23279 .56441 m
.44081 .51616 L
s
.22533 .60241 m
.23279 .56441 L
s
.22533 .60241 m
.23657 .64669 L
s
.31627 1.0245 m
.36916 1.0537 L
s
.36916 1.0537 m
.57172 1.00131 L
s
.57172 1.00131 m
.61383 1.00632 L
s
.86848 .70936 m
.86021 .72574 L
s
.27082 .8003 m
.29667 .84116 L
s
.29667 .84116 m
.50104 .76236 L
s
.29667 .84116 m
.26177 .96942 L
s
.75848 .75679 m
.77239 .75124 L
s
.77239 .75124 m
.86021 .72574 L
s
.52371 .79032 m
.54584 .80737 L
s
.57172 1.00131 m
.54584 .80737 L
s
.656 .751 .92 r
.71334 .5836 m .80083 .55559 L .82494 .58798 L F
0 g
.82494 .58798 m
.84828 .61935 L
s
.52371 .79032 m
.54062 .73521 L
s
.544 .324 .532 r
.71334 .5836 m .80453 .604 L .71579 .63171 L F
.71334 .5836 m .80083 .55559 L .80453 .604 L F
.656 .751 .92 r
.68734 .55106 m .80083 .55559 L .71334 .5836 L F
0 g
.71094 .53677 m
.71172 .55204 L
s
.22557 .64879 m
.43883 .59037 L
s
.22557 .64879 m
.23371 .70002 L
s
.12231 .59496 m
.22557 .64879 L
s
.24922 .75195 m
.27082 .8003 L
s
.27082 .8003 m
.47959 .72532 L
s
.27082 .8003 m
.2105 .89158 L
s
.74076 .38346 m
.75508 .38401 L
s
.43671 .54949 m
.48349 .5765 L
s
.44081 .51616 m
.33967 .36063 L
s
.43671 .54949 m
.44081 .51616 L
s
.6536 .41404 m
.6417 .4258 L
s
.74076 .38346 m
.6536 .41404 L
s
.23371 .70002 m
.44716 .63572 L
s
.23371 .70002 m
.24922 .75195 L
s
.23371 .70002 m
.13716 .69506 L
s
.24922 .75195 m
.46112 .68196 L
s
.24922 .75195 m
.16751 .79722 L
s
.86021 .72574 m
.84758 .73095 L
s
.52327 .96943 m
.52371 .79032 L
s
.50104 .76236 m
.52371 .79032 L
s
.74095 .75041 m
.75848 .75679 L
s
.75848 .75679 m
.84758 .73095 L
s
.14073 .43603 m
.12385 .50619 L
s
.33967 .36063 m
.14073 .43603 L
s
.544 .324 .532 r
.71579 .63171 m .80834 .65377 L .71832 .68115 L F
.71579 .63171 m .80453 .604 L .80834 .65377 L F
0 g
.71334 .5836 m
.71579 .63171 L
s
.656 .751 .92 r
.68734 .55106 m .77592 .52212 L .80083 .55559 L F
0 g
.80083 .55559 m
.80453 .604 L
s
.79723 .50848 m
.80083 .55559 L
s
.80083 .55559 m
.82494 .58798 L
s
.36413 .31429 m
.33967 .36063 L
s
.656 .751 .92 r
.66049 .51744 m .77592 .52212 L .68734 .55106 L F
0 g
.68734 .55106 m
.71334 .5836 L
s
.32766 .43127 m
.43671 .54949 L
s
.43671 .54949 m
.43883 .59037 L
s
.73013 .39488 m
.74076 .38346 L
s
.50104 .76236 m
.47959 .72532 L
s
.47208 .91092 m
.50104 .76236 L
s
.52327 .96943 m
.31627 1.0245 L
s
.26177 .96942 m
.31627 1.0245 L
s
.6417 .4258 m
.73013 .39488 L
s
.6417 .4258 m
.63448 .4491 L
s
.52327 .96943 m
.57172 1.00131 L
s
.84758 .73095 m
.83126 .72404 L
s
.33025 .52179 m
.43883 .59037 L
s
.44716 .63572 m
.43883 .59037 L
s
.544 .324 .532 r
.71832 .68115 m .81226 .70496 L .72092 .73198 L F
0 g
.74095 .75041 m
.83126 .72404 L
s
.72092 .73198 m
.74095 .75041 L
s
.544 .324 .532 r
.71832 .68115 m .80834 .65377 L .81226 .70496 L F
0 g
.71579 .63171 m
.71832 .68115 L
s
.71832 .68115 m
.72092 .73198 L
s
.80453 .604 m
.80834 .65377 L
s
.47959 .72532 m
.46112 .68196 L
s
.42267 .82913 m
.47959 .72532 L
s
.656 .751 .92 r
.66049 .51744 m .75017 .48752 L .77592 .52212 L F
0 g
.77592 .52212 m
.80083 .55559 L
s
.34806 .6248 m
.44716 .63572 L
s
.46112 .68196 m
.44716 .63572 L
s
.37988 .73069 m
.46112 .68196 L
s
.656 .751 .92 r
.63272 .48268 m .75017 .48752 L .66049 .51744 L F
0 g
.66049 .51744 m
.68734 .55106 L
s
.72417 .41804 m
.73013 .39488 L
s
.72417 .41804 m
.63448 .4491 L
s
.12385 .50619 m
.32766 .43127 L
s
.12385 .50619 m
.12231 .59496 L
s
.72092 .73198 m
.81226 .70496 L
s
.69981 .7024 m
.72092 .73198 L
s
.81226 .70496 m
.83126 .72404 L
s
.80834 .65377 m
.81226 .70496 L
s
.2105 .89158 m
.26177 .96942 L
s
.26177 .96942 m
.47208 .91092 L
s
.33967 .36063 m
.32766 .43127 L
s
.656 .751 .92 r
.63272 .48268 m .72353 .45172 L .75017 .48752 L F
0 g
.72353 .45172 m
.75017 .48752 L
s
.63272 .48268 m
.63448 .4491 L
s
.75017 .48752 m
.77592 .52212 L
s
.63272 .48268 m
.66049 .51744 L
s
.63272 .48268 m
.72353 .45172 L
s
.63272 .48268 m
.63673 .5243 L
s
.72353 .45172 m
.72417 .41804 L
s
.67927 .66363 m
.69981 .7024 L
s
.69981 .7024 m
.79193 .67462 L
s
.47208 .91092 m
.52327 .96943 L
s
.79193 .67462 m
.81226 .70496 L
s
.12231 .59496 m
.33025 .52179 L
s
.12231 .59496 m
.13716 .69506 L
s
.63673 .5243 m
.72847 .49367 L
s
.63673 .5243 m
.64638 .57083 L
s
.66095 .61857 m
.67927 .66363 L
s
.67927 .66363 m
.77183 .63503 L
s
.16751 .79722 m
.2105 .89158 L
s
.2105 .89158 m
.42267 .82913 L
s
.64638 .57083 m
.73874 .54075 L
s
.64638 .57083 m
.66095 .61857 L
s
.72353 .45172 m
.72847 .49367 L
s
.66095 .61857 m
.7536 .58918 L
s
.79193 .67462 m
.77183 .63503 L
s
.13716 .69506 m
.34806 .6248 L
s
.13716 .69506 m
.16751 .79722 L
s
.16751 .79722 m
.37988 .73069 L
s
.73874 .54075 m
.72847 .49367 L
s
.32766 .43127 m
.33025 .52179 L
s
.77183 .63503 m
.7536 .58918 L
s
.7536 .58918 m
.73874 .54075 L
s
.42267 .82913 m
.47208 .91092 L
s
.33025 .52179 m
.34806 .6248 L
s
.37988 .73069 m
.42267 .82913 L
s
.34806 .6248 m
.37988 .73069 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{286.25, 345.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N0001FB000`400?l00000o`00003ooooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00L?ooool8o`000:Kooooo001]
ooooo`?o000000?oooooo`000?ooool01Oooool6o`000:3ooooo001[ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`?o000000?oooooo`000?ooool00_l0002Nooooo`00J?ooool5o`0000Go
oooo00?o0000ooooooooool00ol00004ooooo`04o`000?ooooooooooooooo`;o0000W?ooool006Go
oooo0ol000000ooooooo0000o`000007ooooo`?o00002?ooool00ol0003oooooooooo`02ooooo`;o
0000V_ooool006?ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo1?l00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Uoooool0063ooooo0ol00003ooooo`;o00001_oo
ool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`;o0000Uooo
ool005kooooo0_l00003ooooo`?o000000?oooooo`000?ooool00_ooool3o`0000Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o0000UOooool005_ooooo0ol00002oooo
o`?o00000oooool00ol0003oooooo`000002o`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`;o0000U?ooool005Wooooo0_l00003ooooo`;o00001_ooool3o`0000_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`?o000000?oooooo`000?oo
ool0Toooool005Kooooo0ol00002ooooo`?o00001Oooool3o`0000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
Toooool005?ooooo0ol00003ooooo`;o00001_ooool2o`0000;ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_l00006ooooo`03o`00
0?oooooo000009;ooooo001Aooooo`;o00000oooool3o`0000Gooooo0ol00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`;o00002Ooo
ool01?l0003oooooooooool0002Aooooo`00C_ooool3o`0000;ooooo0ol00005ooooo`?o00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00ooo
ool3o`000003ooooool0003ooooo00Wooooo00Co0000oooooooooooo0000T?ooool004cooooo0_l0
0003ooooo`;o00001_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooo000000;o00001?ooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool00000Soooool004Wooooo0ol00002ooooo`?o00001Oooool3o`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`;o00001oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S?ooool004Oooooo0_l00002
ooooo`?o00001_ooool2o`0000cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`?o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Roooool004Cooooo0ol00002ooooo`;o00001_ooool3o`00
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2:ooooo`00@Oooool3o`0000;ooooo0ol00005ooooo`?o00004?ooool00ol0003o
ooooooooo`09ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`00?oooool2o`0000?ooooo
0_l00006ooooo`;o00004Oooool2o`0000_ooooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Sooooo
000looooo`?o00000_ooool3o`0000Gooooo0ol0000@ooooo`?o000000?oooooo`000?ooool01ooo
ool3o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`27ooooo`00>_ooool@
o`0000oooooo0ol00004ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2
o`0008Sooooo000hooooo`;o000000Coooooo`000?l0003o00002_ooool01?l0003oooooo`000?l0
000;ooooo`;o00001oooool01?l0003oooooo`000?ooool3o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool3o`000003ooooool0003ooooo08Oooooo000fooooo`;o000000?oooooo`000?l000000_l0
000;ooooo`04o`000?ooooooooooooooo`;o00001_ooool3o`0000Sooooo00?o0000ooooool00000
0_l0000;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?o00001?ooool2o`0008Oooooo000eooooo`04o`000?oo
oooo0000o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o0000
00Coooooo`000?l0003o00002oooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool3o`0000Oo
oooo00?o0000ooooool00000Q_ooool003?ooooo1?l00005ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00oooool3o`0000[ooooo1?l00004ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0ol00009ooooo`03o`000?oooooo000003[ooooo1ol00015ooooo`00<Oooool3o`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03o`0000?ooooo0_l00006ooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo0000=_ooool3o`000004ooooool0003o0000o`0000?o
oooo00?o0000ooooooooool0@_ooool0033ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`?o00002?ooool2o`000004ooooool0003o0000o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooo`000002o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000003;ooooo0ol000001?oooooo0000o`000?l00007ooooo`03o`000?oooooo
oooo047ooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool3o`00
00cooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`?o000000Koooooo`00
0?l0003o0000ooooool00009ooooo`03o`000?oooooooooo043ooooo000_ooooo`03o`000?oooooo
000000cooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Yooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000[ooooo0_l00011ooooo`00;_oo
ool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00?o00001_ooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0ol00004ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`05oooo
o`?o000000?oooooo`000?ooool0@?ooool002kooooo00Go0000ooooooooooooooooo`00000<oooo
o`;o00002Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool4
o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08_ooool3o`000003ooooool0003o000000Co00001?ooool0
0ol0003oooooooooo`03ooooo`?o00001Oooool00ol0003oooooooooo`0nooooo`00;Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1?l0000:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool3o`000003ooooool0003o000000Co00001oooool00ol0003oooooooooo`03
o`0000Wooooo00?o0000ooooooooool0?Oooool002gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
00Sooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool3o`00
0003ooooool0003o000000Co00002_ooool3o`0000gooooo00?o0000ooooooooool0??ooool002co
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l0000;oooo
o`03o`000?oooooooooo00Cooooo0ol000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06Oooool8o`0000[ooooo0ol0000Aooooo`03o`000?oooooooooo
03_ooooo000[ooooo`03o`000?oooooooooo00Kooooo0ol00009ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ol000000ooooooo
0000o`000007ooooo`?o000000?oooooo`000?l000004Oooool2o`0003cooooo000[ooooo`03o`00
0?oooooooooo00?ooooo1?l0000<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`;o00002oooool4o`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo1?l00006ooooo`;o0000
0_ooool3o`000006ooooool0003o0000o`000?oooooo00003_ooool3o`000003oh]BR?l0003ooooo
03_ooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002Oooool3o`0000Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo0_l0000;ooooo`;o000000Coooooo`00
0?l0003o00001?ooool00ol0003oooooooooo`09ooooo`?o00001?n;DXP2o`0003_ooooo000Zoooo
o`03o`000?oooooo000000;o00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool3o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo0_l0000Eooooo`03o`000?oooooooooo00[ooooo0ol00007
ooooo`03o`000?oooooooooo00Kooooo0ol00007oh]BR0;o0000>oooool002Wooooo0ol0000:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooo000000;o00001_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool3o`00
0003ooooool0003ooooo01?ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
00Oooooo00?o0000ooooooooool00oooool3o`0000[oRe:800?o0000ooooool00000>_ooool002So
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Go
oooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ol0000=oh]BR004
o`000?ooooooooooo`0003Wooooo000Xooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo0ol00004ooooo`;o
00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000002o`0000Oooooo0_l0000Booooo`03o`000?oooooooooo00?o
oooo0ol00009ooooo`03o`000?oooooooooo00Cooooo0ol0000@oh]BR004o`000?ooooooooooo`00
03Wooooo000Xooooo`;o00003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool3o`000003ooooool0003ooooo00Cooooo00?o0000ooooool0
00000oooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`?o
00002Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00?o00003Oooool00ol0
003oooooooooo`04o`0001?oRe:800Co0000oooooooooooo0000>?ooool002Oooooo00Co0000oooo
oooooooo00003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003ooooo00Wooooo00Co0000oooooooooooo00004Oooool3o`00017o
oooo0_l00003oh]BR003o`000?n;DXSoRe:8017oRe:800Co0000oooooooooooo0000>?ooool002Oo
oooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Kooooo1?l00007ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`Co00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0Booooo`03o`000?n;DXSoRe:800;oRe:800?o0000oh]BR?n;DXP04On;DXP00ol0003ooooo
o`000002o`0003Oooooo000Wooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`04o`000?n;DXSoRe:8oh]BR0;o
00004on;DXP2o`0000;ooooo00?o0000ooooooooool0=Oooool002Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo0ol00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`00
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`Co000000?oYl3[o`00
0?n;DXP04_n;DXP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo000Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`?o
00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0@ooooo`?o00001?nW`>/2o`0001;oRe:800?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0dooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool3o`0000Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`?o00001onW`>/00ol0003oYl3[o`00000Aoh]BR003o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<oooool002Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool3o`0000[oYl3[
00?o0000ojO0jol000004On;DXP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo
000Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool4o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool3o`0000goYl3[
00Co0000ojO0jonW`>_o00004?n;DXP00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03;o
oooo000Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool3o`0000Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`03ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`?o
00004?nW`>/01Ol0003oYl3[ojO0jonW`>_o000000ooRe:800?o0000ooooooooool01?ooool00ol0
003oooooooooo`0booooo`009Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooooooool2
o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool3o`0001CoYl3[00Go
0000ojO0jonW`>_oYl3[o`00000>oh]BR003o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<Oooool002Gooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool3o`0000Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00002Oooool3o`0000Gooooo00Co0000oooooooooooooooo2_l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo1?l0000GojO0j`05o`000?nW`>_oYl3[ojO0jol000003_n;DXP00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo037ooooo000Uooooo`03o`000?oooooooooo00Wooooo1?l00009
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Gooooo0ol000000ooooooo0000ooooo`04ooooo`[o00001Oooool4o`0000Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo
00?o0000ojO0jonW`>/06?nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?n;DXSoRe:800_oRe:8
00?o0000ooooooooool01Oooool2o`0003;ooooo000Tooooo`03o`000?oooooooooo00Sooooo1?l0
000;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooo`000?ooool00ol00004ooooo`Ko000000?oooooo`000?l000000_l0000;ooooo`?o
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oYl3[ojO0j`0HojO0j`03o`000?nW`>_oYl3[00?oYl3[00?o0000oh]BR?n;
DXP02on;DXP01?l0003oooooooooooooool3o`000003ooooool0003ooooo037ooooo000Tooooo`03
o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00001?ooool=
o`0000Oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l0000IojO0j`03o`000?nW`>_o
Yl3[00?oYl3[00?o0000oh]BR?n;DXP02on;DXP4o`0000Gooooo00?o0000ooooooooool0;oooool0
02Cooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooo`00000>
o`0000;ooooo00Co0000oooooooooooooooo1?l00009ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
5onW`>/2o`0000KoYl3[00?o0000oh]BR?n;DXP02_n;DXP00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02oooooo000Tooooo`03o`000?oooooooooo00?o00002_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`[o0000
00?oooooo`000?l000000ol00005ooooo`Go00003_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00_ooooo0_l00007ooooo`04o`000?ooooooooooo`0001?oYl3[0ol000000onW
`>_o0000ojO0j`06ojO0j`03o`000?n;DXSoRe:800WoRe:800?o0000ooooooooool01_ooool00ol0
003oooooooooo`0_ooooo`008oooool4o`0000kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool4o`000003ooooool0003o0000
00So00001Oooool6o`0001?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`08oooo
o`?o000000?oooooo`000?ooool01_ooool01Ol0003ooooooooooooooooo000000ooYl3[0ol00004
ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000oh]BR?n;DXP02?n;DXP00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo02kooooo000Sooooo`;o00004Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ol000000ooooooo0000o`000002o`00
0003ooooool0003o000000Co00001Oooool5o`0000;ooooo00?o0000ooooooooool04oooool2o`00
00Oooooo00?o0000ooooooooool01Oooool3o`0000?ooooo00?o0000ooooool000001_ooool01Ol0
003ooooooooooooooooo000000coYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00KoYl3[00?o0000
oh]BR?n;DXP01on;DXP00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo000Soooo
o`03o`000?oooooo0000013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05o`00
0003ooooool0003o000000So00000_ooool00ol0003oooooooooo`06o`0000Cooooo00Co0000oooo
oooooooo00005?ooool3o`0000Oooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000000SoYl3[0ol0000;ojO0j`03o`000?nW
`>_oYl3[00KoYl3[00?o0000oh]BR?n;DXP01on;DXP00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02gooooo000Sooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool4o`000003ooooool0003o000000So00001oooool5o`0000Wooooo00?o0000ooooool000004?oo
ool4o`0000;oRe:800?o0000ooooooooool01?ooool00ol0003oooooooooo`03o`0000Sooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?nW`>_oYl3[00;oYl3[
0ol0000>ojO0j`03o`000?nW`>_oYl3[00OoYl3[00?o0000oh]BR?n;DXP01_n;DXP00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02gooooo000Sooooo`05o`000?ooooooooooooooool00000
4?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000004o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0ol00006ooooo`Go00001?ooool2o`0000Oooooo0ol0000=ooooo`Co00001on;DXP00ol0003ooooo
ooooo`03ooooo`?o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool4o`00017oYl3[00?o0000ojO0jonW`>/02?nW`>/00ol0003oRe:8
oh]BR005oh]BR003o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool002?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000ol00003ooooo`03o`000?oooooooooo00Co00001?ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`Co00000_ooool00ol0003oooooooooo`07ooooo`Co0000
2on;DXP2o`000003ooooool0003o000000;o00003?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo1?l0000DojO0j`03o`000?nW`>_oYl3[00So
Yl3[00?o0000oh]BR?n;DXP01?n;DXP00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02co
oooo000Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo2_l000000ooooooo0000o`000003o`0000;ooooo
0ol000000ooooooo0000o`000002o`0000Sooooo00?o0000ooooooooool00_ooool5o`0000Kooooo
00?o0000ooooooooool00oooool4o`00013oRe:80_l00003ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Co00000oooool00ol0003oYl3[
ojO0j`0BojO0j`03o`000?nW`>_oYl3[00WoYl3[00?o0000oh]BR?n;DXP00on;DXP00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02cooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool8o`000003ooooool0003o000000Ko00002_ooool00ol0003oooooo`00
0003o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000003o`0001CoRe:80_l0
0003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ojO0jonW`>/04OnW`>/00ol0003oYl3[ojO0
j`09ojO0j`03o`000?n;DXSoRe:800?oRe:800?o0000ooooooooool02Oooool2o`0002gooooo000S
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;o00000oooool4o`0000Kooooo1Ol00002ooooo`03o`000?oooooo
oooo00;o00001oooool4o`0000Oooooo0_l00004ooooo`Co00006On;DXP2o`000003ooooool0003o
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ojO0jonW`>/04?nW`>/00ol0003oYl3[ojO0j`0:ojO0j`03o`000?n;DXSo
Re:800;oRe:800?o0000ooooooooool01_ooool3o`000003ooooool0003ooooo02cooooo000Soooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooo000000Go00001oooool3o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1Ol0003oooooo`000?l0003ooooo00Co00000_ooool00ol0003oooooooooo`07ooooo`Go00000_n;
DXP00ol0003oRe:8oh]BR00Hoh]BR004o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ojO0jonW`>/0
3onW`>/00ol0003oYl3[ojO0j`0;ojO0j`03o`000?n;DXSoRe:800;oRe:800?o0000ooooooooool0
0_ooool3o`0000Gooooo00?o0000ooooooooool0:_ooool002?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo0_l00009ooooo`?o00002?oo
ool01Ol0003oooooooooool0003ooooo00Go00001_ooool00ol0003oooooooooo`04ooooo`Co0000
00?oRe:8o`000?n;DXP00_n;DXP00ol0003oRe:8oh]BR00Ioh]BR004o`000?oooooo0000o`0000[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ojO0jonW`>/03onW`>/00ol0003oYl3[ojO0j`0;ojO0j`06o`000?n;DXSoRe:8oh]B
R?l0003ooooo0ol00008ooooo`03o`000?oooooooooo02[ooooo000Sooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo0ol0000<ooooo`Go00001?ooool2o`0000?ooooo00Co0000oooooooooooooooo1?l00006
oh]BR004o`000?n;DXSoRe:8o`0001coRe:800?o0000ooooool000002Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oYl3[ojO0
j`0=ojO0j`;o00003_nW`>/00ol0003oRe:8oh]BR002o`0000_ooooo00?o0000ooooooooool0:_oo
ool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool3o`0000_ooooo1?l000001Ooooooo0000o`000?oo
oooo000000Kooooo0_l000000ooooooo0000o`000002o`0000_oRe:800?o0000oh]BR?l000007?n;
DXP01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?nW`>_oYl3[00WoYl3[0ol000000onW`>_o0000
ojO0j`0=ojO0j`04o`000?n;DXSoRe:8o`0000gooooo00?o0000ooooooooool0:Oooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooooooo0_l0000:ooooo`Co00001_ooool00ol0003oooooo`000005ooooo`Co
00004?n;DXP2o`0001goRe:800?o0000ooooool000001oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oYl3[ojO0j`05ojO0j`?o
00001?nW`>/00ol0003oYl3[ojO0j`0=ojO0j`03o`000?n;DXSo000000gooooo00?o0000oooooooo
ool0:Oooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000000_l00008ooooo`Co00002_ooool3o`000003oooo
ool0003o000000;o00001?n;DXP2o`0000goRe:81?l0000Loh]BR004o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Co0000ojO0jonW`>_oYl3[0ol00008ojO0j`03o`000?nW`>_oYl3[00goYl3[0_l0000=oooo
o`03o`000?oooooooooo02Wooooo000Rooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03o`0000Oooooo1?l0000>ooooo`04o`000?oooooo0000o`00
00[oRe:80_l00007oh]BR0Co00000_nW`>/01?l0003oYl3[o`000?l0000Joh]BR004o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo1?l0000;ojO0j`03o`000?nW`>_oYl3[00koYl3[00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Xooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo1?l00004ooooo`Go00004oooool2o`0000goRe:800?o0000oh]BR?n;DXP01?l00006
ojO0j`04o`000?nW`>_oYl3[ojO0j`;o00006On;DXP01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`Co0000
3OnW`>/00ol0003oYl3[ojO0j`0<ojO0j`;oRe:800?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Xooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo0ol0
00000ooooooo0000ooooo`05o`0001Sooooo00?o0000oh]BR?n;DXP02on;DXP4o`0000[oYl3[00?o
0000ojO0jonW`>/00onW`>/2o`0001OoRe:800Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0>ooooo`05o`000?ooooooooooooooool000001oooool3o`0000Cooooo00?o0000ojO0jonW
`>/02onW`>/00ol0003oYl3[ojO0j`08ojO0j`GoRe:80_l0000=ooooo`03o`000?oooooooooo02So
oooo000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
0_l0000Looooo`03o`000?n;DXSoRe:800OoRe:81?l00004ojO0j`03o`000?nW`>_oYl3[00OoYl3[
00?o0000ojO0jonW`>/01OnW`>/00ol0003oRe:8oh]BR00Doh]BR007o`000?ooooooooooooooool0
003oooooo`00000Aooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Sooooo00?o0000
ojO0jonW`>/02_nW`>/00ol0003oYl3[ojO0j`05ojO0j`SoRe:800?o0000ojO0jol000003Oooool0
0ol0003oooooooooo`0Wooooo`008_ooool00ol0003oooooooooo`0Aooooo`Co00002?ooool00ol0
003oooooooooo`0Jooooo`;o00001On;DXP4o`0000WoYl3[0_l00007ojO0j`03o`000?nW`>_oYl3[
00KoYl3[0_l0000Doh]BR007o`000?ooooooooooooooool0003oooooo`00000Booooo`04o`000?oo
ooooooooooooo`Co00003?ooool00ol0003oYl3[ojO0j`09ojO0j`03o`000?nW`>_oYl3[00;oYl3[
2on;DXP00ol0003oYl3[o`00000<ooooo`;o0000:Oooool002;ooooo00?o0000ooooooooool04?oo
ool3o`0000[ooooo00?o0000ooooooooool06_ooool2o`000003oh]BR?l0003o000000;o00003onW
`>/2o`0000KoYl3[00?o0000ojO0jonW`>/01onW`>/2o`0001?oRe:800?o0000ooooool000000_l0
000Cooooo`05o`000?ooooooooooooooool000003oooool00ol0003oYl3[ojO0j`09ojO0j`03o`00
0?nW`>_oRe:800goRe:800Co0000ojO0jonW`>_o00002?ooool3o`000003ooooool0003ooooo02So
oooo000Rooooo`03o`000?oooooooooo00gooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06Oooool4o`0001GoYl3[00?o0000ojO0jonW`>/00onW`>/00ol0003oYl3[
ojO0j`09ojO0j`;o00004On;DXP2o`0000;ooooo00?o0000ooooooooool04Oooool01Ol0003ooooo
oooooooooooo0000013ooooo00?o0000ojO0jonW`>/01onW`>/2oh]BR003o`000?n;DXSoRe:800co
Re:800Go0000ojO0jonW`>_oYl3[o`000004ooooo`?o00001?ooool00ol0003oooooooooo`0Woooo
o`008_ooool00ol0003oooooooooo`0:ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo1?l00003ojO0j`03o`000?nW`>_oYl3[01CoYl3[0_l00003ojO0j`03
o`000?nW`>_oYl3[00_oYl3[00?o0000oh]BR?n;DXP03_n;DXP00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00oooooo0ol00002ooooo`03o`000?oooooooooo00oooooo00?o0000ojO0jonW
`>/00onW`>/5oh]BR003o`000?n;DXSoRe:800coRe:800?o0000ojO0jonW`>/00_nW`>/4o`0000Oo
oooo00?o0000ooooooooool09oooool002;ooooo00?o0000ooooooooool01oooool3o`0000_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co00001onW`>/00ol0003oYl3[
ojO0j`0FojO0j`;o000000?oYl3[o`000?nW`>/03OnW`>/2o`0000koRe:800?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`Co000000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?nW`>_oRe:800OoRe:800?o0000oh]BR?n;DXP03On;DXP01Ol0003oYl3[
ojO0jonW`>_o000000_ooooo00?o0000ooooooooool09_ooool002;ooooo00?o0000ooooooooool0
1?ooool3o`0000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000
2onW`>/00ol0003oYl3[ojO0j`0HojO0j`;o00004?nW`>/00ol0003oRe:8oh]BR00<oh]BR003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo00;ooooo
00Go0000ooooooooooooooooo`00000Aooooo`03o`000?n;DXSoRe:800SoRe:800?o0000oh]BR?n;
DXP03?n;DXP00ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09_ooool002;ooooo00Co0000oooooooooooooooo0ol0000Cooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool4o`0000ooYl3[00?o0000ojO0jonW`>/05onW`>/3o`00017o
Yl3[0_l0000<oh]BR003o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000;o
oooo0_l00005ooooo`04o`000?ooooooooooo`00017ooooo00?o0000oh]BR?n;DXP01_n;DXP3o`00
00koRe:800?o0000ojO0jonW`>/00onW`>/00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Kooooo000Rooooo`Co00005oooool01Ol0003ooooooooooooooooo000000Sooooo1?l0000CojO0
j`03o`000?nW`>_oYl3[01CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[017oYl3[00?o0000oh]B
R?n;DXP02On;DXP00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`?o00000oooool2
o`0000Oooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?n;DXSoRe:800?oRe:80ol0
0002oh]BR003o`000?n;DXSoRe:800coRe:800?o0000ojO0jonW`>/00onW`>/00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Kooooo000Rooooo`;o00006_ooool00ol0003oooooo`000005
ooooo`Co00006?nW`>/00ol0003oYl3[ojO0j`0?ojO0j`Co00001OnW`>/00ol0003oYl3[ojO0j`0B
ojO0j`;o00002On;DXP00ol0003oooooooooo`03ooooo`Co00001?ooool2o`0000Wooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?n;DXSoRe:800?o00001_n;DXP00ol0003oRe:8oh]B
R00;oh]BR003o`000?nW`>_oYl3[00CoYl3[00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Vooooo`008_ooool01?l0003oooooo`000?l0000Iooooo`;o000000?oooooo`000?l000000_l0
000LojO0j`03o`000?nW`>_oYl3[00_oYl3[1?l00009ojO0j`03o`000?nW`>_oYl3[01CoYl3[00?o
0000oh]BR?n;DXP01_n;DXP01?l0003oooooooooooooool3o`0000Gooooo0_l0000<ooooo`04o`00
0?ooooooooooo`00013ooooo0ol00009oh]BR003o`000?n;DXSoRe:800_oRe:800?o0000ojO0jonW
`>/01OnW`>/00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo000Rooooo`04o`00
0?ooooooooooooooo`;o00006?ooool2o`00023oYl3[00?o0000ojO0jonW`>/02?nW`>/3o`0000ko
Yl3[00?o0000ojO0jonW`>/05?nW`>/00ol0003oRe:8oh]BR005oh]BR0Co00000oooool01Ol0003o
oooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00000;ooooo`Go00003?n;DXP0
0ol0003oRe:8oh]BR00:oh]BR003o`000?nW`>_oYl3[00GoYl3[00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Uooooo`008_ooool00ol0003oooooooooo`03ooooo`;o00005_ooool00ol0
003oYl3[ojO0j`0OojO0j`03o`000?nW`>_oYl3[00CoYl3[1?l0000AojO0j`03o`000?nW`>_oYl3[
01GoYl3[00?o0000oh]BR?n;DXP01?n;DXP00ol0003oooooooooo`04ooooo`04o`000?oooooo0000
o`0000oooooo00Go0000ooooooooooooooooo`000008ooooo`?o00001?ooool00ol0003oRe:8oh]B
R00:oh]BR003o`000?n;DXSoRe:800[oRe:800?o0000ojO0jonW`>/01_nW`>/00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l0000D
ooooo`03o`000?nW`>_oYl3[01ooYl3[00Co0000ojO0jonW`>_oYl3[0ol0000EojO0j`03o`000?nW
`>_oYl3[01KoYl3[00?o0000oh]BR?n;DXP00on;DXP00ol0003oooooooooo`03ooooo`?o00004_oo
ool01?l0003oooooooooool00005ooooo`?o00002?ooool00ol0003oRe:8oh]BR00:oh]BR003o`00
0?n;DXSoRe:800WoRe:800?o0000ojO0jonW`>/01onW`>/00ol0003oooooooooo`03ooooo`;o0000
9oooool002?ooooo00?o0000ooooooooool01_ooool2o`0001;ooooo0_l0000PojO0j`Co00006?nW
`>/00ol0003oYl3[ojO0j`0GojO0j`03o`000?n;DXSoRe:800?oRe:800?o0000ooooool000000_l0
0002ooooo`03o`000?oooooooooo013ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000_o
oooo00?o0000oh]BR?n;DXP02_n;DXP00ol0003oRe:8oh]BR009oh]BR003o`000?nW`>_oYl3[00Oo
Yl3[00?o0000ooooooooool00ol000000ooooooo0000ooooo`0Vooooo`008oooool00ol0003ooooo
ooooo`08ooooo`;o00004?ooool2o`0001coYl3[1?l000000onW`>_o0000ojO0j`0IojO0j`03o`00
0?nW`>_oYl3[01SoYl3[00?o0000oh]BR?n;DXP00_n;DXP2o`0000Gooooo00?o0000ooooooooool0
4?ooool01?l0003oooooooooooooool2o`0000kooooo00?o0000oh]BR?n;DXP02_n;DXP00ol0003o
Re:8oh]BR009oh]BR003o`000?nW`>_oYl3[00SoYl3[0_l00004ooooo`03o`000?oooooooooo02Go
oooo000Sooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`;o00006OnW`>/3o`0000GoYl3[
00?o0000ojO0jonW`>/06?nW`>/00ol0003oYl3[ojO0j`0IojO0j`05o`000?n;DXSoRe:8oh]BR?l0
00001oooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000oh]B
R?n;DXP02on;DXP00ol0003oRe:8oh]BR008oh]BR003o`000?nW`>_oYl3[00WoYl3[00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`008oooool00ol0003oooooooooo`0<ooooo`;o
00003?ooool2o`0001GoYl3[1?l00007ojO0j`Oo00005OnW`>/00ol0003oYl3[ojO0j`0JojO0j`04
o`000?n;DXSoRe:8o`0000Oooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000oh]BR?n;DXP02on;DXP00ol0003oRe:8oh]BR008oh]BR003o`000?nW`>_o
Yl3[00WoYl3[00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`009?ooool00ol0
003oooooooooo`0=ooooo`;o00002_ooool00ol0003oooooo`00000AojO0j`?o00002?nW`>/3o`00
0003ojO0jol0003oYl3[00CoYl3[2Ol0000=ojO0j`03o`000?nW`>_oYl3[01[oYl3[00?o0000oh]B
R?l000001oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oRe:8oh]BR00<oh]BR003o`000?n;DXSoRe:800OoRe:800?o0000ojO0jonW`>/02_nW`>/0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo000Tooooo`03o`000?oooooooooo
00oooooo0_l00008ooooo`03o`000?oooooo000000goYl3[1?l00008ojO0j`?o00001?nW`>/00ol0
003oYl3[ojO0j`0<ojO0j`Wo00001?nW`>/00ol0003oYl3[ojO0j`0KojO0j`;o00001oooool00ol0
003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oRe:8oh]BR00<
oh]BR003o`000?n;DXSoRe:800SoRe:800?o0000ojO0jonW`>/02_nW`>/01Ol0003ooooooooooooo
oooo000002Kooooo000Tooooo`03o`000?oooooooooo017ooooo0_l00006ooooo`03o`000?oooooo
000000[oYl3[0ol00009ojO0j`?o00002?nW`>/00ol0003oYl3[ojO0j`0DojO0j`Go00007_nW`>/0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?n;DXSoRe:800_oRe:80ol00009oh]BR003o`000?nW`>_oYl3[00_oYl3[00Co
0000oooooooooooo00009_ooool002Cooooo00?o0000ooooooooool04oooool2o`0000Cooooo00?o
0000ooooool000001_nW`>/4o`0000WoYl3[0ol0000;ojO0j`03o`000?nW`>_oYl3[01?oYl3[0ol0
0002ojO0j`03o`000?nW`>_oYl3[01[oYl3[0_n;DXP00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?n;DXSoRe:800SoRe:8
0ol00002oh]BR003o`000?n;DXSoRe:800OoRe:800?o0000ojO0jonW`>/03?nW`>/00ol0003ooooo
o`00000Vooooo`009?ooool00ol0003oooooooooo`0Eooooo`;o00000_ooool01Ol0003ooooooooo
ool0003oYl3[00Co00002_nW`>/3o`0000koYl3[00?o0000ojO0jonW`>/04?nW`>/3o`0000GoYl3[
00?o0000ojO0jonW`>/05onW`>/5oh]BR0;o00001oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oRe:8oh]BR005oh]BR0?o0000
1_n;DXP00ol0003oRe:8oh]BR006oh]BR003o`000?nW`>_oYl3[00goYl3[00?o0000ooooool00000
9Oooool002Cooooo00?o0000ooooooooool05oooool3o`000004ooooool0003o0000o`0000_oYl3[
0ol0000BojO0j`03o`000?nW`>_oYl3[00coYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[01?oYl3[
2?n;DXP00ol0003oYl3[o`000006ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`04o`000?n;DXSoRe:8oh]BR0Co00002On;DXP00ol0003oRe:8oh]BR006oh]B
R003o`000?nW`>_oYl3[00koYl3[0_l0000Uooooo`009Oooool00ol0003oooooooooo`0Hooooo`;o
000000?oooooo`000?nW`>/02?nW`>/3o`0001GoYl3[00?o0000ojO0jonW`>/02OnW`>/3o`0000co
Yl3[00?o0000ojO0jonW`>/04?nW`>/;oh]BR004o`000?nW`>_oYl3[o`0000Kooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo000000cooooo1?l0000>oh]BR003o`000?n;DXSo
Re:800GoRe:800?o0000ojO0jonW`>/03_nW`>/2o`0002Gooooo000Uooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`000005ojO0j`?o00006?nW`>/00ol0003oYl3[ojO0j`05
ojO0j`Co00003onW`>/00ol0003oYl3[ojO0j`0=ojO0j`koRe:800Go0000ojO0jonW`>_oYl3[o`00
0004ooooo`Oo00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo1?l0
000Aoh]BR003o`000?n;DXSoRe:800GoRe:800?o0000ojO0jonW`>/02onW`>/3o`000003ooooool0
003ooooo02Cooooo000Uooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
0002ojO0j`?o00007?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001CoYl3[00?o0000ojO0jonW`>/0
2?nW`>/Boh]BR006o`000?nW`>_oYl3[ojO0jol0003ooooo0ol000000ooooooo0000ooooo`04oooo
o`[o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol00003ooooo`03o`000?n;DXSo
Re:8013oRe:800?o0000oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`08ojO0j`?o00001?ooool0
0ol0003oooooooooo`0Sooooo`009Oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
ooooo`?o00007onW`>/4o`0001OoYl3[00?o0000ojO0jonW`>/01OnW`>/Eoh]BR003o`000?nW`>_o
Yl3[00;oYl3[00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`Go00000oooool0
0ol0003oooooooooo`03o`0000Kooooo00?o0000oh]BR?n;DXP04?n;DXP00ol0003oRe:8oh]BR004
oh]BR003o`000?nW`>_oYl3[00GoYl3[0ol00007ooooo`03o`000?oooooooooo02?ooooo000Uoooo
o`03o`000?oooooooooo01Sooooo1?l000000ooooooo0000ojO0j`0MojO0j`?o00006_nW`>/00ol0
003oYl3[ojO0j`02ojO0jaOoRe:800?o0000ojO0jonW`>/01?nW`>/00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00_ooooo0ol00002ooooo`03o`000?oooooooooo00;ooooo0_l00009oooo
o`03o`000?n;DXSoRe:8013oRe:800?o0000oh]BR?n;DXP01?n;DXP00ol0003oYl3[ojO0j`02ojO0
j`?o00002_ooool00ol0003oooooooooo`0Sooooo`009Oooool00ol0003oooooooooo`0Fooooo`Co
00001?ooool00ol0003oYl3[ojO0j`0GojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`0IojO0j`03
o`000?n;DXSoRe:801SoRe:800?o0000ojO0jonW`>/01OnW`>/01Ol0003ooooooooooooooooo0000
00[ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oRe:8oh]BR00Aoh]BR003o`000?n;DXSoRe:800?oRe:800?o0000ojO0jol000000_l0000=oooo
o`03o`000?oooooooooo02?ooooo000Vooooo`03o`000?oooooooooo01;ooooo0ol00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ojO0jonW`>/05?nW`>/3o`0000OoYl3[00?o0000ojO0jonW
`>/05_nW`>/2oh]BR003o`000?n;DXSoRe:801SoRe:800?o0000ojO0jonW`>/01OnW`>/01Ol0003o
oooooooooooooooo000000Kooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oRe:8oh]BR00Aoh]BR003o`000?n;DXSoRe:800?oRe:80_l0000@oooo
o`03o`000?oooooooooo02?ooooo000Vooooo`03o`000?oooooooooo00oooooo0ol00006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ojO0jonW`>/04?nW`>/3o`0000[oYl3[00?o0000ojO0jonW
`>/04_nW`>/6oh]BR003o`000?n;DXSoRe:801SoRe:800?o0000ojO0jonW`>/01_nW`>/01Ol0003o
oooooooooooooooo000000;ooooo0ol0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oRe:8oh]BR00@oh]BR0?o00001?n;DXP00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02?ooooo000Vooooo`03o`000?oooooooooo00cooooo0ol00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ojO0jonW`>/03OnW`>/3o`0000goYl3[00?o0000ojO0jonW
`>/03onW`>/:oh]BR003o`000?n;DXSoRe:801OoRe:800?o0000ojO0jonW`>/01_nW`>/01?l0003o
ooooooooooooool3o`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?n;DXSoRe:800goRe:80ol00002oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`09ooooo`?o
00003?ooool00ol0003oooooooooo`04ooooo`03o`000?nW`>_oYl3[00WoYl3[0ol0000AojO0j`03
o`000?nW`>_oYl3[00_oYl3[3?n;DXP2o`0001WoRe:800?o0000ojO0jonW`>/01onW`>/4o`0001;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?n;DXSoRe:800[o
Re:80ol00006oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`06ooooo`?o00003oooool00ol0003ooooo
ooooo`04ooooo`03o`000?nW`>_oYl3[00GoYl3[1?l0000DojO0j`03o`000?nW`>_oYl3[00SoYl3[
3?n;DXP3o`000003oh]BR?l0003oRe:801SoRe:800?o0000ojO0jonW`>/01onW`>/01?l0003ooooo
ooooool0000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
Re:8oh]BR007oh]BR0?o00002_n;DXP01Ol0003oRe:8oh]BR?n;DXSo000000kooooo0ol0000Uoooo
o`009oooool00ol0003oooooooooo`02ooooo`?o00004_ooool00ol0003oooooooooo`05ooooo`04
o`000?nW`>_oYl3[ojO0j`?o00006?nW`>/00ol0003oYl3[ojO0j`04ojO0j`goRe:81Ol00003oh]B
R003o`000?n;DXSoRe:801KoRe:800?o0000ojO0jonW`>/01onW`>/01Ol0003ooooooooooooooooo
000001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?n;DXSo
Re:800?oRe:81?l0000=oh]BR005o`000?n;DXSoRe:8oh]BR?l000002oooool3o`0000;ooooo00?o
0000ooooooooool08oooool002Oooooo00?o0000ooooool000000_l0000Fooooo`03o`000?oooooo
oooo00Cooooo1?l0000LojO0j`03o`000?nW`>_oYl3[00goRe:80ol000000on;DXSo0000o`000005
oh]BR003o`000?n;DXSoRe:801KoRe:800?o0000ojO0jonW`>/02?nW`>/00ol0003oooooo`000002
o`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?n;DXSo
Re:800?o00004_n;DXP01?l0003oRe:8oh]BR?l00007ooooo`Co00001Oooool00ol0003ooooooooo
o`0Sooooo`009oooool8o`0001?ooooo00?o0000ooooooooool00_ooool4o`0001koYl3[00?o0000
oh]BR?n;DXP02_n;DXP3o`0000?oRe:800?o0000oh]BR?n;DXP01On;DXP00ol0003oRe:8oh]BR00E
oh]BR003o`000?nW`>_oYl3[00WoYl3[0_l000001?oooooo0000ooooool0000@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool3o`0001KoRe:800?o0000oh]BR?l000001?oo
ool3o`0000Wooooo00?o0000ooooooooool08oooool002Oooooo00?o0000ooooooooool01Oooool=
o`0000Kooooo00?o0000ooooool000000_l00004ooooo`03o`000?nW`>_oYl3[01SoYl3[0on;DXP0
0ol0003oRe:8oh]BR007oh]BR0?o00001?n;DXP2o`0000WoRe:800?o0000oh]BR?n;DXP05?n;DXP0
0ol0003oYl3[ojO0j`0:ojO0j`03o`000?oooooo000000;ooooo0_l0000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?l0000Hoh]BR004o`000?n;DXSo0000ooooo`?o00002ooo
ool00ol0003oooooooooo`0Tooooo`009oooool00ol0003oooooooooo`0Booooo`So00002?ooool0
0ol0003oYl3[ojO0j`0DojO0j`KoRe:800?o0000oh]BR?n;DXP01?n;DXP3o`0000GoRe:80_l0000;
oh]BR003o`000?n;DXSoRe:801CoRe:800?o0000ojO0jonW`>/02_nW`>/00ol0003oooooo`000004
ooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`;o00000oooool00ol0003oRe:8oh]BR00G
oh]BR0?o00003_ooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Sooooo00?o0000ojO0jonW`>/03onW`>/;oh]BR003o`000?n;DXSoRe:8
00?o00001on;DXP00ol0003oRe:8oh]BR00<oh]BR003o`000?n;DXSoRe:801?oRe:800?o0000ojO0
jonW`>/02onW`>/2o`0000Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000oh]BR?n;DXP05_n;DXP4o`0000kooooo00?o0000oooo
ooooool09?ooool002Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03
o`000?nW`>_oYl3[00_oYl3[3_n;DXP3o`0000SoRe:80_l0000?oh]BR003o`000?n;DXSoRe:801?o
Re:800?o0000ojO0jonW`>/02onW`>/2o`0000Oooooo0_l0000:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oRe:8oh]BR00Boh]BR0?o00001?ooool00ol0003o
ooooooooo`0:ooooo`;o00009_ooool002Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?nW`>_oYl3[00OoYl3[3_n;DXP4o`0000SoRe:80_l0000Aoh]BR003o`00
0?n;DXSoRe:801;oRe:800?o0000ojO0jonW`>/03?nW`>/00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000017o
Re:80ol00008ooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`0Uooooo`00
:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ojO0jonW`>/0
0onW`>/>oh]BR0?o00001?n;DXP00ol0003oRe:8oh]BR004oh]BR003o`000?n;DXSoRe:801;oRe:8
00?o0000oh]BR?n;DXP04On;DXP00ol0003oYl3[ojO0j`0=ojO0j`;o00002Oooool2o`0000Oooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000koRe:80ol000000ooooooo
0000ooooo`09ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo02Go
oooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oYl3[
oh]BR00=oh]BR0?o00001on;DXP00ol0003oRe:8oh]BR002oh]BR0;o00005On;DXP00ol0003oRe:8
oh]BR00Aoh]BR003o`000?nW`>_oYl3[00goYl3[0_l0000;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool0000:oh]BR0Co00001?ooool00ol0003o
ooooooooo`09ooooo`Co00001_ooool00ol0003oooooooooo`0Uooooo`00:Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000oh]BR?n;DXP02_n;DXP3o`0000[oRe:8
00?o0000oh]BR?n;DXP00_l0000Goh]BR003o`000?n;DXSoRe:8017oRe:800?o0000ojO0jonW`>/0
3OnW`>/2o`0000cooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000
1on;DXP3o`0000Sooooo00?o0000ooooooooool01oooool5o`0000Oooooo00?o0000ooooooooool0
9Oooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?n;
DXSoRe:800OoRe:80ol0000>oh]BR0;o00006On;DXP2o`0001;oRe:800?o0000ojO0jonW`>/03_nW
`>/00ol0003oooooooooo`0<ooooo`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000CoRe:80ol0000:ooooo`03o`000?oooooooooo00Gooooo1?l00004ooooo`;o00000_oo
ool3o`0002Sooooo000Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool0
0ol0003oRe:8oh]BR004oh]BR0?o00003on;DXP3o`0001OoRe:80ol000000on;DXSo0000oh]BR00@
oh]BR003o`000?nW`>_oYl3[00koYl3[0_l0000@ooooo`04o`000?ooooooooooo`0000_ooooo0_l0
00001?n;DXSo0000o`000?l0000=ooooo`03o`000?oooooooooo00;ooooo1?l00007ooooo`Co0000
:oooool002[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`04o`000?n;
DXSoRe:8oh]BR0?o00003on;DXP3o`0000;oRe:800?o0000oh]BR?n;DXP04_n;DXP3o`0000?oRe:8
00?o0000oh]BR?l000004?n;DXP00ol0003oYl3[ojO0j`0;ojO0j`?o000000?oooooo`000?ooool0
4?ooool3o`0000cooooo0_l0000@ooooo`03o`000?oooooo000000?o00001oooool4o`0002kooooo
000Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool4o`0000ooRe:80ol0
0006oh]BR003o`000?n;DXSoRe:800koRe:80ol00006oh]BR004o`000?n;DXSoRe:8o`0000ooRe:8
00?o0000ojO0jonW`>/02OnW`>/2o`0000Cooooo0_l0000Booooo`;o00003Oooool00ol0003ooooo
ooooo`0<ooooo`Co00001_ooool4o`0003;ooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01_ooool3o`0000ooRe:80ol00009oh]BR003o`000?n;DXSoRe:800_oRe:80ol0
0008oh]BR005o`000?n;DXSoRe:8oh]BR?l000003on;DXP00ol0003oYl3[ojO0j`06ojO0j`?o0000
1_ooool00ol0003oooooo`00000@ooooo`?o00003_ooool00ol0003oooooooooo`08ooooo`?o0000
00?oooooo`000?ooool01?ooool4o`0003Gooooo000[ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00oooool3o`0000;ooooo00?o0000oh]BR?n;DXP02_n;DXP3o`0000goRe:800?o
0000oh]BR?n;DXP02?n;DXP2o`0000_oRe:800?o0000oh]BR?n;DXP00_n;DXP00ol0003oRe:8oh]B
R00;oh]BR003o`000?nW`>_oYl3[00CoYl3[0ol00009ooooo`04o`000?ooooooooooo`0000cooooo
0ol00002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool3o`0000?ooooo
00?o0000ooooooooool01Ol0000hooooo`00:oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?o00001_ooool00ol0003oRe:8oh]BR005oh]BR0Co00004?n;DXP00ol0003oRe:8oh]B
R005oh]BR0?o00003?n;DXP00ol0003oRe:8oh]BR003oh]BR003o`000?n;DXSoRe:800_oRe:800?o
0000ojO0jonW`>/00_nW`>/2o`0000cooooo00Go0000ooooooooooooooooo`000008ooooo`?o0000
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o00001Oooool6o`0003_ooooo
000[ooooo`03o`000?oooooooooo01Sooooo0ol00009ooooo`03o`000?n;DXSoRe:800;oRe:80ol0
000Doh]BR003o`000?n;DXSoRe:800;oRe:80ol0000>oh]BR003o`000?n;DXSoRe:800GoRe:800?o
0000oh]BR?n;DXP02_n;DXP00ol0003oYl3[o`000002o`0000gooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool4o`0000Sooooo00?o0000ooooooooool03oooool2o`0000Kooooo
1Ol0000nooooo`00;?ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool02Ooo
ool00ol0003oRe:8o`000002o`0001SoRe:81?l0000Aoh]BR003o`000?n;DXSoRe:800KoRe:800?o
0000oh]BR?n;DXP02?n;DXP3o`00013ooooo00?o0000ooooooooool01?ooool3o`0000cooooo00?o
0000ooooooooool04Oooool3o`000003ooooool0003o000000;o0000@Oooool002cooooo00?o0000
ooooooooool04oooool2o`0000Cooooo00?o0000ooooooooool01_ooool3o`0001WoRe:80ol0000C
oh]BR003o`000?n;DXSoRe:800OoRe:800?o0000oh]BR?n;DXP02?n;DXP00ol0003oooooooooo`0@
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool03?ooool00ol0003ooooooooo
o`0Dooooo`;o0000A?ooool002cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo1?l000000ooooooo0000oh]BR00Foh]BR0?o00000on;DXP0
0ol0003oRe:8oh]BR00@oh]BR003o`000?n;DXSoRe:800OoRe:80_l00009oh]BR003o`000?oooooo
oooo013ooooo1?l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool0
02cooooo00?o0000ooooooooool04?ooool2o`0000Sooooo1?l00005ooooo`03o`000?n;DXSoRe:8
01?oRe:80_l00006oh]BR003o`000?n;DXSoRe:800ooRe:800?o0000oh]BR?n;DXP01On;DXP3o`00
0003oh]BR?l0003oRe:800OoRe:800?o0000ooooooooool03_ooool4o`0000Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0=ooooo`;o
00002?ooool3o`0000Sooooo00?o0000oh]BR?n;DXP04?n;DXP3o`0000WoRe:800?o0000oh]BR?n;
DXP03_n;DXP00ol0003oRe:8oh]BR003oh]BR0;o00001?n;DXP2o`0000OoRe:800?o0000oooooooo
ool02oooool5o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0;ooooo`;o00001oooool3o`0000;ooooo
00?o0000ooooooooool01_ooool00ol0003oRe:8oh]BR00=oh]BR0?o00003?n;DXP00ol0003oRe:8
oh]BR00=oh]BR004o`000?n;DXSoRe:8oh]BR0?o00001_n;DXP00ol0003oRe:8o`000006oh]BR003
o`000?oooooooooo00Oooooo1_l00004ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Wooooo000]ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`?o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?n;DXSoRe:800[oRe:80ol0000?oh]BR003o`00
0?n;DXSoRe:800goRe:800Co0000oh]BR?l0003o00002?n;DXP01Ol0003oRe:8oh]BR?n;DXSo0000
00CoRe:800?o0000ooooooooool01Oooool3o`000004ooooool0003o0000o`0000Gooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Wooooo000]
ooooo`03o`000?oooooooooo00Oooooo0_l00004ooooo`Co00002Oooool00ol0003oooooooooo`05
ooooo`03o`000?n;DXSoRe:800OoRe:80ol0000Coh]BR003o`000?n;DXSoRe:800_oRe:80ol0000:
oh]BR003o`000?n;DXSoRe:800;oRe:800Go0000oh]BR?n;DXSoRe:8o`000004ooooo`?o00000_oo
ool2o`0000Sooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo05Wooooo000^ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`?o00003_oo
ool00ol0003oooooooooo`05ooooo`03o`000?n;DXSoRe:800CoRe:80_l0000Foh]BR003o`000?n;
DXSoRe:800WoRe:80_l0000=oh]BR003o`000?n;DXSoRe:800?oRe:800?o0000oh]BR?n;DXP01Ol0
0002ooooo`?o00002_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Iooooo`00;_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?o00004Oooool00ol0003oooooooooo`05ooooo`04o`000?n;DXSoRe:8oh]BR0?o0000
6On;DXP00ol0003oRe:8oh]BR005oh]BR0?o000000?oRe:8o`000?n;DXP03?n;DXP00ol0003oRe:8
oh]BR004oh]BR0?o00001?ooool2o`0000cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool002kooooo00Co
0000oooooooooooooooo1Ol0000Eooooo`03o`000?oooooooooo00Cooooo1?l0000Loh]BR003o`00
0?n;DXSoRe:800?oRe:80_l00003oh]BR003o`000?n;DXSoRe:800coRe:800?o0000oh]BR?n;DXP0
1?n;DXP3o`000004ooooool0003o0000o`0000gooooo0_l00005ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`00;oooool5o`0001Sooooo
00?o0000ooooooooool00_ooool3o`00023oRe:800?o0000oh]BR?l000000_l00005oh]BR003o`00
0?n;DXSoRe:800_oRe:800?o0000oh]BR?n;DXP00_n;DXP3o`000004ooooool0003o0000o`0000ko
oooo0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Iooooo`00;oooool2o`0001_ooooo00?o0000ooooool00000
0_l00002ooooo`03o`000?n;DXSoRe:801koRe:80_l00007oh]BR003o`000?n;DXSoRe:800coRe:8
00?o0000oh]BR?n;DXP00_l00002ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`?o0000
0_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Iooooo`00;oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000oh]BR?n;DXP06_n;DXP4o`0000SoRe:800?o0000oh]BR?n;DXP03?n;
DXP4o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
1?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Hooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000oh]BR?n;DXP05on;DXP3o`0000CoRe:800?o0000oh]BR?n;DXP0
1?n;DXP00ol0003oRe:8oh]BR00;oh]BR0?o000000Coooooo`000?l0003o00001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000F_ooool0
033ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`000005ooooo`03o`000?n;DXSoRe:8
01GoRe:80_l00007oh]BR003o`000?n;DXSoRe:800CoRe:800?o0000oh]BR?n;DXP02On;DXP2o`00
00;ooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00;ooooo1Ol00006oooo
o`;o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooo0000F_ooool0037ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00005
ooooo`03o`000?n;DXSoRe:801;oRe:80ol0000:oh]BR003o`000?n;DXSoRe:800;oRe:800?o0000
oh]BR?n;DXP02?n;DXP2o`000004ooooool0003o0000o`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04o`0000;ooooo0ol000001_oooooo0000o`000?l0003oooooo`0000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000005[o
oooo000aooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?n;DXSoRe:8013oRe:80_l0000=oh]BR005o`000?n;DXSoRe:8oh]BR?l000002?n;DXP3o`00
0003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`Go000000?ooooo
o`000?ooool00oooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo0_l0001Jooooo`00<_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oRe:8oh]BR00<oh]B
R0?o00004?n;DXP01?l0003oRe:8oh]BR?l00006oh]BR0;o000000Coooooo`000?l0003o00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo1Ol00003ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02Oooool3o`0005[ooooo000booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?n;DXSoRe:800[oRe:80_l0
000Coh]BR003o`000?n;DXSo000000CoRe:80ol000000ooooooo0000o`000007ooooo`06o`000?oo
ooooooooooooool0003ooooo1Ol00005ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`?o
00000_ooool00ol0003oooooooooo`1Hooooo`00<oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000009oh]BR0?o00005On;DXP00ol0003o
Re:8o`000002oh]BR0;o000000Koooooo`000?l0003o0000ooooool00007ooooo`03o`000?oooooo
oooo00Go00000_ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo
1?l00005ooooo`03o`000?oooooooooo05Sooooo000cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000OoRe:80_l0000Goh]BR0?o0000
00CoRe:8o`000?l0003ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`Go
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`?o00002Oooool00ol0003oooooooooo`1Hooooo`00
=?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`000003oh]BR0?o00005_n;DXP3o`000003oh]BR?l0003o000000Co00002?ooool00ol0003o
ooooooooo`02ooooo`Co000000?oooooo`000?ooool00oooool3o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool4o`0000_ooooo00?o0000ooooooooool0F?ooool003Cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooo`000?n;DXP00_l0000Foh]BR0?o
00000_n;DXP2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000003o`0000Co
oooo00?o0000ooooool000000ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`Go00001?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Sooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooo`000002o`0001CoRe:81?l00003oh]BR0;o00001?ooool00ol0003ooooo
ooooo`09ooooo`Ko00001?ooool4o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1?l00007ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0F?ooool003Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00017oRe:80ol00004oh]BR0?o
00001Oooool00ol0003oooooo`000008ooooo`Co000000Coooooo`000?oooooo00000_ooool4o`00
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo1?l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Hooooo`00=_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00Go0000ooooooooooooooooo`00000=oh]BR0?o00001On;DXP2o`0000Sooooo00Co0000oooo
oooooooo00001Oooool4o`0000Cooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o000000?ooooo
o`000?ooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0F?ooool003Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`;o00000_ooool00ol0003oRe:8oh]BR007oh]BR0Co00001On;DXP3o`0000[ooooo00?o0000oooo
ooooool00_l000000ooooooo0000o`000003o`0000Gooooo1?l00004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Hooooo`00=_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00000_ooool00ol0003oRe:8oh]BR003oh]BR0?o00001on;DXP2o`00
00cooooo00?o0000ooooooooool00_ooool4o`0000Kooooo1?l000000ooooooo0000ooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000003o`00
0003ooooool0003ooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool003Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0=ooooo`07o`000?ooooooooooooooool0003oooooo`000002
oh]BR0?o00002?n;DXP2o`0000kooooo00?o0000ooooooooool01?l00006ooooo`?o00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool3o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`00=oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool4
o`0000SoRe:80ol0000@ooooo`Go000000?oooooo`000?l000000_ooool4o`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?l0
00000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0FOoo
ool003Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00?o000000?oooooo`000?l000001on;DXP2o`00017ooooo1?l00005ooooo`Go00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo0ol00005ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Iooooo`00>?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo0ol00005ooooo`;o00001?n;DXP2o`00
017ooooo0_l000000ooooooo0000ooooo`05ooooo`Co00002?ooool00ol0003oooooooooo`03oooo
o`;o000000?oooooo`000?l000000_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00001Kooooo`00>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo1Ol00008ooooo`03o`000?n;DXSo000000;o00004Oooool2o`0000?ooooo00Co0000oooo
oooooooooooo1?l000000ooooooo0000o`000007ooooo`03o`000?oooooooooo00Gooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000005_ooooo000iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool3
o`0000Cooooo00?o0000ooooooooool01oooool2o`00013ooooo0ol00004ooooo`03o`000?oooooo
000000Co00000oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00Co0000
oooooooooooo0000Foooool003[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`?o00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000gooooo0_l00006
ooooo`03o`000?oooooo000000?o00001_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooo`00001Kooooo`00>_ooool01Ol0003ooooooooooooooooo000000Gooooo1?l00009
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_l00009ooooo`;o00001oooool6
o`0000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
000005_ooooo000kooooo`04o`000?ooooooooooo`0000;ooooo0ol0000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00007ooooo`Co00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool2
o`0005_ooooo000kooooo`03o`000?oooooo000000?o00004?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o00002?ooool4o`0000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0ol0001K
ooooo`00??ooool2o`0001;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`Go00000oooool4o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool4o`0000;ooooo00?o0000oooo
ooooool0FOooool003cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool4o`0000Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000_l00006oooo
o`03o`000?oooooooooo05Wooooo000mooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4o`0000Wo
oooo00?o0000ooooooooool0FOooool003kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooo
o`000?l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000ol00003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0F_ooool003kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool3o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool3o`0000Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Jooooo`00?oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o000000?o
ooooo`000?ooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`000003o`0000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05[ooooo0010ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0ol00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo1?l00006ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00@?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?l00002ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05[ooooo0011ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`?o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool3o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Foooool0
047ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
ooooo`Co000000?oooooo`000?ooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool4o`000003ooooool0003ooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Foooool004;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`Co00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
001Mooooo`00@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`Co000000?o
ooooo`000?ooool01oooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000ooooool00000
1Oooool3o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00001Mooooo`00@oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooool0003o0000ooooo`04o`000003ooooool0003ooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo0000GOooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool5o`0000Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool0001Mooooo`00AOooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l00006oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo0_l0001Nooooo`00AOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool5o`0000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`;o0000G_ooool004Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool3o`0005ko
oooo0017ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool4o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo1?l00002ooooo`03o`000?oooooooooo05cooooo0017ooooo`05o`000?ooooooooooooooool0
00002oooool5o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo1?l00005ooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`Go00001oooool00ol0003oooooooooo`1Nooooo`00B?ooool01?l0
003oooooooooool00004ooooo`?o00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooool000000_l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0G_ooool004Wooooo0_l000000ooooooo0000o`000002o`0000_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000;oooo
o`03o`000?oooooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Goooool004[ooooo0_l0000?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`Co00002oooool01?l0003oooooooooooooool4o`00
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
063ooooo001;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`08oooo
o`Co00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0H?ooool004cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo1?l00009ooooo`;o00001?ooool5o`0000[ooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool0001Sooooo`00COooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000000ol0000>ooooo`Co00001?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000Hoooool004ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`Co00000_ooool00ol0003o
ooooooooo`09ooooo`Co000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooool00000I?ooool004oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`?o00000oooool01?l0003oooooooooool00008ooooo`?o
00001_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`?o
0000IOooool0053ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool5o`0000Oooooo00?o0000ooooool00000
1?ooool4o`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?oooooooooooooo
o`Go0000Ioooool0057ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool4o`0000_ooooo0_l000000ooooooo
0000o`000002o`00013ooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo1?l00002ooooo`;o
0000J?ooool005;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oooooooooo00Wo
oooo0_l0000Fooooo`03o`000?oooooo000000Oooooo1?l00004ooooo`03o`000?oooooooooo06So
oooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`Co00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo
0_l00003ooooo`Co00000oooool00ol0003oooooooooo`02o`0006_ooooo001Dooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`Go00002_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo2Ol00005ooooo`;o0000KOoo
ool005Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo
ooooooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04oooool7o`0000Kooooo1_l0001^ooooo`00E_ooool01Ol0003ooooooooooooo
oooo000000cooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`Oo00002Oooool4o`00077ooooo001Gooooo`04o`000?oooooo
ooooo`0000Sooooo1?l000000ooooooo0000ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`Oo00002Oooool4o`0007Gooooo001H
ooooo`03o`000?oooooo000000Gooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo1ol00008
ooooo`Co0000NOooool005Wooooo0_l000000ooooooo0000o`000002o`0000Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool7o`0000Sooooo1?l0001mooooo`00F_ooool2o`0000cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool7o`0000Sooooo1?l00021ooooo`00G?ooool2o`0000[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo2?l00007ooooo`Co
0000QOooool005kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000001ol00006ooooo`Go0000ROooool005oooooo0_l0
0007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool8o`0000Kooooo1?l0
002>ooooo`00HOooool2o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`Co00000_ooool3o`0000Gooooo1?l0002Booooo`00Hoooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000000_l00004ooooo`;o00001?ooool4o`00
09Kooooo001Tooooo`;o00000oooool00ol0003oooooooooo`07ooooo`Co00001?ooool3o`0000;o
oooo1?l0002Jooooo`00I_ooool2o`000003ooooool0003ooooo00Cooooo1?l00002ooooo`04o`00
0?ooooooooooooooo`;o000000?oooooo`000?l000000_l0002Nooooo`00J?ooool2o`000003oooo
ool0003o000000;o00001oooool6o`000:;ooooo001Yooooo`oo0000Y_ooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool0
0?oooooo7oooool00?oooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 285.25}, {344.625, 0}} -> {0.0845644, -0.000223281, \
0.00273298, 0.00273298}}]
}, Open  ]],

Cell["\<\
We can now use the generated aspheric lens as a started condition \
for our optimization. First we assign symbolic values to accompany each \
numeric parameter in the previously generated aspheric lens. These symbolic \
parameters are used in the optimization procedure. We do not assign symboic \
values to the lens aperture parameters since these are not relavent to the \
optimization procedure.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
alens = \
AsphericLens[{{curva,0.9},{ka,-0.696917},{ca1,0},{ca2,0},{ca3,-0.0869628},{\
ca4,-0.0133304},{ca5,-0.153352},1.3},
\t{{curvb,-0.9},{kb,-6.99529},{cb1,0},{cb2,0},{cb3,-0.171893},{cb4,-0.0409008}\
, {cb5,0.0885435}, 1.13},2.4, 1.03,{ComponentMedium\[Rule]CO550}]\
\>", \
"Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[\(AsphericLens[{{curva, 0.9`}, {ka, \(-0.696917`\)}, {ca1, 
                0}, {ca2, 
                0}, {ca3, \(-0.0869628`\)}, {ca4, \(-0.0133304`\)}, {ca5, \
\(-0.153352`\)}, 
              1.3`}, {{curvb, \(-0.9`\)}, {kb, \(-6.99529`\)}, {cb1, 
                0}, {cb2, 
                0}, {cb3, \(-0.171893`\)}, {cb4, \(-0.0409008`\)}, {cb5, 
                0.0885435`}, 1.13`}, 2.4`, 
            1.03`, {ComponentMedium \[Rule] CO550}]\),
          HoldForm],
        FontColor->RGBColor[0, 0.392187, 0]],
      DisplayForm]], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[TextData[{
  "Each aspheric lens surface is internally represented by an equation which \
you can examine from the ",
  StyleBox["SymbolicSurfaceFunction", "Input"],
  " of the lens as follows."
}], "Text"],

Cell[CellGroupData[{

Cell["SymbolicSurfaceFunction/.(Surfaces/.alens)[[{1,4}]]", "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({{ca1\ \((#1\^2 + #2\^2)\) + ca2\ \((#1\^2 + #2\^2)\)\^2 + 
            ca3\ \((#1\^2 + #2\^2)\)\^3 + ca4\ \((#1\^2 + #2\^2)\)\^4 + 
            ca5\ \((#1\^2 + #2\^2)\)\^5 + \(curva\ \((#1\^2 + #2\^2)\)\)\/\(1 \
+ \@\(1 - curva\^2\ \((1 + ka)\)\ \((#1\^2 + #2\^2)\)\)\), #1, #2} &, {cb1\ \
\((#1\^2 + #2\^2)\) + cb2\ \((#1\^2 + #2\^2)\)\^2 + 
            cb3\ \((#1\^2 + #2\^2)\)\^3 + cb4\ \((#1\^2 + #2\^2)\)\^4 + 
            cb5\ \((#1\^2 + #2\^2)\)\^5 + \(curvb\ \((#1\^2 + #2\^2)\)\)\/\(1 \
+ \@\(1 - curvb\^2\ \((1 + kb)\)\ \((#1\^2 + #2\^2)\)\)\), #1, #2} &}\)], \
"Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[TextData[{
  "For the default settings of the lens, each symbolic parameter is assigned \
a numeric value for the purposes of making a numeric trace of the system. \
These assignments are stored in ",
  StyleBox["SymbolicValues", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["?SymbolicValues", "Input",
  CellLabel->"In[60]:=",
  FormatType->InputForm],

Cell[BoxData[
    \("SymbolicValues -> {symbol->value,...} is an option that attaches \
numerical values to the specified symbolic variable names.\n\nSymbolicValues \
is required in custom component functions, such as CustomMirror and \
CustomLens, to assign numerical values to any user-defined symbolic variables \
present in the custom surface function. SymbolicValues is stored in the \
Surfaces rule of the Component object. SymbolicValues can be user-specified \
or, in some cases, is automatically generated during the Component creation."\
\)], "Print",
  CellTags->"Info3334672378-7410168"]
}, Open  ]],

Cell[TextData[{
  "Here are the ",
  StyleBox["SymbolicValues", "Input"],
  " for ",
  StyleBox["alens", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["SymbolicValues/.(Surfaces/.alens)", "Input"],

Cell[BoxData[
    \({{ca1 \[Rule] 0, ca2 \[Rule] 0, ca3 \[Rule] \(-0.0869628`\), 
        ca4 \[Rule] \(-0.0133304`\), ca5 \[Rule] \(-0.153352`\), 
        curva \[Rule] 0.9`, 
        ka \[Rule] \(-0.696917`\)}, {}, {}, {cb1 \[Rule] 0, cb2 \[Rule] 0, 
        cb3 \[Rule] \(-0.171893`\), cb4 \[Rule] \(-0.0409008`\), 
        cb5 \[Rule] 0.0885435`, curvb \[Rule] \(-0.9`\), 
        kb \[Rule] \(-6.99529`\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
We will now place a light source in front of this lens and trace \
rays to a screen surface placed a fixed distance from the lens.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
plot = \
TurboPlot[{WedgeOfRays[20,NumberOfRays->11],Move[alens,2.5],Move[Screen[2.5],\
5]},PlotType->TopView];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.25 0.190476 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.53548 .12619 m
.67403 .14238 L
.68552 .17825 L
.51617 .16746 L
.53548 .12619 L
F
.51617 .16746 m
.68552 .17825 L
.69327 .21413 L
.50403 .20873 L
.51617 .16746 L
F
.50403 .20873 m
.69327 .21413 L
.69619 .25 L
.5 .25 L
.50403 .20873 L
F
.5 .25 m
.69619 .25 L
.69327 .28587 L
.50403 .29127 L
.5 .25 L
F
.50403 .29127 m
.69327 .28587 L
.68552 .32175 L
.51617 .33254 L
.50403 .29127 L
F
.51617 .33254 m
.68552 .32175 L
.67403 .35762 L
.53548 .37381 L
.51617 .33254 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.53548 .12619 m
.51617 .16746 L
.50403 .20873 L
.5 .25 L
.50403 .29127 L
.51617 .33254 L
.53548 .37381 L
.67403 .35762 L
.68552 .32175 L
.69327 .28587 L
.69619 .25 L
.69327 .21413 L
.68552 .17825 L
.67403 .14238 L
.53548 .12619 L
s
.5 g
.53548 .25 m
.67403 .25 L
.68552 .25 L
.51617 .25 L
.53548 .25 L
F
.51617 .25 m
.68552 .25 L
.69327 .25 L
.50403 .25 L
.51617 .25 L
F
.50403 .25 m
.69327 .25 L
.69619 .25 L
.5 .25 L
.50403 .25 L
F
.5 .25 m
.69619 .25 L
.69327 .25 L
.50403 .25 L
.5 .25 L
F
.50403 .25 m
.69327 .25 L
.68552 .25 L
.51617 .25 L
.50403 .25 L
F
.51617 .25 m
.68552 .25 L
.67403 .25 L
.53548 .25 L
.51617 .25 L
F
0 g
.53548 .25 m
.51617 .25 L
.50403 .25 L
.5 .25 L
.50403 .25 L
.51617 .25 L
.53548 .25 L
.67403 .25 L
.68552 .25 L
.69327 .25 L
.69619 .25 L
.69327 .25 L
.68552 .25 L
.67403 .25 L
.53548 .25 L
s
.53548 .37381 m
.53548 .47857 L
.53548 .47078 L
.53548 .36959 L
.53548 .37381 L
s
.53548 .36959 m
.53548 .47078 L
.53548 .44795 L
.53548 .35722 L
.53548 .36959 L
s
.53548 .35722 m
.53548 .44795 L
.53548 .41162 L
.53548 .33755 L
.53548 .35722 L
s
.53548 .33755 m
.53548 .41162 L
.53548 .36429 L
.53548 .3119 L
.53548 .33755 L
s
.53548 .3119 m
.53548 .36429 L
.53548 .30916 L
.53548 .28204 L
.53548 .3119 L
s
.53548 .28204 m
.53548 .30916 L
.53548 .25 L
.53548 .25 L
.53548 .28204 L
s
.53548 .25 m
.53548 .25 L
.53548 .19084 L
.53548 .21796 L
.53548 .25 L
s
.53548 .21796 m
.53548 .19084 L
.53548 .13571 L
.53548 .1881 L
.53548 .21796 L
s
.53548 .1881 m
.53548 .13571 L
.53548 .08838 L
.53548 .16245 L
.53548 .1881 L
s
.53548 .16245 m
.53548 .08838 L
.53548 .05205 L
.53548 .14278 L
.53548 .16245 L
s
.53548 .14278 m
.53548 .05205 L
.53548 .02922 L
.53548 .13041 L
.53548 .14278 L
s
.53548 .13041 m
.53548 .02922 L
.53548 .02143 L
.53548 .12619 L
.53548 .13041 L
s
.53548 .12619 m
.53548 .02143 L
.53548 .02922 L
.53548 .13041 L
.53548 .12619 L
s
.53548 .13041 m
.53548 .02922 L
.53548 .05205 L
.53548 .14278 L
.53548 .13041 L
s
.53548 .14278 m
.53548 .05205 L
.53548 .08838 L
.53548 .16245 L
.53548 .14278 L
s
.53548 .16245 m
.53548 .08838 L
.53548 .13571 L
.53548 .1881 L
.53548 .16245 L
s
.53548 .1881 m
.53548 .13571 L
.53548 .19084 L
.53548 .21796 L
.53548 .1881 L
s
.53548 .21796 m
.53548 .19084 L
.53548 .25 L
.53548 .25 L
.53548 .21796 L
s
.53548 .25 m
.53548 .25 L
.53548 .30916 L
.53548 .28204 L
.53548 .25 L
s
.53548 .28204 m
.53548 .30916 L
.53548 .36429 L
.53548 .3119 L
.53548 .28204 L
s
.53548 .3119 m
.53548 .36429 L
.53548 .41162 L
.53548 .33755 L
.53548 .3119 L
s
.53548 .33755 m
.53548 .41162 L
.53548 .44795 L
.53548 .35722 L
.53548 .33755 L
s
.53548 .35722 m
.53548 .44795 L
.53548 .47078 L
.53548 .36959 L
.53548 .35722 L
s
.53548 .36959 m
.53548 .47078 L
.53548 .47857 L
.53548 .37381 L
.53548 .36959 L
s
.53548 .47857 m
.67403 .47857 L
.67403 .47078 L
.53548 .47078 L
.53548 .47857 L
s
.53548 .47078 m
.67403 .47078 L
.67403 .44795 L
.53548 .44795 L
.53548 .47078 L
s
.53548 .44795 m
.67403 .44795 L
.67403 .41162 L
.53548 .41162 L
.53548 .44795 L
s
.53548 .41162 m
.67403 .41162 L
.67403 .36429 L
.53548 .36429 L
.53548 .41162 L
s
.53548 .36429 m
.67403 .36429 L
.67403 .30916 L
.53548 .30916 L
.53548 .36429 L
s
.53548 .30916 m
.67403 .30916 L
.67403 .25 L
.53548 .25 L
.53548 .30916 L
s
.53548 .25 m
.67403 .25 L
.67403 .19084 L
.53548 .19084 L
.53548 .25 L
s
.53548 .19084 m
.67403 .19084 L
.67403 .13571 L
.53548 .13571 L
.53548 .19084 L
s
.53548 .13571 m
.67403 .13571 L
.67403 .08838 L
.53548 .08838 L
.53548 .13571 L
s
.53548 .08838 m
.67403 .08838 L
.67403 .05205 L
.53548 .05205 L
.53548 .08838 L
s
.53548 .05205 m
.67403 .05205 L
.67403 .02922 L
.53548 .02922 L
.53548 .05205 L
s
.53548 .02922 m
.67403 .02922 L
.67403 .02143 L
.53548 .02143 L
.53548 .02922 L
s
.53548 .02143 m
.67403 .02143 L
.67403 .02922 L
.53548 .02922 L
.53548 .02143 L
s
.53548 .02922 m
.67403 .02922 L
.67403 .05205 L
.53548 .05205 L
.53548 .02922 L
s
.53548 .05205 m
.67403 .05205 L
.67403 .08838 L
.53548 .08838 L
.53548 .05205 L
s
.53548 .08838 m
.67403 .08838 L
.67403 .13571 L
.53548 .13571 L
.53548 .08838 L
s
.53548 .13571 m
.67403 .13571 L
.67403 .19084 L
.53548 .19084 L
.53548 .13571 L
s
.53548 .19084 m
.67403 .19084 L
.67403 .25 L
.53548 .25 L
.53548 .19084 L
s
.53548 .25 m
.67403 .25 L
.67403 .30916 L
.53548 .30916 L
.53548 .25 L
s
.53548 .30916 m
.67403 .30916 L
.67403 .36429 L
.53548 .36429 L
.53548 .30916 L
s
.53548 .36429 m
.67403 .36429 L
.67403 .41162 L
.53548 .41162 L
.53548 .36429 L
s
.53548 .41162 m
.67403 .41162 L
.67403 .44795 L
.53548 .44795 L
.53548 .41162 L
s
.53548 .44795 m
.67403 .44795 L
.67403 .47078 L
.53548 .47078 L
.53548 .44795 L
s
.53548 .47078 m
.67403 .47078 L
.67403 .47857 L
.53548 .47857 L
.53548 .47078 L
s
.53548 .37381 m
.67403 .35762 L
.67403 .35395 L
.53548 .36959 L
.53548 .37381 L
s
.53548 .36959 m
.67403 .35395 L
.67403 .3432 L
.53548 .35722 L
.53548 .36959 L
s
.53548 .35722 m
.67403 .3432 L
.67403 .3261 L
.53548 .33755 L
.53548 .35722 L
s
.53548 .33755 m
.67403 .3261 L
.67403 .30381 L
.53548 .3119 L
.53548 .33755 L
s
.53548 .3119 m
.67403 .30381 L
.67403 .27785 L
.53548 .28204 L
.53548 .3119 L
s
.53548 .28204 m
.67403 .27785 L
.67403 .25 L
.53548 .25 L
.53548 .28204 L
s
.53548 .25 m
.67403 .25 L
.67403 .22215 L
.53548 .21796 L
.53548 .25 L
s
.53548 .21796 m
.67403 .22215 L
.67403 .19619 L
.53548 .1881 L
.53548 .21796 L
s
.53548 .1881 m
.67403 .19619 L
.67403 .1739 L
.53548 .16245 L
.53548 .1881 L
s
.53548 .16245 m
.67403 .1739 L
.67403 .1568 L
.53548 .14278 L
.53548 .16245 L
s
.53548 .14278 m
.67403 .1568 L
.67403 .14605 L
.53548 .13041 L
.53548 .14278 L
s
.53548 .13041 m
.67403 .14605 L
.67403 .14238 L
.53548 .12619 L
.53548 .13041 L
s
.53548 .12619 m
.67403 .14238 L
.67403 .14605 L
.53548 .13041 L
.53548 .12619 L
s
.53548 .13041 m
.67403 .14605 L
.67403 .1568 L
.53548 .14278 L
.53548 .13041 L
s
.53548 .14278 m
.67403 .1568 L
.67403 .1739 L
.53548 .16245 L
.53548 .14278 L
s
.53548 .16245 m
.67403 .1739 L
.67403 .19619 L
.53548 .1881 L
.53548 .16245 L
s
.53548 .1881 m
.67403 .19619 L
.67403 .22215 L
.53548 .21796 L
.53548 .1881 L
s
.53548 .21796 m
.67403 .22215 L
.67403 .25 L
.53548 .25 L
.53548 .21796 L
s
.53548 .25 m
.67403 .25 L
.67403 .27785 L
.53548 .28204 L
.53548 .25 L
s
.53548 .28204 m
.67403 .27785 L
.67403 .30381 L
.53548 .3119 L
.53548 .28204 L
s
.53548 .3119 m
.67403 .30381 L
.67403 .3261 L
.53548 .33755 L
.53548 .3119 L
s
.53548 .33755 m
.67403 .3261 L
.67403 .3432 L
.53548 .35722 L
.53548 .33755 L
s
.53548 .35722 m
.67403 .3432 L
.67403 .35395 L
.53548 .36959 L
.53548 .35722 L
s
.53548 .36959 m
.67403 .35395 L
.67403 .35762 L
.53548 .37381 L
.53548 .36959 L
s
.67403 .47857 m
.67403 .35762 L
.67403 .35395 L
.67403 .47078 L
.67403 .47857 L
s
.67403 .47078 m
.67403 .35395 L
.67403 .3432 L
.67403 .44795 L
.67403 .47078 L
s
.67403 .44795 m
.67403 .3432 L
.67403 .3261 L
.67403 .41162 L
.67403 .44795 L
s
.67403 .41162 m
.67403 .3261 L
.67403 .30381 L
.67403 .36429 L
.67403 .41162 L
s
.67403 .36429 m
.67403 .30381 L
.67403 .27785 L
.67403 .30916 L
.67403 .36429 L
s
.67403 .30916 m
.67403 .27785 L
.67403 .25 L
.67403 .25 L
.67403 .30916 L
s
.67403 .25 m
.67403 .25 L
.67403 .22215 L
.67403 .19084 L
.67403 .25 L
s
.67403 .19084 m
.67403 .22215 L
.67403 .19619 L
.67403 .13571 L
.67403 .19084 L
s
.67403 .13571 m
.67403 .19619 L
.67403 .1739 L
.67403 .08838 L
.67403 .13571 L
s
.67403 .08838 m
.67403 .1739 L
.67403 .1568 L
.67403 .05205 L
.67403 .08838 L
s
.67403 .05205 m
.67403 .1568 L
.67403 .14605 L
.67403 .02922 L
.67403 .05205 L
s
.67403 .02922 m
.67403 .14605 L
.67403 .14238 L
.67403 .02143 L
.67403 .02922 L
s
.67403 .02143 m
.67403 .14238 L
.67403 .14605 L
.67403 .02922 L
.67403 .02143 L
s
.67403 .02922 m
.67403 .14605 L
.67403 .1568 L
.67403 .05205 L
.67403 .02922 L
s
.67403 .05205 m
.67403 .1568 L
.67403 .1739 L
.67403 .08838 L
.67403 .05205 L
s
.67403 .08838 m
.67403 .1739 L
.67403 .19619 L
.67403 .13571 L
.67403 .08838 L
s
.67403 .13571 m
.67403 .19619 L
.67403 .22215 L
.67403 .19084 L
.67403 .13571 L
s
.67403 .19084 m
.67403 .22215 L
.67403 .25 L
.67403 .25 L
.67403 .19084 L
s
.67403 .25 m
.67403 .25 L
.67403 .27785 L
.67403 .30916 L
.67403 .25 L
s
.67403 .30916 m
.67403 .27785 L
.67403 .30381 L
.67403 .36429 L
.67403 .30916 L
s
.67403 .36429 m
.67403 .30381 L
.67403 .3261 L
.67403 .41162 L
.67403 .36429 L
s
.67403 .41162 m
.67403 .3261 L
.67403 .3432 L
.67403 .44795 L
.67403 .41162 L
s
.67403 .44795 m
.67403 .3432 L
.67403 .35395 L
.67403 .47078 L
.67403 .44795 L
s
.67403 .47078 m
.67403 .35395 L
.67403 .35762 L
.67403 .47857 L
.67403 .47078 L
s
.97619 .0119 m
.97619 .09127 L
.97619 .17063 L
.97619 .25 L
.97619 .32937 L
.97619 .40873 L
.97619 .4881 L
.97619 .4881 L
.97619 .40873 L
.97619 .32937 L
.97619 .25 L
.97619 .17063 L
.97619 .09127 L
.97619 .0119 L
.97619 .0119 L
s
.97619 .25 m
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
s
.97619 .4881 m
.97619 .47998 L
.97619 .4562 L
.97619 .41836 L
.97619 .36905 L
.97619 .31162 L
.97619 .25 L
.97619 .18838 L
.97619 .13095 L
.97619 .08164 L
.97619 .0438 L
.97619 .02002 L
.97619 .0119 L
.97619 .02002 L
.97619 .0438 L
.97619 .08164 L
.97619 .13095 L
.97619 .18838 L
.97619 .25 L
.97619 .31162 L
.97619 .36905 L
.97619 .41836 L
.97619 .4562 L
.97619 .47998 L
.97619 .4881 L
s
.039 .916 .04 r
.02381 .25 m
.51801 .33714 L
s
0 0 0 r
2.5 Mabswid
.51801 .33714 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51113 .31849 L
s
0 0 0 r
2.5 Mabswid
.51113 .31849 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50609 .30069 L
s
0 0 0 r
2.5 Mabswid
.50609 .30069 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50265 .28348 L
s
0 0 0 r
2.5 Mabswid
.50265 .28348 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50066 .26665 L
s
0 0 0 r
2.5 Mabswid
.50066 .26665 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.5 .25 L
s
0 0 0 r
2.5 Mabswid
.5 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50066 .23335 L
s
0 0 0 r
2.5 Mabswid
.50066 .23335 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50265 .21652 L
s
0 0 0 r
2.5 Mabswid
.50265 .21652 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50609 .19931 L
s
0 0 0 r
2.5 Mabswid
.50609 .19931 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51113 .18151 L
s
0 0 0 r
2.5 Mabswid
.51113 .18151 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51801 .16286 L
s
0 0 0 r
2.5 Mabswid
.51801 .16286 Mdot
.039 .916 .04 r
.5 Mabswid
.51801 .33714 m
.68357 .32874 L
s
0 0 0 r
2.5 Mabswid
.68357 .32874 Mdot
.039 .916 .04 r
.5 Mabswid
.51113 .31849 m
.68808 .3117 L
s
0 0 0 r
2.5 Mabswid
.68808 .3117 Mdot
.039 .916 .04 r
.5 Mabswid
.50609 .30069 m
.69155 .2957 L
s
0 0 0 r
2.5 Mabswid
.69155 .2957 Mdot
.039 .916 .04 r
.5 Mabswid
.50265 .28348 m
.69409 .28025 L
s
0 0 0 r
2.5 Mabswid
.69409 .28025 Mdot
.039 .916 .04 r
.5 Mabswid
.50066 .26665 m
.69566 .26507 L
s
0 0 0 r
2.5 Mabswid
.69566 .26507 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25 m
.69619 .25 L
s
0 0 0 r
2.5 Mabswid
.69619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50066 .23335 m
.69566 .23493 L
s
0 0 0 r
2.5 Mabswid
.69566 .23493 Mdot
.039 .916 .04 r
.5 Mabswid
.50265 .21652 m
.69409 .21975 L
s
0 0 0 r
2.5 Mabswid
.69409 .21975 Mdot
.039 .916 .04 r
.5 Mabswid
.50609 .19931 m
.69155 .2043 L
s
0 0 0 r
2.5 Mabswid
.69155 .2043 Mdot
.039 .916 .04 r
.5 Mabswid
.51113 .18151 m
.68808 .1883 L
s
0 0 0 r
2.5 Mabswid
.68808 .1883 Mdot
.039 .916 .04 r
.5 Mabswid
.51801 .16286 m
.68357 .17126 L
s
0 0 0 r
2.5 Mabswid
.68357 .17126 Mdot
.039 .916 .04 r
.5 Mabswid
.68357 .32874 m
.97619 .24782 L
s
0 0 0 r
2.5 Mabswid
.97619 .24782 Mdot
.039 .916 .04 r
.5 Mabswid
.68808 .3117 m
.97619 .24869 L
s
0 0 0 r
2.5 Mabswid
.97619 .24869 Mdot
.039 .916 .04 r
.5 Mabswid
.69155 .2957 m
.97619 .24887 L
s
0 0 0 r
2.5 Mabswid
.97619 .24887 Mdot
.039 .916 .04 r
.5 Mabswid
.69409 .28025 m
.97619 .24899 L
s
0 0 0 r
2.5 Mabswid
.97619 .24899 Mdot
.039 .916 .04 r
.5 Mabswid
.69566 .26507 m
.97619 .24937 L
s
0 0 0 r
2.5 Mabswid
.97619 .24937 Mdot
.039 .916 .04 r
.5 Mabswid
.69619 .25 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69566 .23493 m
.97619 .25063 L
s
0 0 0 r
2.5 Mabswid
.97619 .25063 Mdot
.039 .916 .04 r
.5 Mabswid
.69409 .21975 m
.97619 .25101 L
s
0 0 0 r
2.5 Mabswid
.97619 .25101 Mdot
.039 .916 .04 r
.5 Mabswid
.69155 .2043 m
.97619 .25113 L
s
0 0 0 r
2.5 Mabswid
.97619 .25113 Mdot
.039 .916 .04 r
.5 Mabswid
.68808 .1883 m
.97619 .25131 L
s
0 0 0 r
2.5 Mabswid
.97619 .25131 Mdot
.039 .916 .04 r
.5 Mabswid
.68357 .17126 m
.97619 .25218 L
s
0 0 0 r
2.5 Mabswid
.97619 .25218 Mdot
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1014.56, 507.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?f0001nb000`400?l00000o`00003ooooooooo
oooooooooooonOooool00?ooooooooooooooooooooWooooo003ooooooooooooooooooooiooooo`00
oooooooooooooooooooonOooool00?ooooooooooooooooooooWooooo003ooooooooooooooooooooi
ooooo`00oooooooooooooooooooonOooool00?ooooooooooooooooooooWooooo003ooooooooooooo
oooooooiooooo`00oooooooooooooooooooonOooool00?ooooooooooooooooooooWooooo003ooooo
oooooooooooooooiooooo`00oooooooooooooooooooogoooool2o`0001Sooooo003ooooooooooooo
oooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooo
oooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03
o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo
003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooO
ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo8?oooon=o`000?oooooo<_ooool00ol0003oooooooooo`0Gooooo`00
ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo
00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooohgo0000oooooolb
ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooooooo
ool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
ooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000
ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo
00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooo
oooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0
003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo
003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?oo
ool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oo
oooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3oooooSOl0003ooooooc;ooooo
00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooo
oooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0
003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo
003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?oo
ool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oo
oooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooo
oolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oo
oooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03
o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05ooo
ool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`
ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooooooo
ool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
ooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000
ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo
00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooohgo0000oooooolb
ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooooooo
ool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
ooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000
ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo
00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooo
oooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0
003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo
003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?oo
ool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPoooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oo
oooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooo
oolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oo
oooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03
o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05ooo
ool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`
ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29oooo
o`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooooooo
ool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
ooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000
ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
ooooooooooooob3ooooo1Ol00027ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooo
ooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ogmoOomoOgl00_moOgl9o`0007kooooo00?o
0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo7oooool2
o`0000goOgmo2Ol0001eooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0G
ooooo`00oooooooooooooaoooooo0_l0000FogmoO`Wo0000K?ooool00ol0003oooooooooo`3ooooo
oc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolNooooo`03o`000?moOgoo000000Co
00006omoOgl8o`0006Cooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo7_ooool00ol0003oOgmoo`000004ogmoO`Wo00006_moOgl9o`0005_ooooo
00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo7_oo
ool00ol0003oOgmoo`00000=ogmoO`Wo00006_moOgl9o`0005;ooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo7Oooool01?l0003oOgmoogmoOol0
000FogmoO`Wo00006_moOgl9o`0004Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooo7Oooool01?l0003oOgmoogmoOol0000OogmoO`So00006omo
Ogl8o`00047ooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooo7?ooool01Ol0003oOgmoogmoOomoOgoo000002OoOgmo2Ol0000JogmoO`Wo0000>?oo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolL
ooooo`04o`000?moOgooOgmoogmoOhgo0000oooooolbooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooo6oooool00ol0003oOgmoogmoO`02ogmoO`03o`000?moOgooOgmo03OoOgmo2Ol0000J
ogmoO`Wo00009_ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolKooooo`03o`000?moOgooOgmo00;oOgmo00?o0000ogmoOomoOgl0@?moOgl8o`00
01_oOgmo2?l0000Nooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Goooo
o`00oooooooooooooa[ooooo00?o0000ogmoOomoOgl00omoOgl00ol0003oOgmoogmoO`18ogmoO`Wo
00006_moOgl9o`0001Gooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo6_ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo057oOgmo
2Ol0000JogmoO`Wo00003?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
5oooool00?oooooooooooolIooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl0F_mo
Ogl9o`0001[oOgmo2Ol00003ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooooooo
o`0Gooooo`00oooooooooooooaWooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`1S
ogmoO`So00006omoOgl4o`000?oooooo<_ooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
oaWooooo00?o0000ogmoOomoOgl01?moOgl6o`0006SoOgmo2Ol0000EogmoO`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaSooooo00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oOgmoogmoO`03ogmoO`[o0000IomoOgl9o`0000coOgmo00?o0000oooooooo
ool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo6?ooool00ol0003oOgmo
ogmoO`05ogmoO`03o`000?moOgooOgmo00goOgmo2_l0001VogmoO`Wo00000omoOgl2o`000?oooooo
<Oooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaOooooo00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oOgmoogmoO`0GogmoO`[o0000IOmoOgl5o`000?oooooo<Oooool00ol0003ooooooooo
o`0Gooooo`00oooooooooooooaOooooo00?o0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0Q
ogmoO`[o0000G_moOgl2o`000?oooooo<Oooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
oaKooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0[ogmoO`[o0000E?moOgl00ol0
003oOgmoo`00003ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolFooooo`03
o`000?moOgooOgmo00OoOgmo00?o0000ogmoOomoOgl0=OmoOgl:o`0004[oOgmo00?o0000ogmoOol0
0000ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo5Oooool00ol0003oOgmo
ogmoO`08ogmoO`03o`000?moOgooOgmo03ooOgmo2_l00010ogmoO`03o`000?moOgoo00000?oooooo
<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaGooooo00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oOgmoogmoO`19ogmoO`[o0000=_moOgl01?l0003oOgmoogmoOol0003ooooooboooooo
00?o0000ooooooooool05oooool00?oooooooooooolDooooo`03o`000?moOgooOgmo00WoOgmo00?o
0000ogmoOomoOgl0DomoOgl:o`0002coOgmo00Co0000ogmoOomoOgoo0000ooooool_ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo5?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?mo
OgooOgmo05goOgmo2_l0000RogmoO`04o`000?moOgooOgmoo`000?oooooo;oooool00ol0003ooooo
ooooo`0Gooooo`00oooooooooooooaCooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oOgmoogmo
O`1WogmoO`[o00006?moOgl01Ol0003oOgmoogmoOomoOgoo00000?oooooo;_ooool00ol0003ooooo
ooooo`0Gooooo`00oooooooooooooa?ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmo
O`1aogmoO`[o00003_moOgl01Ol0003oOgmoogmoOomoOgoo00000?oooooo;_ooool00ol0003ooooo
ooooo`0Gooooo`00oooooooooooooa?ooooo00?o0000ogmoOomoOgl02_moOgl00ol0003oOgmoogmo
O`1kogmoO`[o00001?moOgl01Ol0003oOgmoogmoOomoOgoo00000?oooooo;_ooool00ol0003ooooo
ooooo`0Gooooo`00oooooooooooooa;ooooo00?o0000ogmoOomoOgl02omoOgl00ol0003oOgmoogmo
O`25ogmoO`Go00001?moOgl00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool05ooo
ool00?oooooooooooolBooooo`03o`000?moOgooOgmo00_oOgmo00?o0000ogmoOomoOgl0ROmoOgl0
0ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0G
ooooo`00oooooooooooooa7ooooo00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`29ogmo
O`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo4Oooool00ol0003oOgmoogmoO`0<ogmoO`03o`000?moOgooOgmo08Wo
Ogmo00?o0000ogmoOomoOgl00omoOgl00ol0003oooooooooo`3oooooob[ooooo00?o0000oooooooo
ool05oooool00?ooooooooooool@ooooo`03o`000?moOgooOgmo00goOgmo00?o0000ogmoOomoOgl0
ROmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0?oooooo:_ooool00ol0003ooooo
ooooo`0Gooooo`00oooooooooooooa3ooooo00?o0000ogmoOomoOgl03OmoOgl00ol0003oOgmoogmo
O`29ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0oooooolZooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooo3?ooool2o`WZ2P03o`000?l9jP[o2NX:00So2NX:1omoOgl7
o`0008GoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`3oooooobWooooo00?o0000
ooooooooool05oooool00?ooooooooooool6ooooo`Ko2NX:0_ooool2o`0000WoOgmo4ol9jPX8o`00
07SoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`3oooooobWooooo00?o0000oooo
ooooool05oooool00?ooooooooooool1ooooo`Go2NX:2Oooool00ol0003oOgmoogmoO`0>ogmoO`03
o`000?moOgooOgmo00WoOgmo4_l9jPX3o`0006_oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003o
ooooooooo`3oooooobWooooo00?o0000ooooooooool05oooool00?oooooon_ooool6o`WZ2Pgooooo
00?o0000ogmoOomoOgl03omoOgl00ol0003oOgmoogmoO`0KogmoOa?o2NX:FomoOgl00ol0003oOgmo
ogmoO`05ogmoO`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Gooooo`00oooo
ooodooooo`Ko2NX:4oooool00ol0003oOgmoogmoO`0?ogmoO`03o`000?moOgooOgmo02_oOgmo0ol0
000Co`WZ2TSoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`3oooooobSooooo00?o
0000ooooooooool05oooool00?ooooookoooool5o`WZ2QSooooo00?o0000ogmoOomoOgl04?moOgl0
0ol0003oOgmoogmoO`0gogmoO`[o00004_l9jPXfogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000
ooooooooool0oooooolXooooo`03o`000?oooooooooo01Oooooo003oooooonWooooo1_l9jPXMoooo
o`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomoOgl0A?moOgl=o`0000;oOgmo4ol9jPXSogmo
O`03o`000?moOgooOgmo00KoOgmo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo
01Oooooo003oooooon?ooooo1_l9jPXSooooo`03o`000?moOgooOgmo013oOgmo00?o0000ogmoOomo
Ogl0DOmoOgl<o`0000WoOgmo4_l9jPXAogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000oooooooo
ool0oooooolWooooo`03o`000?oooooooooo01Oooooo003oooooomkooooo1Ol9jPXXooooo`03o`00
0?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0GOmoOgl=o`0000koOgmo4ol9jPX7ogmoO`;o0000
oooooolXooooo`03o`000?oooooooooo01Oooooo003oooooomSooooo1_l9jPX]ooooo`03o`000?mo
OgooOgmo017oOgmo00?o0000ogmoOomoOgl0J_moOgl=o`0001;oOgmo00?o0000ogmoOol9jPX01_l9
jPX01?l0003o2NX:o`WZ2_l9jP[oooooobKooooo00?o0000ooooooooool05oooool00?ooooood_oo
ool6o`WZ2S?ooooo00?o0000ogmoOomoOgl04OmoOgl00ol0003oOgmoogmoO`1gogmoO`go00001Omo
Ogl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo00?o2NX:oooooolSooooo`03o`000?oo
oooooooo01Oooooo003oooooolgooooo1Ol9jPXhooooo`03o`000?moOgooOgmo01;oOgmo00?o0000
ogmoOomoOgl0Q?moOgl6o`0000WoOgmo00?o0000ooooooooool00oooool4o`WZ2_oooooo7oooool0
0ol0003oooooooooo`0Gooooo`00ooooooo7ooooo`Ko2NX:?Oooool00ol0003oOgmoogmoO`0Bogmo
O`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl02?moOgl00ol0003oooooooooo`06oooo
o`Co2NX:oooooolKooooo`03o`000?oooooooooo01Oooooo003ooooool7ooooo1_l9jPY3ooooo`03
o`000?moOgooOgmo01;oOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`08ogmoO`03
o`000?oooooooooo00[ooooo0ol9jP[ooooooaSooooo00?o0000ooooooooool05oooool00?oooooo
^oooool6o`WZ2TSooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`29ogmoO`03o`00
0?moOgooOgmo00SoOgmo00?o0000ooooooooool03Oooool4o`WZ2_oooooo5?ooool00ol0003ooooo
ooooo`0Gooooo`00oooooonfooooo`Go2NX:C_ooool00ol0003oOgmoogmoO`0CogmoO`03o`000?mo
OgooOgmo08WoOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0@ooooo`?o2NX:oooo
oolAooooo`03o`000?oooooooooo01Oooooo003ooooook3ooooo1_l9jPYCooooo`03o`000?moOgoo
Ogmo01?oOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooo
oooo01?ooooo1?l9jP[oooooo`gooooo00?o0000ooooooooool05oooool00?ooooooZ_ooool6o`WZ
2USooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo
00WoOgmo00?o0000ooooooooool05oooool4o`WZ2_oooooo2Oooool00ol0003oooooooooo`0Goooo
o`00oooooonUooooo`Go2NX:G_ooool00ol0003oOgmoogmoO`0DogmoO`03o`000?moOgooOgmo08Wo
Ogmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0Kooooo`?o2NX:ooooool6ooooo`03
o`000?oooooooooo01Oooooo003ooooooioooooo1_l9jPYNooooo`?o2NX:00?o0000o`WZ2_l9jPX0
3?l9jPX:ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl02_moOgl00ol0003ooooo
ooooo`0Mooooo`Co2NX:ooooool2ooooo`03o`000?oooooooooo01Oooooo003ooooooiWooooo1_l9
jPYMooooo`Oo2NX:0oooool3o`0000coOgmo6Ol9jPYmogmoO`03o`000?moOgooOgmo00[oOgmo00?o
0000ooooooooool08Oooool4o`WZ2_gooooo00?o0000ooooooooool05oooool00?ooooooU?ooool5
o`WZ2Ucooooo1ol9jPX;ooooo`03o`000?moOgooOgmo01GoOgmo00?o0000ogmoOomoOgl03?moOglJ
o`WZ2V?oOgmo00?o0000ogmoOomoOgl02_moOgl00ol0003oooooooooo`0Uooooo`?o2NX:n_ooool0
0ol0003oooooooooo`0Gooooo`00oooooon>ooooo`Ko2NX:F_ooool7o`WZ2Q;ooooo00?o0000ogmo
OomoOgl05OmoOgl00ol0003oOgmoogmoO`0VogmoOa[o2NX:BOmoOgl00ol0003oOgmoogmoO`0:ogmo
O`03o`000?oooooooooo02Sooooo1?l9jP[fooooo`03o`000?oooooooooo01Oooooo003oooooohSo
oooo1_l9jPYIooooo`Oo2NX:6Oooool00ol0003oOgmoogmoO`0EogmoO`03o`000?moOgooOgmo043o
Ogmo6Ol9jPX`ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool0;?ooool3o`WZ2_?o
oooo00?o0000ooooooooool05oooool00?ooooooPoooool5o`WZ2USooooo1ol9jPXOooooo`03o`00
0?moOgooOgmo01KoOgmo00?o0000ogmoOomoOgl0FOmoOglJo`WZ2QKoOgmo00?o0000ogmoOomoOgl0
2omoOgl00ol0003oooooooooo`0^ooooo`Co2NX:koooool00ol0003oooooooooo`0Gooooo`00oooo
oommooooo`Ko2NX:EOooool8o`WZ2RKooooo00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmoogmo
O`1cogmoOaWo2NX:2omoOgl00ol0003oooooooooo`0booooo`Co2NX:joooool00ol0003ooooooooo
o`0Gooooo`00oooooomgooooo`Ko2NX:E?ooool7o`WZ2Rkooooo00?o0000ogmoOomoOgl05_moOgl:
o`0008;oOgmo00?o0000ogmoOomoOgl02ol9jPX01?l0003o2NX:o`WZ2_l9jPXeooooo`?o2NX:j?oo
ool00ol0003oooooooooo`0Gooooo`00oooooomaooooo`Ko2NX:Doooool7o`WZ2SCooooo00?o0000
ogmoOomoOgl05omoOgl00ol0003oOgmoogmoO`07ogmoOa7o0000LOmoOgl00ol0003oOgmoogmoO`0;
ogmoO`;o00000_ooool5o`WZ2S?ooooo1?l9jP[Tooooo`03o`000?oooooooooo01Oooooo003ooooo
ofcooooo1Ol9jPYBooooo`Oo2NX:>oooool00ol0003oOgmoogmoO`0GogmoOhgo00003_moOgl00ol0
003oooooooooo`05ooooo`Co2NX:<oooool3o`WZ2^7ooooo00?o0000ooooooooool05oooool00?oo
ooooI_ooool6o`WZ2U3ooooo1ol9jPY2ooooo`03o`000?moOgooOgmo01OoOgmo00?o0000ogmoOomo
Ogl0:_moOglAo`0004koOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`09ooooo`Go
2NX:<Oooool4o`WZ2]gooooo00?o0000ooooooooool05oooool00?ooooooH?ooool6o`WZ2Toooooo
1ol9jPY8ooooo`03o`000?moOgooOgmo01SoOgmo00?o0000ogmoOomoOgl0>omoOglBo`0003coOgmo
00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`0>ooooo`Co2NX:<Oooool4o`WZ2]Wooooo
00?o0000ooooooooool05oooool00?ooooooFoooool5o`WZ2Tkooooo1ol9jPY?ooooo`03o`000?mo
OgooOgmo01SoOgmo00?o0000ogmoOomoOgl0COmoOglAo`0002_oOgmo00?o0000ogmoOomoOgl03?mo
Ogl00ol0003oooooooooo`0Booooo`Go2NX:<?ooool3o`WZ2]Kooooo00?o0000ooooooooool05ooo
ool00?ooooooEOooool6o`WZ2T_ooooo2?l9jPYFooooo`03o`000?moOgooOgmo01SoOgmo00?o0000
ogmoOomoOgl0G_moOglBo`0001WoOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`0G
ooooo`Go2NX:;_ooool4o`WZ2];ooooo00?o0000ooooooooool05oooool00?ooooooCoooool6o`WZ
2T[ooooo1ol9jPYMooooo`03o`000?moOgooOgmo01WoOgmo00?o0000ogmoOomoOgl0L?moOglAo`00
00SoOgmo00?o0000ogmoOomoOgl03OmoOgl00ol0003oooooooooo`0Kooooo`Co2NX:;_ooool3o`WZ
2/oooooo00?o0000ooooooooool05oooool00?ooooooB_ooool5o`WZ2TWooooo1ol9jPYTooooo`03
o`000?moOgooOgmo01WoOgmo00?o0000ogmoOomoOgl0POmoOgl9o`0000ooOgmo00?o0000oooooooo
ool07oooool5o`WZ2Rcooooo1?l9jP[;ooooo`03o`000?oooooooooo01Oooooo003oooooodCooooo
1_l9jPY7ooooo`Oo2NX:Joooool00ol0003oOgmoogmoO`0IogmoO`03o`000?moOgooOgmo08WoOgmo
00?o0000ogmoOomoOgl03OmoOgl00ol0003oooooooooo`0Tooooo`Co2NX:;?ooool4o`WZ2/Oooooo
00?o0000ooooooooool05oooool00?oooooo?_ooool6o`WZ2TKooooo1ol9jPYbooooo`03o`000?mo
OgooOgmo01WoOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0=ogmoO`03o`000?oo
oooooooo02Sooooo1Ol9jPX[ooooo`?o2NX:a?ooool00ol0003oooooooooo`0Gooooo`00ooooooli
ooooo`Go2NX:AOooool7o`WZ2W;ooooo6Ol9jPX:ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000
ogmoOomoOgl03_moOgl00ol0003oooooooooo`0/ooooo`Co2NX::_ooool4o`WZ2/3ooooo00?o0000
ooooooooool05oooool00?oooooo<oooool6o`WZ2T;ooooo2?l9jPY`ooooo`Wo2NX:1Oooool2o`00
01;oOgmo9Ol9jPYaogmoO`03o`000?moOgooOgmo00koOgmo00?o0000ooooooooool0<?ooool5o`WZ
2RWooooo0ol9jPZmooooo`03o`000?oooooooooo01Oooooo003oooooobgooooo1_l9jPY1ooooo`Oo
2NX:K_ooool:o`WZ2Poooooo00?o0000ogmoOomoOgl06_moOgl00ol0003oOgmoogmoO`0HogmoObKo
2NX:BomoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo03Gooooo1?l9jPXXooooo`Co
2NX:^Oooool00ol0003oooooooooo`0Gooooo`00oooooolWooooo`Ko2NX:@?ooool7o`WZ2Vcooooo
2Ol9jPXHooooo`03o`000?moOgooOgmo01_oOgmo00?o0000ogmoOomoOgl0?_moOglVo`WZ2RGoOgmo
00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`0iooooo`Go2NX:9oooool4o`WZ2[Gooooo
00?o0000ooooooooool05oooool00?oooooo8_ooool5o`WZ2Soooooo1ol9jPYYooooo`[o2NX:8Ooo
ool00ol0003oOgmoogmoO`0KogmoO`03o`000?moOgooOgmo06CoOgmo9Ol9jPX00ol0003oOgmoogmo
O`0>ogmoO`03o`000?oooooooooo03kooooo1?l9jPXWooooo`?o2NX:/_ooool00ol0003ooooooooo
o`0Gooooo`00oooooolLooooo`Ko2NX:?Oooool7o`WZ2VKooooo2_l9jPX[ooooo`03o`000?moOgoo
Ogmo01_oOgmo00?o0000ogmoOomoOgl0ROmoOglAo`WZ2P03o`000?l9jP[o2NX:00;o2NX:@?ooool5
o`WZ2RGooooo1?l9jPZ^ooooo`03o`000?oooooooooo01Oooooo003ooooooaKooooo1_l9jPXloooo
o`Oo2NX:I?ooool9o`WZ2SCooooo00?o0000ogmoOomoOgl07?moOgl00ol0003oOgmoogmoO`29ogmo
O`03o`000?moOgooOgmo00koOgmo0_l00003ooooo`Ko2NX:?oooool5o`WZ2RCooooo1?l9jPZZoooo
o`03o`000?oooooooooo01Oooooo003ooooooa7ooooo1Ol9jPXjooooo`So2NX:HOooool:o`WZ2Sgo
oooo00?o0000ogmoOomoOgl07?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo00oo
Ogmo00?o0000ooooooooool01oooool6o`WZ2Skooooo1?l9jPXTooooo`?o2NX:Yoooool00ol0003o
ooooooooo`0Gooooo`00ooooool;ooooo`Ko2NX:>?ooool7o`WZ2V3ooooo2Ol9jPY7ooooo`03o`00
0?moOgooOgmo01coOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`00
0?oooooooooo00gooooo1_l9jPXlooooo`Go2NX:8_ooool4o`WZ2Z?ooooo00?o0000ooooooooool0
5oooool00?oooooo1Oooool6o`WZ2SOooooo1ol9jPYMooooo`[o2NX:Coooool00ol0003oOgmoogmo
O`0MogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003ooooooooo
o`0Booooo`Ko2NX:>oooool4o`WZ2R;ooooo0ol9jPZPooooo`03o`000?oooooooooo01Oooooo003o
ooooo`Go2NX:=_ooool7o`WZ2U_ooooo2Ol9jPYIooooo`03o`000?moOgooOgmo01goOgmo00?o0000
ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo01Sooooo1_l9jPXi
ooooo`Go2NX:8?ooool4o`WZ2Ycooooo00?o0000ooooooooool05oooool00?Wooooo1_l9jPXdoooo
o`Oo2NX:F?ooool:o`WZ2V;ooooo00?o0000ogmoOomoOgl07OmoOgl00ol0003oOgmoogmoO`29ogmo
O`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool07_ooool6o`WZ2SSooooo1?l9jPXPoooo
o`Co2NX:V?ooool00ol0003oooooooooo`0Gooooo`00loooool6o`WZ2S?ooooo1ol9jPYEooooo`[o
2NX:K?ooool00ol0003oOgmoogmoO`0MogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`0Tooooo`Ko2NX:=_ooool5o`WZ2Qoooooo0ol9jPZEooooo`03
o`000?oooooooooo01Oooooo003]ooooo`Ko2NX:<Oooool8o`WZ2U?ooooo2Ol9jPYfooooo`03o`00
0?moOgooOgmo01goOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?oooooooooo02[ooooo1_l9jPXeooooo`Co2NX:7_ooool4o`WZ2Y7ooooo00?o0000ooooooooool0
5oooool00>Sooooo1Ol9jPX`ooooo`Oo2NX:DOooool:o`WZ2Woooooo00?o0000ogmoOomoOgl07Omo
Ogl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0;ooo
ool6o`WZ2S?ooooo1Ol9jPXMooooo`?o2NX:S_ooool00ol0003oooooooooo`0Gooooo`00h_ooool6
o`WZ2Rkooooo1ol9jPY?ooooo`Wo2NX:ROooool00ol0003oOgmoogmoO`0MogmoO`03o`000?moOgoo
Ogmo08WoOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0eooooo`Ko2NX:<_ooool4
o`WZ2Qcooooo1?l9jPZ:ooooo`03o`000?oooooooooo01Oooooo003Looooo`Ko2NX:;Oooool7o`WZ
2Tcooooo2_l9jPZAooooo`03o`000?moOgooOgmo01koOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0
003oOgmoogmoO`0AogmoO`03o`000?oooooooooo03_ooooo1_l9jPX`ooooo`Go2NX:6oooool4o`WZ
2XKooooo00?o0000ooooooooool05oooool00=Oooooo1Ol9jPX/ooooo`Oo2NX:B_ooool9o`WZ2YCo
oooo1_l9jPX00ol0003o2NX:o`WZ2P0Go`WZ2PSoOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003o
OgmoogmoO`0AogmoO`03o`000?oooooooooo047ooooo1_l9jPX_ooooo`Go2NX:6_ooool3o`WZ2X?o
oooo00?o0000ooooooooool05oooool00=7ooooo1_l9jPXZooooo`Oo2NX:Aoooool:o`WZ2Xoooooo
3_l9jPX6ooooo`;o00006?moOglao`WZ2V?oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003ooooo
ooooo`17ooooo`Ko2NX:;_ooool4o`WZ2QWooooo1?l9jPYoooooo`03o`000?oooooooooo01Oooooo
003;ooooo`Ko2NX::Oooool7o`WZ2TCooooo2_l9jPZ:ooooo`oo2NX:5Oooool00ol0003oOgmoogmo
O`0NogmoOa?o00005_moOgl`o`WZ2S?oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003ooooooooo
o`1=ooooo`Ko2NX:;?ooool5o`WZ2QSooooo0ol9jPYlooooo`03o`000?oooooooooo01Oooooo0036
ooooo`Go2NX:9oooool8o`WZ2T;ooooo2Ol9jPZ6ooooo`ko2NX:9?ooool00ol0003oOgmoogmoO`0N
ogmoO`03o`000?moOgooOgmo013oOgmo8ol0000SogmoOc7o2NX:0_moOgl00ol0003oOgmoogmoO`0A
ogmoO`;o0000E?ooool6o`WZ2R_ooooo1?l9jPXGooooo`Co2NX:N?ooool00ol0003oooooooooo`0G
ooooo`00`?ooool6o`WZ2RGooooo1ol9jPY0ooooo`[o2NX:POooool>o`WZ2S;ooooo00?o0000ogmo
OomoOgl07_moOgl00ol0003oOgmoogmoO`0cogmoOb?o0000<OmoOglFo`WZ2P03o`000?l9jP[o2NX:
00Co2NX:EOooool6o`WZ2RWooooo1Ol9jPXFooooo`Co2NX:M?ooool00ol0003oooooooooo`0Goooo
o`00^_ooool6o`WZ2RCooooo1ol9jPXnooooo`Wo2NX:OOooool>o`WZ2T3ooooo00?o0000ogmoOomo
Ogl07_moOgl00ol0003oOgmoogmoO`1FogmoOb?o00004?moOgl00ol0003oOgmoogmoO`0BogmoO`03
o`000?oooooooooo00?ooooo2Ol9jPYBooooo`Ko2NX::?ooool4o`WZ2QKooooo0ol9jPYaooooo`03
o`000?oooooooooo01Oooooo002eooooo`Go2NX:8oooool7o`WZ2S_ooooo2_l9jPYgooooo`oo2NX:
C_ooool00ol0003oOgmoogmoO`0NogmoO`03o`000?moOgooOgmo07WoOgmo4Ol0000DogmoO`03o`00
0?oooooooooo00cooooo2Ol9jPY?ooooo`Ko2NX:9_ooool5o`WZ2QCooooo1?l9jPY]ooooo`03o`00
0?oooooooooo01Oooooo002_ooooo`Ko2NX:8Oooool7o`WZ2SWooooo2Ol9jPYcooooo`ko2NX:GOoo
ool00ol0003oOgmoogmoO`0NogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04_mo
Ogl00ol0003oooooooooo`0Eooooo`Wo2NX:C?ooool6o`WZ2RGooooo1?l9jPXDooooo`Co2NX:JOoo
ool00ol0003oooooooooo`0Gooooo`00ZOooool6o`WZ2R3ooooo1ol9jPXfooooo`[o2NX:K_ooool>
o`WZ2V_ooooo00?o0000ogmoOomoOgl07_moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgoo
Ogmo01;oOgmo00?o0000ooooooooool07_ooool9o`WZ2TWooooo1_l9jPXSooooo`Go2NX:4oooool3
o`WZ2VKooooo00?o0000ooooooooool05oooool00:?ooooo1_l9jPXNooooo`So2NX:<oooool:o`WZ
2VWooooo3ol9jPYhooooo`03o`000?moOgooOgmo01ooOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0
003oOgmoogmoO`0BogmoO`03o`000?oooooooooo02Oooooo2_l9jPY5ooooo`Ko2NX:8_ooool5o`WZ
2Q7ooooo1?l9jPYRooooo`03o`000?oooooooooo01Oooooo002Nooooo`Go2NX:7Oooool7o`WZ2S;o
oooo2Ol9jPYUooooo`ko2NX:Qoooool00ol0003oOgmoogmoO`0OogmoO`03o`000?moOgooOgmo08Wo
Ogmo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`0aooooo`Wo2NX:@_ooool6o`WZ2R7o
oooo1?l9jPXAooooo`?o2NX:Goooool00ol0003oooooooooo`0Gooooo`00V?ooool6o`WZ2Q_ooooo
1ol9jPX_ooooo`[o2NX:H?ooool>o`WZ2YGooooo00?o0000ogmoOomoOgl07omoOgl00ol0003oOgmo
ogmoO`29ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool0>_ooool9o`WZ2Soooooo
1_l9jPXOooooo`Go2NX:3oooool4o`WZ2U_ooooo00?o0000ooooooooool05oooool009;ooooo1_l9
jPXJooooo`Oo2NX:;Oooool9o`WZ2Ucooooo3_l9jPZSooooo`03o`000?moOgooOgmo01ooOgmo00?o
0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooooooo04?ooooo2Ol9
jPXlooooo`Ko2NX:7_ooool4o`WZ2Poooooo1?l9jPYGooooo`03o`000?oooooooooo01Oooooo002=
ooooo`Go2NX:6Oooool7o`WZ2R[ooooo2_l9jPYFooooo`oo2NX:/Oooool00ol0003oOgmoogmoO`0O
ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`1<
ooooo`Wo2NX:>Oooool6o`WZ2Qcooooo1Ol9jPX>ooooo`?o2NX:E?ooool00ol0003oooooooooo`0G
ooooo`00Qoooool6o`WZ2QOooooo1ol9jPXXooooo`Wo2NX:D_ooool>o`WZ2/3ooooo00?o0000ogmo
OomoOgl07omoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000oooo
ooooool0EOooool:o`WZ2SGooooo1_l9jPXKooooo`Co2NX:3Oooool4o`WZ2U3ooooo00?o0000oooo
ooooool05oooool0087ooooo1_l9jPXEooooo`So2NX:9Oooool:o`WZ2Tgooooo3_l9jP[>ooooo`03
o`000?moOgooOgmo01ooOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0BogmoO`03
o`000?oooooooooo05oooooo2Ol9jPXbooooo`Ko2NX:6Oooool5o`WZ2Pcooooo0ol9jPY=ooooo`03
o`000?oooooooooo01Oooooo001looooo`Go2NX:5?ooool7o`WZ2R?ooooo2_l9jPY9ooooo`ko2NX:
g?ooool00ol0003oOgmoogmoO`0OogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl0
4_moOgl00ol0003oooooooooo`1Xooooo`Wo2NX:;oooool6o`WZ2QSooooo1?l9jPX;ooooo`Co2NX:
BOooool00ol0003oooooooooo`0Gooooo`00M_ooool6o`WZ2Q;ooooo1ol9jPXQooooo`Wo2NX:A?oo
ool?o`WZ2^Sooooo0ol0000QogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omo
Ogl00ol0003oooooooooo`1`ooooo`Wo2NX:;?ooool6o`WZ2QKooooo1Ol9jPX:ooooo`Co2NX:AOoo
ool00ol0003oooooooooo`0Gooooo`00L?ooool6o`WZ2Q7ooooo1ol9jPXNooooo`[o2NX:?oooool>
o`WZ2^Wooooo3_l9jPX00ol0003o2NX:o`WZ2P1Ro`WZ2T_oOgmo00?o0000ogmoOomoOgl04omoOgl0
0ol0003oooooooooo`1iooooo`Wo2NX::Oooool6o`WZ2QGooooo1?l9jPX:ooooo`?o2NX:@_ooool0
0ol0003oooooooooo`0Gooooo`00Joooool5o`WZ2Q3ooooo1ol9jPXLooooo`Wo2NX:>oooool>o`WZ
2]Wooooo7_l9jPX@ooooo`03o`000?moOgooOgmo01ooOgmo00?o0000ogmoOomoOgl0?_moOgm[o`WZ
2W_ooooo2_l9jPXUooooo`Ko2NX:4oooool5o`WZ2PSooooo1?l9jPXnooooo`03o`000?oooooooooo
01Oooooo001Uooooo`Ko2NX:3_ooool7o`WZ2QWooooo2_l9jPXfooooo`ko2NX:bOoooolNo`WZ2Rgo
oooo00?o0000ogmoOomoOgl08?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01?o
Ogmo0_l00008oooooa;o2NX:Loooool9o`WZ2R;ooooo1_l9jPXBooooo`Go2NX:1oooool3o`WZ2S_o
oooo00?o0000ooooooooool05oooool005oooooo1_l9jPX<ooooo`So2NX:5oooool9o`WZ2S7ooooo
3ol9jPZhoooooaoo2NX:Boooool00ol0003oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo
00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`0Ioooooa7o2NX:Joooool9o`WZ2Qoooooo
1_l9jPXAooooo`Co2NX:1_ooool4o`WZ2SOooooo00?o0000ooooooooool05oooool005Wooooo1_l9
jPX;ooooo`Oo2NX:5Oooool:o`WZ2Rcooooo3_l9jPZYoooooako2NX:J_ooool00ol0003oOgmoogmo
O`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003ooooooooo
o`0Zoooooa;o2NX:H_ooool9o`WZ2Qcooooo1_l9jPX?ooooo`Go2NX:1Oooool4o`WZ2S?ooooo00?o
0000ooooooooool05oooool005Cooooo1Ol9jPX:ooooo`Oo2NX:4_ooool:o`WZ2RSooooo3_l9jPZI
oooooako2NX:R?ooool00ol0003oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000
ogmoOomoOgl04omoOgl00ol0003oooooooooo`0loooooa;o2NX:FOooool9o`WZ2QWooooo1_l9jPX>
ooooo`Co2NX:1Oooool3o`WZ2S3ooooo00?o0000ooooooooool05oooool004kooooo1_l9jPX8oooo
o`Oo2NX:4?ooool9o`WZ2RCooooo3_l9jPZ9oooooako2NX:Y_ooool00ol0003oOgmoogmoO`0Pogmo
O`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1>oooo
oa;o2NX:D?ooool9o`WZ2QKooooo1_l9jPX<ooooo`Go2NX:0oooool4o`WZ2Rcooooo00?o0000oooo
ooooool05oooool004Sooooo1_l9jPX7ooooo`Oo2NX:3Oooool:o`WZ2Qkooooo3ol9jPYioooooako
2NX:a?ooool00ol0003oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomo
Ogl04omoOgl00ol0003oooooooooo`1Poooooa7o2NX:B?ooool:o`WZ2Q;ooooo1_l9jPX;ooooo`Co
2NX:0oooool3o`WZ2RWooooo00?o0000ooooooooool05oooool004?ooooo1Ol9jPX6ooooo`Oo2NX:
2oooool9o`WZ2Q[ooooo3_l9jPYYoooooaoo2NX:h_ooool00ol0003oOgmoogmoO`0PogmoO`03o`00
0?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1aoooooa;o2NX:
@?ooool9o`WZ2Poooooo1_l9jPX9ooooo`Go2NX:00?oooooo`WZ2_l9jPX00_l9jPXUooooo`03o`00
0?oooooooooo01Oooooo000mooooo`Ko2NX:1?ooool7o`WZ2PSooooo2_l9jPXEooooo`ko2NX:FOoo
oolNo`WZ2_oooooo0_ooool00ol0003oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o
0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`23oooooa;o2NX:=oooool9o`WZ2Pcooooo1_l9
jPX8ooooo`Co2NX:00?oooooo`WZ2_l9jPX00_l9jPXQooooo`03o`000?oooooooooo01Oooooo000g
ooooo`Ko2NX:0_ooool8o`WZ2PKooooo2Ol9jPX@ooooo`oo2NX:BOoooolNo`WZ2_oooooo8?ooool0
0ol0003oOgmoogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl0
0ol0003oooooooooo`2Eoooooa;o2NX:;_ooool9o`WZ2PWooooo1_l9jPX6ooooo`So2NX:7_ooool0
0ol0003oooooooooo`0Gooooo`00<_ooool5o`WZ2P03ooooool9jP[o2NX:00Go2NX:1?ooool:o`WZ
2P_ooooo3_l9jPXjoooooako2NX:oooooolnooooo`03o`000?moOgooOgmo023oOgmo00?o0000ogmo
OomoOgl0ROmoOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo0:Kooooo4Ol9jPXVoooo
o`Wo2NX:1_ooool6o`WZ2PGooooo1ol9jPXJooooo`03o`000?oooooooooo01Oooooo000/ooooo`co
2NX:00?oooooo`WZ2_l9jPX02?l9jPX7ooooo`ko2NX::_oooolNo`WZ2_ooooooFoooool00ol0003o
OgmoogmoO`0QogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl05?moOgl00ol0003o
ooooooooo`2goooooa;o2NX:7Oooool:o`WZ2P;ooooo1_l9jPX3ooooo`Oo2NX:5_ooool00ol0003o
ooooooooo`0Gooooo`009_oooolCo`WZ2P?ooooo3_l9jPXIoooooaoo2NX:oooooomiooooo`03o`00
0?moOgooOgmo027oOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0DogmoO`03o`00
0?oooooooooo0<Wooooo4_l9jPXEooooo`ko2NX:0_ooool5o`WZ2Q?ooooo00?o0000ooooooooool0
5oooool0027ooooo6ol9jPX9oooooako2NX:oooooonHooooo`03o`000?moOgooOgmo027oOgmo00?o
0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo0=_ooooo4_l9
jPX<ooooo`_o2NX:00?oooooo`WZ2_l9jPX00_l9jPX=ooooo`;o2NX:0_l0000Hooooo`006ooooolZ
o`WZ2_oooooo]_ooool00ol0003oOgmoogmoO`0QogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000
ogmoOomoOgl05?moOgl00ol0003oooooooooo`3]oooooa7o2NX:1?ooool<o`WZ2PGooooo1Ol9jPX2
o`0001Sooooo000Hoooooooo2NX:ool9jPZZo`WZ2P03o`000?l9jP[o2NX:0?oo2NX:6_l9jPX2o`00
01Sooooo000LooooobSo2NX:oooooongooooo`;o00008_moOgl00ol0003oOgmoogmoO`29ogmoO`03
o`000?moOgooOgmo01?oOgmo0_l0003ooooooa_o2NX:0_l0000Hooooo`008OoooolLo`WZ2POooooo
7?l9jP[ooooooi_ooooo00?o0000ogmoOomoOgl08OmoOgl00ol0003oOgmoogmoO`29ogmoO`03o`00
0?moOgooOgmo01CoOgmo00?o0000ooooooooool0k?oooolFo`WZ2P03ooooool9jP[o2NX:00So2NX:
1oooool4o`WZ2P;o00006?ooool002Oooooo4ol9jPX3ooooo`ko2NX:5OoooolLo`WZ2_ooooooOooo
ool00ol0003oOgmoogmoO`0QogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl05?mo
Ogl00ol0003oooooooooo`3Joooooa;o2NX:1?ooool9o`WZ2PCooooo1_l9jPX00ooooooo2NX:o`WZ
2P02o`WZ2Poooooo00?o2NX:o`000?l000006?ooool002gooooo3?l9jPX00ooooooo2NX:o`WZ2P07
o`WZ2PSooooo3_l9jPXSoooooago2NX:oooooomRooooo`03o`000?moOgooOgmo027oOgmo00?o0000
ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo0<Sooooo4_l9jPX=
ooooo`Wo2NX:1oooool6o`WZ2P;ooooo1Ol9jPXDooooo`03o`000?oooooooooo01Oooooo000boooo
o`Ko2NX:00?oooooo`WZ2_l9jPX01Ol9jPX3ooooo`[o2NX:3?ooool>o`WZ2S;ooooo7?l9jP[ooooo
odKooooo00?o0000ogmoOomoOgl08OmoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo
01CoOgmo00?o0000ooooooooool0]_oooolBo`WZ2QKooooo2Ol9jPX:ooooo`Ko2NX:0oooool7o`WZ
2QOooooo00?o0000ooooooooool05oooool003Sooooo1_l9jPX2ooooo`Oo2NX:1_ooool9o`WZ2Q7o
oooo3ol9jPXooooooago2NX:oooooolZooooo`03o`000?moOgooOgmo023oOgmo00?o0000ogmoOomo
Ogl0ROmoOgl00ol0003oOgmoogmoO`0DogmoO`03o`000?oooooooooo0:Gooooo4Ol9jPXOooooo`Wo
2NX:3Oooool6o`WZ2PGooooo1ol9jPXKooooo`03o`000?oooooooooo01Oooooo000nooooo`Go2NX:
1?ooool7o`WZ2PSooooo2Ol9jPXGooooo`ko2NX:C_oooolLo`WZ2_oooooo3_ooool00ol0003oOgmo
ogmoO`0PogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003ooooo
ooooo`2Doooooa;o2NX:9oooool9o`WZ2Q3ooooo1_l9jPX6ooooo`So2NX:7oooool00ol0003ooooo
ooooo`0Gooooo`00@oooool6o`WZ2PGooooo1ol9jPX:ooooo`[o2NX:6oooool>o`WZ2Ucooooo7Ol9
jP[`ooooo`03o`000?moOgooOgmo023oOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmo
O`0CogmoO`03o`000?oooooooooo08;ooooo4_l9jPX`ooooo`Wo2NX:4oooool6o`WZ2PSooooo1?l9
jPX00ooooooo2NX:o`WZ2P02o`WZ2R;ooooo00?o0000ooooooooool05oooool004Wooooo1Ol9jPX7
ooooo`Oo2NX:3Oooool9o`WZ2R3ooooo3ol9jPYZoooooaco2NX:e?ooool00ol0003oOgmoogmoO`0P
ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1`
oooooa;o2NX:>Oooool9o`WZ2QKooooo1_l9jPX9ooooo`Go2NX:00?oooooo`WZ2_l9jPX00_l9jPXV
ooooo`03o`000?oooooooooo01Oooooo001>ooooo`Ko2NX:2?ooool7o`WZ2Poooooo2_l9jPXUoooo
o`ko2NX:N?oooolLo`WZ2[Sooooo00?o0000ogmoOomoOgl08?moOgl00ol0003oOgmoogmoO`29ogmo
O`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool0GooooolAo`WZ2T?ooooo2?l9jPXIoooo
o`Ko2NX:2oooool4o`WZ2P?ooooo0ol9jPXZooooo`03o`000?oooooooooo01Oooooo001Dooooo`Ko
2NX:2Oooool7o`WZ2Q;ooooo2Ol9jPXZooooo`ko2NX:Q_oooolMo`WZ2Y_ooooo00?o0000ogmoOomo
Ogl08?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000oooooooo
ool0COoooolBo`WZ2T_ooooo2Ol9jPXKooooo`Ko2NX:3?ooool5o`WZ2P?ooooo1?l9jPX]ooooo`03
o`000?oooooooooo01Oooooo001Jooooo`Go2NX:2oooool7o`WZ2QCooooo2Ol9jPX_ooooo`ko2NX:
UOoooolLo`WZ2Woooooo00?o0000ogmoOomoOgl08?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`00
0?moOgooOgmo01?oOgmo00?o0000ooooooooool0>ooooolBo`WZ2UCooooo2Ol9jPXNooooo`Ko2NX:
3_ooool4o`WZ2PGooooo0ol9jPXaooooo`03o`000?oooooooooo01Oooooo001Oooooo`Ko2NX:3?oo
ool7o`WZ2QKooooo2_l9jPXcooooo`oo2NX:X_oooolMo`WZ2V;ooooo00?o0000ogmoOomoOgl08?mo
Ogl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01?oOgmo00?o0000ooooooooool0:Ooo
oolBo`WZ2Ugooooo2Ol9jPXQooooo`Ko2NX:3oooool5o`WZ2PGooooo1?l9jPXdooooo`03o`000?oo
oooooooo01Oooooo001Uooooo`Ko2NX:3Oooool7o`WZ2QWooooo2Ol9jPXiooooo`ko2NX:/OoooolL
o`WZ2TKooooo00?o0000ogmoOomoOgl08?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgoo
Ogmo01?oOgmo00?o0000ooooooooool06?oooolAo`WZ2VKooooo2Ol9jPXTooooo`Ko2NX:4Oooool4
o`WZ2PKooooo1?l9jPXhooooo`03o`000?oooooooooo01Oooooo001[ooooo`Go2NX:3oooool7o`WZ
2Q_ooooo2Ol9jPXnooooo`ko2NX:_ooooolLo`WZ2R[ooooo00?o0000ogmoOomoOgl08?moOgl00ol0
003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01?oOgmo0_l00007oooooa;o2NX:K_ooool9o`WZ
2ROooooo1_l9jPXBooooo`Go2NX:1oooool3o`WZ2Scooooo00?o0000ooooooooool05oooool0073o
oooo1_l9jPX@ooooo`Oo2NX:7Oooool:o`WZ2T;ooooo3_l9jP[=oooooago2NX:3Oooool00ol0003o
OgmoogmoO`0PogmoO`03o`000?moOgooOgmo03goOgmoJol9jPYgooooo`Wo2NX::_ooool6o`WZ2Q?o
oooo1Ol9jPX8ooooo`Co2NX:?oooool00ol0003oooooooooo`0Gooooo`00M_ooool6o`WZ2Q7ooooo
2?l9jPXOooooo`Wo2NX:Aoooool?o`WZ2]_ooooo3?l9jPX00ol0003o2NX:o`WZ2P1Qo`WZ2TcoOgmo
00?o0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1dooooo`Wo2NX:;Oooool6o`WZ2QGooooo
1?l9jPX:ooooo`?o2NX:@oooool00ol0003oooooooooo`0Gooooo`00O?ooool5o`WZ2QCooooo1ol9
jPXQooooo`[o2NX:C?ooool>o`WZ2]Wooooo0ol0000QogmoO`03o`000?moOgooOgmo08WoOgmo00?o
0000ogmoOomoOgl04omoOgl00ol0003oooooooooo`1[ooooo`Wo2NX:<?ooool6o`WZ2QKooooo1Ol9
jPX:ooooo`Co2NX:A_ooool00ol0003oooooooooo`0Gooooo`00POooool6o`WZ2QGooooo1ol9jPXT
ooooo`Wo2NX:DOooool>o`WZ2/gooooo00?o0000ogmoOomoOgl07omoOgl00ol0003oOgmoogmoO`29
ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool0Hoooool9o`WZ2S?ooooo1_l9jPXH
ooooo`Co2NX:2oooool4o`WZ2T[ooooo00?o0000ooooooooool05oooool008Oooooo1Ol9jPXGoooo
o`Oo2NX:9_ooool9o`WZ2UKooooo3_l9jPZoooooo`03o`000?moOgooOgmo01ooOgmo00?o0000ogmo
OomoOgl0ROmoOgl00ol0003oOgmoogmoO`0BogmoO`03o`000?oooooooooo05_ooooo2?l9jPXfoooo
o`Ko2NX:6Oooool5o`WZ2Pcooooo0ol9jPY>ooooo`03o`000?oooooooooo01Oooooo002<ooooo`Ko
2NX:6?ooool7o`WZ2RSooooo2_l9jPYJooooo`oo2NX:/?ooool00ol0003oOgmoogmoO`0OogmoO`03
o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`1Booooo`Wo
2NX:>?ooool6o`WZ2Q_ooooo1?l9jPX=ooooo`Co2NX:DOooool00ol0003oooooooooo`0Gooooo`00
T_ooool6o`WZ2QWooooo1ol9jPX[ooooo`Wo2NX:H?ooool>o`WZ2Z;ooooo00?o0000ogmoOomoOgl0
7omoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool0
BOooool9o`WZ2S_ooooo1_l9jPXLooooo`Go2NX:3_ooool3o`WZ2UGooooo00?o0000ooooooooool0
5oooool009Sooooo1Ol9jPXKooooo`Oo2NX:;Oooool:o`WZ2VCooooo3_l9jPZDooooo`03o`000?mo
OgooOgmo01ooOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0BogmoO`03o`000?oo
oooooooo043ooooo2Ol9jPXnooooo`Ko2NX:7_ooool4o`WZ2Poooooo1?l9jPYHooooo`03o`000?oo
oooooooo01Oooooo002Mooooo`Ko2NX:7?ooool7o`WZ2S3ooooo2Ol9jPYYooooo`ko2NX:Q_ooool0
0ol0003oOgmoogmoO`0OogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04_moOgl0
0ol0003oooooooooo`0gooooo`Wo2NX:@Oooool6o`WZ2Qoooooo1Ol9jPX?ooooo`Co2NX:G?ooool0
0ol0003oooooooooo`0Gooooo`00Xoooool6o`WZ2Qgooooo1ol9jPXbooooo`Wo2NX:K_ooool?o`WZ
2WOooooo00?o0000ogmoOomoOgl07omoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo
01;oOgmo00?o0000ooooooooool0;_ooool9o`WZ2TCooooo1_l9jPXQooooo`Co2NX:4Oooool3o`WZ
2V3ooooo00?o0000ooooooooool05oooool00:Wooooo1Ol9jPXOooooo`Oo2NX:=?ooool:o`WZ2W?o
oooo3_l9jPYYooooo`03o`000?moOgooOgmo01ooOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003o
OgmoogmoO`0BogmoO`03o`000?oooooooooo02Gooooo2Ol9jPY7ooooo`Ko2NX:8_ooool5o`WZ2Q7o
oooo1?l9jPYSooooo`03o`000?oooooooooo01Oooooo002^ooooo`Ko2NX:8?ooool7o`WZ2SOooooo
2Ol9jPYhooooo`ko2NX:G?ooool00ol0003oOgmoogmoO`0NogmoO`03o`000?moOgooOgmo08WoOgmo
00?o0000ogmoOomoOgl04_moOgl00ol0003oooooooooo`0Looooo`Wo2NX:B_ooool6o`WZ2R?ooooo
1Ol9jPXCooooo`?o2NX:Ioooool00ol0003oooooooooo`0Gooooo`00]?ooool5o`WZ2R;ooooo1ol9
jPXiooooo`Wo2NX:OOooool?o`WZ2Tgooooo00?o0000ogmoOomoOgl07_moOgl00ol0003oOgmoogmo
O`29ogmoO`03o`000?moOgooOgmo01;oOgmo00?o0000ooooooooool04oooool9o`WZ2Tgooooo1_l9
jPXUooooo`Co2NX:5?ooool4o`WZ2V[ooooo00?o0000ooooooooool05oooool00;Wooooo1_l9jPXS
ooooo`Oo2NX:>oooool:o`WZ2X;ooooo3_l9jPXoooooo`03o`000?moOgooOgmo01koOgmo00?o0000
ogmoOomoOgl0N?moOglBo`0001CoOgmo00?o0000ooooooooool02_ooool9o`WZ2U3ooooo1_l9jPXV
ooooo`Go2NX:5?ooool4o`WZ2Vkooooo00?o0000ooooooooool05oooool00;oooooo1_l9jPXToooo
o`Oo2NX:?_ooool9o`WZ2XOooooo3_l9jPXaooooo`03o`000?moOgooOgmo01koOgmo00?o0000ogmo
OomoOgl0EOmoOglSo`00017oOgmo00?o0000ogmoOomoOgl04_moOgl01?l0003oooooooooooooool9
o`WZ2U?ooooo1_l9jPXXooooo`Co2NX:5_ooool3o`WZ2W;ooooo00?o0000ooooooooool05oooool0
0<Gooooo1Ol9jPXVooooo`Oo2NX:@?ooool:o`WZ2X_ooooo3_l9jPXSooooo`03o`000?moOgooOgmo
01koOgmo00?o0000ogmoOomoOgl0<_moOglSo`0002WoOgmo7ol9jPX00ol0003o2NX:o`WZ2P02o`WZ
2UKooooo1_l9jPXYooooo`Go2NX:5_ooool4o`WZ2WGooooo00?o0000ooooooooool05oooool00<[o
oooo1_l9jPXWooooo`Oo2NX:@oooool9o`WZ2Y3ooooo3ol9jPXDooooo`03o`000?moOgooOgmo01ko
Ogmo00?o0000ogmoOomoOgl03omoOglSo`0000_oOgmo@Ol9jPX;ogmoO`03o`000?moOgooOgmo017o
Ogmo0_l0001Cooooo`Ko2NX::oooool4o`WZ2QOooooo1?l9jPYiooooo`03o`000?oooooooooo01Oo
oooo003@ooooo`Ko2NX::?ooool7o`WZ2TGooooo2Ol9jPZFooooo`ko2NX:1_ooool00ol0003oOgmo
ogmoO`0MogmoOd7o2NX:C?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo04cooooo
1_l9jPX/ooooo`Go2NX:6?ooool3o`WZ2Wgooooo00?o0000ooooooooool05oooool00=Kooooo1Ol9
jPXZooooo`Oo2NX:Aoooool:o`WZ2Y[ooooo1Ol9jPX00ol0003o2NX:o`WZ2P0No`WZ2P03ogmoOol0
003oOgmo08[oOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`16ooooo`Ko2NX:;_oo
ool4o`WZ2QWooooo1?l9jPZ0ooooo`03o`000?oooooooooo01Oooooo003Kooooo`Ko2NX::oooool8
o`WZ2TWooooo2Ol9jPZFooooo`;o00008?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgoo
Ogmo017oOgmo00?o0000ooooooooool0@?ooool6o`WZ2Roooooo1Ol9jPXJooooo`?o2NX:Q?ooool0
0ol0003oooooooooo`0Gooooo`00hOooool5o`WZ2Rkooooo1ol9jPY;ooooo`[o2NX:SOooool00ol0
003oOgmoogmoO`0NogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0
003oooooooooo`0jooooo`Ko2NX:<?ooool5o`WZ2Q_ooooo1?l9jPZ7ooooo`03o`000?oooooooooo
01Oooooo003Vooooo`Ko2NX:;oooool7o`WZ2Tkooooo2Ol9jPZ4ooooo`03o`000?moOgooOgmo01ko
Ogmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo03Co
oooo1_l9jPXbooooo`Co2NX:7?ooool4o`WZ2X_ooooo00?o0000ooooooooool05oooool00>cooooo
1_l9jPX`ooooo`Oo2NX:D?ooool9o`WZ2Wcooooo00?o0000ogmoOomoOgl07OmoOgl00ol0003oOgmo
ogmoO`29ogmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0;_ooool6o`WZ2S?ooooo
1Ol9jPXMooooo`?o2NX:Soooool00ol0003oooooooooo`0Gooooo`00l_ooool5o`WZ2S;ooooo1ol9
jPYBooooo`[o2NX:L_ooool00ol0003oOgmoogmoO`0MogmoO`03o`000?moOgooOgmo08WoOgmo00?o
0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`0Xooooo`Ko2NX:=Oooool4o`WZ2Qkooooo1?l9
jPZBooooo`03o`000?oooooooooo01Oooooo003gooooo`Ko2NX:<oooool7o`WZ2UGooooo2Ol9jPYY
ooooo`03o`000?moOgooOgmo01goOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0@
ogmoO`03o`000?oooooooooo02?ooooo1_l9jPXfooooo`Go2NX:7oooool3o`WZ2YKooooo00?o0000
ooooooooool05oooool00?gooooo1_l9jPXdooooo`Oo2NX:Eoooool9o`WZ2V3ooooo00?o0000ogmo
OomoOgl07OmoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000oooo
ooooool07Oooool6o`WZ2SSooooo1?l9jPXPooooo`Co2NX:VOooool00ol0003oooooooooo`0Goooo
o`00ooooool4ooooo`Go2NX:=_ooool7o`WZ2UWooooo2_l9jPYFooooo`03o`000?moOgooOgmo01go
Ogmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo01Oo
oooo1_l9jPXiooooo`Go2NX:8?ooool4o`WZ2Ygooooo00?o0000ooooooooool05oooool00?oooooo
2Oooool6o`WZ2SOooooo1ol9jPYLooooo`Wo2NX:COooool00ol0003oOgmoogmoO`0MogmoO`03o`00
0?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`0Aooooo`Ko2NX:
>oooool4o`WZ2R;ooooo0ol9jPZQooooo`03o`000?oooooooooo01Oooooo003oooooo`oooooo1_l9
jPXhooooo`Oo2NX:G_ooool:o`WZ2T?ooooo00?o0000ogmoOomoOgl07OmoOgl00ol0003oOgmoogmo
O`29ogmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool02oooool6o`WZ2Scooooo1Ol9
jPXRooooo`Co2NX:Y?ooool00ol0003oooooooooo`0Gooooo`00oooooolEooooo`Go2NX:>_ooool7
o`WZ2V7ooooo2Ol9jPXkooooo`03o`000?moOgooOgmo01coOgmo00?o0000ogmoOomoOgl0ROmoOgl0
0ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo00Kooooo1_l9jPXnooooo`Co2NX:9?ooool3
o`WZ2ZSooooo00?o0000ooooooooool05oooool00?oooooo6_ooool6o`WZ2S_ooooo1ol9jPYSoooo
o`Wo2NX:<_ooool00ol0003oOgmoogmoO`0LogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmo
OomoOgl03_moOgl2o`0000;ooooo1_l9jPXoooooo`Go2NX:9?ooool4o`WZ2Z_ooooo00?o0000oooo
ooooool05oooool00?oooooo8?ooool5o`WZ2Sgooooo1ol9jPYUooooo`[o2NX::?ooool00ol0003o
OgmoogmoO`0LogmoO`03o`000?moOgooOgmo08SoOgmo4_l9jPX01?l0003o2NX:o`WZ2_l9jPY0oooo
o`Go2NX:9Oooool4o`WZ2Zoooooo00?o0000ooooooooool05oooool00?oooooo9Oooool6o`WZ2Sko
oooo1ol9jPYXooooo`Wo2NX:8?ooool00ol0003oOgmoogmoO`0KogmoO`03o`000?moOgooOgmo06?o
Ogmo9Ol9jPX00omoOgoo0000ogmoO`0@ogmoO`03o`000?oooooooooo03cooooo1?l9jPXWooooo`?o
2NX:/oooool00ol0003oooooooooo`0Gooooo`00ooooool[ooooo`Ko2NX:?oooool7o`WZ2V[ooooo
2_l9jPXFooooo`03o`000?moOgooOgmo01_oOgmo00?o0000ogmoOomoOgl0?OmoOglVo`WZ2RKoOgmo
00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`0hooooo`Go2NX:9oooool4o`WZ2[Kooooo
00?o0000ooooooooool05oooool00?oooooo<Oooool5o`WZ2T7ooooo1ol9jPY]ooooo`Wo2NX:3Ooo
ool00ol0003oOgmoogmoO`0KogmoO`03o`000?moOgooOgmo01OoOgmo9_l9jPY<ogmoO`03o`000?mo
OgooOgmo00koOgmo00?o0000ooooooooool0=?ooool4o`WZ2RSooooo1?l9jPZjooooo`03o`000?oo
oooooooo01Oooooo003oooooocKooooo1_l9jPY2ooooo`Oo2NX:Koooool9o`WZ2PCooooo0_l0000A
ogmoObGo2NX:L_moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo02oooooo1Ol9jPXY
ooooo`?o2NX:__ooool00ol0003oooooooooo`0Gooooo`00oooooollooooo`Ko2NX:@oooool8o`WZ
2W3ooooo5ol9jPX;ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl03_moOgl00ol0
003oooooooooo`0[ooooo`Co2NX::_ooool4o`WZ2/7ooooo00?o0000ooooooooool05oooool00?oo
oooo@_ooool5o`WZ2TKooooo1ol9jPY^ooooo`03o`000?moOgooOgmo01[oOgmo00?o0000ogmoOomo
Ogl0ROmoOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo02Kooooo1Ol9jPX[ooooo`?o
2NX:aOooool00ol0003oooooooooo`0Gooooo`00oooooom7ooooo`Ko2NX:Aoooool7o`WZ2VSooooo
00?o0000ogmoOomoOgl06OmoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo00goOgmo
00?o0000ooooooooool08oooool4o`WZ2Rcooooo1?l9jP[8ooooo`03o`000?oooooooooo01Oooooo
003oooooodgooooo1Ol9jPY9ooooo`Oo2NX:HOooool00ol0003oOgmoogmoO`0IogmoO`03o`000?mo
OgooOgmo083oOgmo2_l0000?ogmoO`03o`000?oooooooooo01kooooo1Ol9jPX/ooooo`Co2NX:c?oo
ool00ol0003oooooooooo`0Gooooo`00oooooomBooooo`Ko2NX:B_ooool7o`WZ2U[ooooo00?o0000
ogmoOomoOgl06OmoOgl00ol0003oOgmoogmoO`1_ogmoOa7o00002OmoOgl00ol0003oOgmoogmoO`0=
ogmoO`03o`000?oooooooooo01[ooooo1?l9jPX^ooooo`?o2NX:d?ooool00ol0003oooooooooo`0G
ooooo`00oooooomHooooo`Ko2NX:Boooool7o`WZ2U?ooooo00?o0000ogmoOomoOgl06OmoOgl00ol0
003oOgmoogmoO`1MogmoOa;o00006_moOgl00ol0003oOgmoogmoO`0=ogmoO`03o`000?oooooooooo
01Gooooo1Ol9jPX^ooooo`Co2NX:doooool00ol0003oooooooooo`0Gooooo`00oooooomNooooo`Go
2NX:COooool7o`WZ2Tgooooo00?o0000ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`1<ogmoOa7o
0000;?moOgl00ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo017ooooo1Ol9jPX`ooooo`?o
2NX:eoooool00ol0003oooooooooo`0Gooooo`00oooooomSooooo`Ko2NX:C_ooool7o`WZ2TKooooo
00?o0000ogmoOomoOgl06?moOgl00ol0003oOgmoogmoO`0jogmoOa;o0000?OmoOgl00ol0003oOgmo
ogmoO`0<ogmoO`03o`000?oooooooooo00gooooo1?l9jPXaooooo`Co2NX:f_ooool00ol0003ooooo
ooooo`0Gooooo`00oooooomYooooo`Ko2NX:Coooool7o`WZ2Soooooo00?o0000ogmoOomoOgl06?mo
Ogn=o`0000koOgmo00?o0000ooooooooool02?ooool5o`WZ2S7ooooo1?l9jP[Nooooo`03o`000?oo
oooooooo01Oooooo003oooooofoooooo1Ol9jPYAooooo`Oo2NX:>Oooool00ol0003oOgmoogmoO`0G
ogmoO`03o`000?moOgooOgmo01OoOgmo4_l0001PogmoO`03o`000?moOgooOgmo00coOgmo00?o0000
ooooooooool01?ooool4o`WZ2S?ooooo0ol9jP[Rooooo`03o`000?oooooooooo01Oooooo003ooooo
ogCooooo1_l9jPYBooooo`Oo2NX:<_ooool00ol0003oOgmoogmoO`0GogmoO`03o`000?moOgooOgmo
00KoOgmo4Ol0001bogmoO`03o`000?moOgooOgmo00coOgmo00?o0000ooooool9jPX01?l9jPXcoooo
o`Co2NX:iOooool00ol0003oooooooooo`0Gooooo`00oooooomjooooo`Go2NX:E?ooool7o`WZ2R_o
oooo00?o0000ogmoOomoOgl05omoOgl9o`0008?oOgmo00?o0000ogmoOol9jPX02ol9jPX00ol0003o
2NX:o`WZ2P0eooooo`?o2NX:jOooool00ol0003oooooooooo`0Gooooo`00oooooomoooooo`Ko2NX:
EOooool7o`WZ2RGooooo00?o0000ogmoOomoOgl05_moOgl00ol0003oOgmoogmoO`1bogmoOaWo2NX:
3?moOgl2o`0003;ooooo1?l9jP[/ooooo`03o`000?oooooooooo01Oooooo003oooooohGooooo1_l9
jPYFooooo`Oo2NX:7_ooool00ol0003oOgmoogmoO`0FogmoO`03o`000?moOgooOgmo05SoOgmo6_l9
jPXGogmoO`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool0;Oooool4o`WZ2_3ooooo00?o
0000ooooooooool05oooool00?ooooooRoooool5o`WZ2USooooo1ol9jPXGooooo`03o`000?moOgoo
Ogmo01KoOgmo00?o0000ogmoOomoOgl0?_moOglJo`WZ2S7oOgmo00?o0000ogmoOomoOgl02omoOgl0
0ol0003oooooooooo`0Zooooo`?o2NX:m?ooool00ol0003oooooooooo`0Gooooo`00oooooon@oooo
o`Ko2NX:FOooool7o`WZ2Q7ooooo00?o0000ogmoOomoOgl05OmoOgl00ol0003oOgmoogmoO`0Uogmo
OaWo2NX:BomoOgl00ol0003oOgmoogmoO`0:ogmoO`03o`000?oooooooooo02Oooooo1?l9jP[goooo
o`03o`000?oooooooooo01Oooooo003ooooooiKooooo1_l9jPYJooooo`Oo2NX:2_ooool00ol0003o
OgmoogmoO`0EogmoO`03o`000?moOgooOgmo00_oOgmo6_l9jPYTogmoO`03o`000?moOgooOgmo00[o
Ogmo00?o0000ooooooooool09?ooool3o`WZ2__ooooo00?o0000ooooooooool05oooool00?oooooo
W?ooool5o`WZ2Ucooooo1ol9jPX2ooooo`;o00003?moOglIo`WZ2WkoOgmo00?o0000ogmoOomoOgl0
2_moOgl00ol0003oooooooooo`0Pooooo`Co2NX:o_ooool00ol0003oooooooooo`0Gooooo`00oooo
oonQooooo`Ko2NX:GOooool2o`WZ2P03o`000?l9jP[o2NX:00_o2NX:2omoOgl00ol0003oOgmoogmo
O`29ogmoO`03o`000?moOgooOgmo00[oOgmo00?o0000ooooooooool07?ooool4o`WZ2_oooooo0ooo
ool00ol0003oooooooooo`0Gooooo`00oooooonWooooo`Go2NX:G?ooool00ol0003oOgmoogmoO`0D
ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl02_moOgl00ol0003oooooooooo`0I
ooooo`?o2NX:ooooool7ooooo`03o`000?oooooooooo01Oooooo003oooooojcooooo1_l9jPYFoooo
o`03o`000?moOgooOgmo01CoOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`09ogmo
O`03o`000?oooooooooo01Kooooo1?l9jP[oooooo`[ooooo00?o0000ooooooooool05oooool00?oo
oooo/_ooool6o`WZ2U3ooooo00?o0000ogmoOomoOgl05?moOgl00ol0003oOgmoogmoO`29ogmoO`03
o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool04_ooool4o`WZ2_oooooo3_ooool00ol0003o
ooooooooo`0Gooooo`00oooooonhooooo`Go2NX:C?ooool00ol0003oOgmoogmoO`0CogmoO`03o`00
0?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl02OmoOgl00ol0003oooooooooo`0?ooooo`?o2NX:
oooooolBooooo`03o`000?oooooooooo01Oooooo003ooooookgooooo1_l9jPY6ooooo`03o`000?mo
OgooOgmo01?oOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`08ogmoO`03o`000?oo
oooooooo00cooooo1?l9jP[ooooooaGooooo00?o0000ooooooooool05oooool00?oooooo`oooool6
o`WZ2T3ooooo00?o0000ogmoOomoOgl04omoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgoo
Ogmo00SoOgmo00?o0000ooooooooool02Oooool3o`WZ2_oooooo6Oooool00ol0003oooooooooo`0G
ooooo`00ooooooo9ooooo`Go2NX:??ooool00ol0003oOgmoogmoO`0BogmoO`03o`000?moOgooOgmo
08?oOgmo1ol0000:ogmoO`03o`000?oooooooooo00Gooooo1?l9jP[ooooooacooooo00?o0000oooo
ooooool05oooool00?ooooooc_ooool6o`WZ2SKooooo00?o0000ogmoOomoOgl04_moOgl00ol0003o
OgmoogmoO`1gogmoO`co00001_moOgl00ol0003oOgmoogmoO`07ogmoO`03o`000?oooooooooo00;o
oooo1?l9jP[oooooob3ooooo00?o0000ooooooooool05oooool00?ooooooe?ooool6o`WZ2S3ooooo
00?o0000ogmoOomoOgl04_moOgl00ol0003oOgmoogmoO`1/ogmoO`_o00004_moOgl00ol0003oOgmo
ogmoO`07ogmoO`03o`000?oooooo2NX:00;o2NX:oooooolTooooo`03o`000?oooooooooo01Oooooo
003oooooom[ooooo1Ol9jPX/ooooo`03o`000?moOgooOgmo017oOgmo00?o0000ogmoOomoOgl0H?mo
Ogl<o`0001goOgmo00?o0000o`WZ2_l9jPX01_l9jPX00ol0003o2NX:o`WZ2P3oooooobOooooo00?o
0000ooooooooool05oooool00?oooooogoooool6o`WZ2RKooooo00?o0000ogmoOomoOgl04OmoOgl0
0ol0003oOgmoogmoO`1DogmoO`co00005omoOglCo`WZ2PSoOgmo0_l0003oooooobSooooo00?o0000
ooooooooool05oooool00?ooooooiOooool5o`WZ2R7ooooo00?o0000ogmoOomoOgl04OmoOgl00ol0
003oOgmoogmoO`19ogmoO`_o00004OmoOglBo`WZ2Q;oOgmo00?o0000ogmoOomoOgl01_moOgl00ol0
003oooooooooo`3oooooobOooooo00?o0000ooooooooool05oooool00?ooooooj_ooool6o`WZ2Qco
oooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0mogmoO`co00002OmoOglCo`WZ2RCo
Ogmo00?o0000ogmoOomoOgl01_moOgl00ol0003oooooooooo`3oooooobOooooo00?o0000oooooooo
ool05oooool00?ooooool?ooool6o`WZ2QKooooo00?o0000ogmoOomoOgl04?moOgl00ol0003oOgmo
ogmoO`0aogmoO`co00000_moOglCo`WZ2SOoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003ooooo
ooooo`3oooooobSooooo00?o0000ooooooooool05oooool00?oooooom_ooool5o`WZ2Q7ooooo00?o
0000ogmoOomoOgl04?moOgl00ol0003oOgmoogmoO`0VogmoO`Oo00004_l9jPY:ogmoO`03o`000?mo
OgooOgmo00GoOgmo00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01Oooooo003o
oooooo_ooooo1_l9jPX<ooooo`03o`000?moOgooOgmo00ooOgmo00?o0000ogmoOomoOgl06_moOglC
o`WZ2UcoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003oooooooooo`3oooooobSooooo00?o0000
ooooooooool05oooool00?ooooooooooool2ooooo`Ko2NX:1_ooool00ol0003oOgmoogmoO`0?ogmo
O`03o`000?moOgooOgmo00SoOgmo4_l9jPY_ogmoO`03o`000?moOgooOgmo00CoOgmo00?o0000oooo
ooooool0oooooolYooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo2?ooool5o`WZ2P03
ooooool0003o000000SoOgmo4ol9jPX6o`0007_oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003o
ooooooooo`3oooooobWooooo00?o0000ooooooooool05oooool00?ooooooooooool=ooooo`03o`WZ
2_l0003o2NX:00So2NX:2?moOgl6o`0008KoOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003ooooo
ooooo`3oooooobWooooo00?o0000ooooooooool05oooool00?ooooooooooool?ooooo`03o`000?mo
OgooOgmo00koOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo0?oooooo:_ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooa3ooooo00?o0000
ogmoOomoOgl03OmoOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000
ooooooooool0oooooolZooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo4?ooool00ol0
003oOgmoogmoO`0=ogmoO`03o`000?moOgooOgmo08WoOgmo00?o0000ogmoOomoOgl00omoOgl00ol0
003oooooooooo`3oooooob[ooooo00?o0000ooooooooool05oooool00?oooooooooooolAooooo`03
o`000?moOgooOgmo00coOgmo00?o0000ogmoOomoOgl0ROmoOgl00ol0003oOgmoogmoO`02ogmoO`03
o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Gooooo`00oooooooooooooa7ooooo
00?o0000ogmoOomoOgl03?moOgl00ol0003oOgmoogmoO`29ogmoO`03o`000?moOgooOgmo00;oOgmo
00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo4_oo
ool00ol0003oOgmoogmoO`0;ogmoO`03o`000?moOgooOgmo08CoOgmo1_l00004ogmoO`03o`000?oo
oooooooo0?oooooo:oooool00ol0003oooooooooo`0Gooooo`00oooooooooooooa;ooooo00?o0000
ogmoOomoOgl02omoOgl00ol0003oOgmoogmoO`1jogmoO`[o00001OmoOgl01Ol0003oOgmoogmoOomo
Ogoo00000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooa?ooooo00?o0000
ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`1`ogmoO`[o00003omoOgl01Ol0003oOgmoogmoOomo
Ogoo00000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooa?ooooo00?o0000
ogmoOomoOgl02_moOgl00ol0003oOgmoogmoO`1VogmoO`[o00006OmoOgl01Ol0003oOgmoogmoOomo
Ogoo00000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaCooooo00?o0000
ogmoOomoOgl02OmoOgl00ol0003oOgmoogmoO`1LogmoO`[o00008omoOgl01?l0003oOgmoogmoOol0
003ooooooboooooo00?o0000ooooooooool05oooool00?oooooooooooolDooooo`03o`000?moOgoo
Ogmo00WoOgmo00?o0000ogmoOomoOgl0D_moOgl:o`0002goOgmo00Co0000ogmoOomoOgoo0000oooo
ool_ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo5?ooool00ol0003oOgmoogmoO`09
ogmoO`03o`000?moOgooOgmo04SoOgmo2_l0000gogmoO`04o`000?moOgooOgmoo`000?oooooo;ooo
ool00ol0003oooooooooo`0Gooooo`00oooooooooooooaGooooo00?o0000ogmoOomoOgl02?moOgl0
0ol0003oOgmoogmoO`0nogmoO`[o0000@OmoOgl00ol0003oOgmoo`00003ooooooc3ooooo00?o0000
ooooooooool05oooool00?oooooooooooolEooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ogmo
OomoOgl0=?moOgl:o`0004_oOgmo00?o0000ogmoOol00000ooooool`ooooo`03o`000?oooooooooo
01Oooooo003ooooooooooooo5_ooool00ol0003oOgmoogmoO`07ogmoO`03o`000?moOgooOgmo02[o
Ogmo2_l0001EogmoO`03o`000?moOgoo00000?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
oooooooooooooaKooooo00?o0000ogmoOomoOgl01omoOgl00ol0003oOgmoogmoO`0PogmoO`[o0000
GomoOgl2o`000?oooooo<Oooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaOooooo00?o
0000ogmoOomoOgl01_moOgl00ol0003oOgmoogmoO`0FogmoO`[o0000I?moOgl7o`000?oooooo<Ooo
ool00ol0003oooooooooo`0Gooooo`00oooooooooooooaOooooo00?o0000ogmoOomoOgl01_moOgl0
0ol0003oOgmoogmoO`0<ogmoO`[o0000IOmoOgl9o`0000GoOgmo0_l0003ooooooc7ooooo00?o0000
ooooooooool05oooool00?oooooooooooolHooooo`03o`000?moOgooOgmo00GoOgmo00?o0000ogmo
OomoOgl00_moOgl:o`0006KoOgmo2Ol0000>ogmoO`03o`000?oooooooooo0?oooooo<?ooool00ol0
003oooooooooo`0Gooooo`00oooooooooooooaSooooo00?o0000ogmoOomoOgl01OmoOgl5o`0006Ko
Ogmo2_l0000CogmoO`Go0000oooooolbooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo
6Oooool00ol0003oOgmoogmoO`04ogmoO`03o`000?moOgooOgmo05ooOgmo2Ol0000EogmoO`So0000
1?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooo
oolIooooo`03o`000?moOgooOgmo00CoOgmo00?o0000ogmoOomoOgl0E_moOgl9o`0001GoOgmo2Ol0
000<ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
oooooaWooooo00?o0000ogmoOomoOgl01?moOgl00ol0003oOgmoogmoO`1<ogmoO`[o00005_moOgl8
o`0001Gooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooo
oooooooo6_ooool00ol0003oOgmoogmoO`03ogmoO`03o`000?moOgooOgmo04?oOgmo2Ol0000Hogmo
O`So00007Oooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oo
oooooooooolJooooo`03o`000?moOgooOgmo00?oOgmo00?o0000ogmoOomoOgl0>_moOgl9o`0001Wo
Ogmo2?l0000Uooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00
oooooooooooooa_ooooo00?o0000ogmoOomoOgl00_moOgl00ol0003oOgmoogmoO`0`ogmoO`[o0000
6OmoOgl9o`0002gooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo
003ooooooooooooo6oooool00ol0003oOgmoogmoO`02ogmoOhgo0000oooooolbooooo`03o`000?oo
oooooooo01Oooooo003ooooooooooooo7?ooool01Ol0003oOgmoogmoOomoOgoo0000023oOgmo2Ol0
000LogmoO`So0000?_ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05ooo
ool00?oooooooooooolLooooo`05o`000?moOgooOgmoogmoOol000005_moOgl:o`0001goOgmo2?l0
0016ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooo
oooooagooooo00Co0000ogmoOomoOgoo00003OmoOgl9o`0001ooOgmo2?l0001>ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooagooooo00Co0000
ogmoOomoOgoo00001?moOgl9o`0001ooOgmo2Ol0001Fooooo`03o`000?oooooooooo0?oooooo<?oo
ool00ol0003oooooooooo`0Gooooo`00oooooooooooooakooooo00?o0000ogmoOol000001?l0000P
ogmoO`So0000Goooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolNooooo`03o`000?moOgoo000001coOgmo2?l0001Wooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooakooooo00?o0000ogmoOol0
00005?moOgl8o`0006oooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo7oooool2o`0000_oOgmo2Ol0001gooooo`03o`000?oooooooooo0?oooooo
<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooooaoooooo0_l00003ogmoO`So0000P?oo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`Co0000R?ooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`oooo
o`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
5oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
ob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooo
ooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o
0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000
ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Goooo
o`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3o
oooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?oo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooooooo
o`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3o
oooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooo
oooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003o
ooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool0
0ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo
<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooo
oooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooo
oooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`oooo
o`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
5oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
ob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?oooon=o`000?oooooo
<_ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooo
oooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooo
oooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`oooo
o`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
5oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
ob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooo
ooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o
0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000
ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Goooo
o`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3o
oooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?oo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003ooooooooo
o`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3o
oooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooo
oooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003o
ooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool0
0ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo
<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooo
oooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooo
oooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3oooooSOl0003o
oooooc;ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooo
oooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003o
ooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03o`000?oo
oooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo<?ooool0
0ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolPooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo0?oooooo
<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooo
oooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooo
oooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`oooo
o`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool0
5oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0oooo
ool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00oooooooooooo
ob3ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000oooo
ooooool05oooool00?oooooooooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool0ooooool`ooooo`03o`000?oooooooooo01Oooooo003ooooooooooooo8?oooon=o`000?oooooo
<_ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooooooooolP
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooo
oooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool00?oooooo
oooooolPooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0ooooool`ooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooo8?ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00ol0003oooooooooo`0Gooooo`00ooooooooooooob3ooooo00?o0000
ooooooooool0ROooool00ol0003oooooooooo`3ooooooc3ooooo00?o0000ooooooooool05oooool0
0?oooooooooooolPooooohgo0000oooooolbooooo`03o`000?oooooooooo01Oooooo003ooooooooo
oooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`00
0?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003o
oooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOoooo
o`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oo
oooo003ooooooooooooooooooooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooo
oooOooooo`03o`000?oooooooooo01Oooooo003ooooooooooooooooooooOooooo`;o00006?ooool0
0?ooooooooooooooooooooWooooo003ooooooooooooooooooooiooooo`00oooooooooooooooooooo
nOooool00?ooooooooooooooooooooWooooo003ooooooooooooooooooooiooooo`00oooooooooooo
oooooooonOooool00?ooooooooooooooooooooWooooo003ooooooooooooooooooooiooooo`00oooo
oooooooooooooooonOooool00?ooooooooooooooooooooWooooo003ooooooooooooooooooooioooo
o`00oooooooooooooooooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 1013.56}, {506.25, 0}} -> {-0.127781, -1.31251, \
0.00518524, 0.00518524}}]
}, Open  ]],

Cell[TextData[{
  "Here we can see that the rays are not focusing to the smallest possible \
point on the screen. Using ",
  StyleBox["FindSpotSize", "Input"],
  ", we can measure the spot size on the screen."
}], "Text"],

Cell[CellGroupData[{

Cell["SpotSize/.FindSpotSize[plot]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49474 28.0564 0.502754 28.0564 [
[.07389 -0.0125 -18 -9 ]
[.07389 -0.0125 18 0 ]
[.21418 -0.0125 -15 -9 ]
[.21418 -0.0125 15 0 ]
[.35446 -0.0125 -18 -9 ]
[.35446 -0.0125 18 0 ]
[.49474 -0.0125 -3 -9 ]
[.49474 -0.0125 3 0 ]
[.63502 -0.0125 -15 -9 ]
[.63502 -0.0125 15 0 ]
[.7753 -0.0125 -12 -9 ]
[.7753 -0.0125 12 0 ]
[.91559 -0.0125 -15 -9 ]
[.91559 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08191 -36 -4.5 ]
[-0.0125 .08191 0 4.5 ]
[-0.0125 .22219 -30 -4.5 ]
[-0.0125 .22219 0 4.5 ]
[-0.0125 .36247 -36 -4.5 ]
[-0.0125 .36247 0 4.5 ]
[-0.0125 .50275 -6 -4.5 ]
[-0.0125 .50275 0 4.5 ]
[-0.0125 .64304 -30 -4.5 ]
[-0.0125 .64304 0 4.5 ]
[-0.0125 .78332 -24 -4.5 ]
[-0.0125 .78332 0 4.5 ]
[-0.0125 .9236 -30 -4.5 ]
[-0.0125 .9236 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1.00551 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.00551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07389 0 m
.07389 .00625 L
s
[(-0.015)] .07389 -0.0125 0 1 Mshowa
.21418 0 m
.21418 .00625 L
s
[(-0.01)] .21418 -0.0125 0 1 Mshowa
.35446 0 m
.35446 .00625 L
s
[(-0.005)] .35446 -0.0125 0 1 Mshowa
.49474 0 m
.49474 .00625 L
s
[(0)] .49474 -0.0125 0 1 Mshowa
.63502 0 m
.63502 .00625 L
s
[(0.005)] .63502 -0.0125 0 1 Mshowa
.7753 0 m
.7753 .00625 L
s
[(0.01)] .7753 -0.0125 0 1 Mshowa
.91559 0 m
.91559 .00625 L
s
[(0.015)] .91559 -0.0125 0 1 Mshowa
.125 Mabswid
.10195 0 m
.10195 .00375 L
s
.13001 0 m
.13001 .00375 L
s
.15806 0 m
.15806 .00375 L
s
.18612 0 m
.18612 .00375 L
s
.24223 0 m
.24223 .00375 L
s
.27029 0 m
.27029 .00375 L
s
.29835 0 m
.29835 .00375 L
s
.3264 0 m
.3264 .00375 L
s
.38251 0 m
.38251 .00375 L
s
.41057 0 m
.41057 .00375 L
s
.43863 0 m
.43863 .00375 L
s
.46668 0 m
.46668 .00375 L
s
.5228 0 m
.5228 .00375 L
s
.55085 0 m
.55085 .00375 L
s
.57891 0 m
.57891 .00375 L
s
.60697 0 m
.60697 .00375 L
s
.66308 0 m
.66308 .00375 L
s
.69113 0 m
.69113 .00375 L
s
.71919 0 m
.71919 .00375 L
s
.74725 0 m
.74725 .00375 L
s
.80336 0 m
.80336 .00375 L
s
.83142 0 m
.83142 .00375 L
s
.85947 0 m
.85947 .00375 L
s
.88753 0 m
.88753 .00375 L
s
.04584 0 m
.04584 .00375 L
s
.01778 0 m
.01778 .00375 L
s
.94364 0 m
.94364 .00375 L
s
.9717 0 m
.9717 .00375 L
s
.99975 0 m
.99975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08191 m
.00625 .08191 L
s
[(-0.015)] -0.0125 .08191 1 0 Mshowa
0 .22219 m
.00625 .22219 L
s
[(-0.01)] -0.0125 .22219 1 0 Mshowa
0 .36247 m
.00625 .36247 L
s
[(-0.005)] -0.0125 .36247 1 0 Mshowa
0 .50275 m
.00625 .50275 L
s
[(0)] -0.0125 .50275 1 0 Mshowa
0 .64304 m
.00625 .64304 L
s
[(0.005)] -0.0125 .64304 1 0 Mshowa
0 .78332 m
.00625 .78332 L
s
[(0.01)] -0.0125 .78332 1 0 Mshowa
0 .9236 m
.00625 .9236 L
s
[(0.015)] -0.0125 .9236 1 0 Mshowa
.125 Mabswid
0 .10997 m
.00375 .10997 L
s
0 .13802 m
.00375 .13802 L
s
0 .16608 m
.00375 .16608 L
s
0 .19413 m
.00375 .19413 L
s
0 .25025 m
.00375 .25025 L
s
0 .2783 m
.00375 .2783 L
s
0 .30636 m
.00375 .30636 L
s
0 .33442 m
.00375 .33442 L
s
0 .39053 m
.00375 .39053 L
s
0 .41859 m
.00375 .41859 L
s
0 .44664 m
.00375 .44664 L
s
0 .4747 m
.00375 .4747 L
s
0 .53081 m
.00375 .53081 L
s
0 .55887 m
.00375 .55887 L
s
0 .58692 m
.00375 .58692 L
s
0 .61498 m
.00375 .61498 L
s
0 .67109 m
.00375 .67109 L
s
0 .69915 m
.00375 .69915 L
s
0 .72721 m
.00375 .72721 L
s
0 .75526 m
.00375 .75526 L
s
0 .81137 m
.00375 .81137 L
s
0 .83943 m
.00375 .83943 L
s
0 .86749 m
.00375 .86749 L
s
0 .89554 m
.00375 .89554 L
s
0 .05385 m
.00375 .05385 L
s
0 .0258 m
.00375 .0258 L
s
0 .95166 m
.00375 .95166 L
s
0 .97971 m
.00375 .97971 L
s
.25 Mabswid
0 0 m
0 1.00551 L
s
.07389 .99926 m
.07389 1.00551 L
s
.21418 .99926 m
.21418 1.00551 L
s
.35446 .99926 m
.35446 1.00551 L
s
.49474 .99926 m
.49474 1.00551 L
s
.63502 .99926 m
.63502 1.00551 L
s
.7753 .99926 m
.7753 1.00551 L
s
.91559 .99926 m
.91559 1.00551 L
s
.125 Mabswid
.10195 1.00176 m
.10195 1.00551 L
s
.13001 1.00176 m
.13001 1.00551 L
s
.15806 1.00176 m
.15806 1.00551 L
s
.18612 1.00176 m
.18612 1.00551 L
s
.24223 1.00176 m
.24223 1.00551 L
s
.27029 1.00176 m
.27029 1.00551 L
s
.29835 1.00176 m
.29835 1.00551 L
s
.3264 1.00176 m
.3264 1.00551 L
s
.38251 1.00176 m
.38251 1.00551 L
s
.41057 1.00176 m
.41057 1.00551 L
s
.43863 1.00176 m
.43863 1.00551 L
s
.46668 1.00176 m
.46668 1.00551 L
s
.5228 1.00176 m
.5228 1.00551 L
s
.55085 1.00176 m
.55085 1.00551 L
s
.57891 1.00176 m
.57891 1.00551 L
s
.60697 1.00176 m
.60697 1.00551 L
s
.66308 1.00176 m
.66308 1.00551 L
s
.69113 1.00176 m
.69113 1.00551 L
s
.71919 1.00176 m
.71919 1.00551 L
s
.74725 1.00176 m
.74725 1.00551 L
s
.80336 1.00176 m
.80336 1.00551 L
s
.83142 1.00176 m
.83142 1.00551 L
s
.85947 1.00176 m
.85947 1.00551 L
s
.88753 1.00176 m
.88753 1.00551 L
s
.04584 1.00176 m
.04584 1.00551 L
s
.01778 1.00176 m
.01778 1.00551 L
s
.94364 1.00176 m
.94364 1.00551 L
s
.9717 1.00176 m
.9717 1.00551 L
s
.99975 1.00176 m
.99975 1.00551 L
s
.25 Mabswid
0 1.00551 m
1 1.00551 L
s
.99375 .08191 m
1 .08191 L
s
.99375 .22219 m
1 .22219 L
s
.99375 .36247 m
1 .36247 L
s
.99375 .50275 m
1 .50275 L
s
.99375 .64304 m
1 .64304 L
s
.99375 .78332 m
1 .78332 L
s
.99375 .9236 m
1 .9236 L
s
.125 Mabswid
.99625 .10997 m
1 .10997 L
s
.99625 .13802 m
1 .13802 L
s
.99625 .16608 m
1 .16608 L
s
.99625 .19413 m
1 .19413 L
s
.99625 .25025 m
1 .25025 L
s
.99625 .2783 m
1 .2783 L
s
.99625 .30636 m
1 .30636 L
s
.99625 .33442 m
1 .33442 L
s
.99625 .39053 m
1 .39053 L
s
.99625 .41859 m
1 .41859 L
s
.99625 .44664 m
1 .44664 L
s
.99625 .4747 m
1 .4747 L
s
.99625 .53081 m
1 .53081 L
s
.99625 .55887 m
1 .55887 L
s
.99625 .58692 m
1 .58692 L
s
.99625 .61498 m
1 .61498 L
s
.99625 .67109 m
1 .67109 L
s
.99625 .69915 m
1 .69915 L
s
.99625 .72721 m
1 .72721 L
s
.99625 .75526 m
1 .75526 L
s
.99625 .81137 m
1 .81137 L
s
.99625 .83943 m
1 .83943 L
s
.99625 .86749 m
1 .86749 L
s
.99625 .89554 m
1 .89554 L
s
.99625 .05385 m
1 .05385 L
s
.99625 .0258 m
1 .0258 L
s
.99625 .95166 m
1 .95166 L
s
.99625 .97971 m
1 .97971 L
s
.25 Mabswid
1 0 m
1 1.00551 L
s
.039 .916 .04 r
2.5 Mabswid
.17377 .50275 Mdot
.30135 .50275 Mdot
.32775 .50275 Mdot
.34588 .50275 Mdot
.40245 .50275 Mdot
.49474 .50275 Mdot
.58703 .50275 Mdot
.6436 .50275 Mdot
.66173 .50275 Mdot
.68813 .50275 Mdot
.81571 .50275 Mdot
0 0 0 r
.0002 w
.97619 .50275 m
.93457 .69858 L
.81689 .86054 L
.64352 .96064 L
.44441 .98157 L
.25401 .9197 L
.10524 .78574 L
.02381 .60285 L
.02381 .40265 L
.10524 .21976 L
.25401 .08581 L
.44441 .02394 L
.64352 .04487 L
.81689 .14497 L
.93457 .30693 L
.97619 .50275 L
s
0 0 m
1 0 L
1 1.00551 L
0 1.00551 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{286.375, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N00017b000`400?l00000o`00003ooooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00;oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol00003ooooo`?o00002oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0000<ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000?ooooo0ol0000Aooooo`;o00005Oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`?o00002oooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000?ooooo0ol0000<ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000?ooooo0ol00009ooooo`00;_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0=oooo
o`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool002Oooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool5o`0000;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool03Oooool01?l0003oooooooooool0000Cooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool002kooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooo
o`0001?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`00;_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooooooo1?l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00004?ooool01?l0
003oooooooooool0000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0_ooool01Ol0003oooooooooool0003ooooo00Co00002_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo1?l00009ooooo`00
;_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00003?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00Ko0000oooooooooooo0000ooooool0000Cooooo`04o`000?ooooooooooo`0001?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
0_l0000<ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`00
00?ooooo00?o0000ooooooooool02_ooool002oooooo0_l0000:ooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`0000[ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0;oooo
o`;o00002_ooool2o`0000Cooooo0_l00002ooooo`Go00004?ooool2o`0001Gooooo0_l0000:oooo
o`;o00001?ooool2o`0000;ooooo1Ol0000:ooooo`;o00002_ooool2o`0000Cooooo00?o0000oooo
ooooool02oooool2o`0000[ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00002?ooool0
0?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool002Oooooomol00000
02Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0Ol00000
02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`7o0000000Wooooo`03
o`000?oooooooooo0??ooooo0Ol0000002Oooooo00?o0000ooooooooool0loooool1o`0000009ooo
ool00ol0003oooooooooo`3cooooo`7o0000000Wooooo`03o`000?oooooooooo06Sooooo2?l00023
ooooo`7o0000000Wooooo`;o0000I_ooool3o`0000Sooooo2_l0001hooooo`;o0000000Wooooo`03
o`000?oooooooooo06;ooooo0ol0000Eooooo`[o0000Koooool1o`0000009oooool00ol0003ooooo
ooooo`1Oooooo`?o00008_ooool9o`0006Kooooo0Ol0000002Oooooo00?o0000ooooooooool0G?oo
ool3o`0002kooooo2_l0001Looooo`7o0000000Wooooo`03o`000?oooooooooo05Wooooo0ol0000k
ooooo`Ko0000E_ooool1o`0000009oooool00ol0003oooooooooo`1Fooooo`?o0000A?ooool2o`00
05Cooooo0Ol0000002Oooooo00?o0000ooooooooool0D_ooool4o`0004Wooooo00?o0000oooooooo
ool0DOooool1o`0000009oooool2o`00053ooooo0ol0001>ooooo`;o0000D?ooool2o`0000009ooo
ool00ol0003oooooooooo`1<ooooo`?o0000Doooool2o`0004oooooo0Ol0000002Oooooo00?o0000
ooooooooool0BOooool3o`0005Sooooo00?o0000ooooooooool0C?ooool1o`0000009oooool00ol0
003oooooooooo`16ooooo`?o0000G?ooool2o`0004cooooo0Ol0000000Sooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo0_l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000oooooooo
ool0@oooool3o`00067ooooo0_l0001:ooooo`7o00000007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`10ooooo`?o0000I_ooool2o`0004Sooooo0Ol00000
00Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000?_ooool3o`0006_ooooo00?o
0000ooooooooool0@oooool3o`0000001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03[ooooo0ol0001_ooooo`;o0000AOooool1o`0000001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo1?l00005oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0L_ooool2o`0004?ooooo0Ol0000000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0MOooool2
o`00047ooooo0Ol0000000Sooooo0_l0000:ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo03kooooo0Ol0000002Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1joooo
o`;o0000?_ooool1o`0000009oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07go
oooo0_l0000looooo`7o0000000Wooooo`;o0000=Oooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo03Sooooo0_l0000002Oooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`22ooooo`;o0000>Oooool1o`0000009oooool00ol0003oooooooooo`0aooooo`;o0000Qoooool2
o`0003Oooooo0Ol0000002Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`29oooo
o`;o0000=Oooool1o`0000009oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0<_ooool1o`0000009oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo08kooooo0_l0000booooo`7o0000000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0TOooool2o`00033ooooo0Ol0000002Oooooo0_l0000]ooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool0;?ooool2o`0000009oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo09Kooooo0_l0000]ooooo`7o0000000Wooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Zooooo`7o0000000Wooooo`03o`00
0?oooooooooo02Sooooo0_l0002Looooo`03o`000?oooooooooo02[ooooo0Ol0000002Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo02Wooooo0Ol0
000002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo
oooo02Sooooo0Ol0000002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo02Oooooo0Ol0000002Oooooo0_l0000Uooooo`03o`000?oooooooooo0:;o
oooo00?o0000ooooooooool09_ooool2o`0000009oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo0:Cooooo00?o0000ooooooooool09_ooool1o`0000009oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool09Oooool1o`0000009oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool09Oooool1
o`0000009oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool09?ooool1o`0000009oooool00ol0003oooooooooo`0Nooooo`;o0000[Oooool00ol0003o
ooooooooo`0Sooooo`7o0000000Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
[_ooool00ol0003oooooooooo`0Rooooo`7o0000000Wooooo`;o00007Oooool00ol0003ooooooooo
o`2_ooooo`03o`000?oooooooooo027ooooo0_l0000002Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo027ooooo0Ol0000002Oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo023ooooo0Ol0000002Oo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo01oo
oooo0Ol0000002Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2fooooo`03o`00
0?oooooooooo01oooooo0Ol0000000kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l0
0003ooooo`?o00001Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;Sooooo00?o
0000ooooooooool07_ooool1o`0000003Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool07Oooool1o`0000001_ooool5o`0000;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Co
oooo0_l0000Gooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool06oooool3o`000000
3Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool07?ooool1o`0000003Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo0;gooooo00?o0000ooooooooool06oooool1o`0000003Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00006ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0_oooool00ol0003oooooooooo`0Jooooo`7o0000000>ooooo`;o00002_ooool2
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo0;oooooo00?o0000ooooooooool06_ooool1o`0000009oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool06Oooool1o`0000009oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool06?ooool1o`000000
9oooool2o`0001Cooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`0Gooooo`;o0000
000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0a?ooool00ol0003ooooooooo
o`0Gooooo`7o0000000Wooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0aOooool0
0ol0003oooooooooo`0Fooooo`7o0000000Wooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0aoooool00ol0003oooooooooo`0Eooooo`7o0000000Wooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`0Eooooo`7o0000000Wooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`0Dooooo`7o0000
000Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0b_ooool00ol0003ooooooooo
o`0Cooooo`7o0000000Wooooo`;o00004Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo017ooooo0_l0000002Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo01;ooooo0Ol0000002Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`3=ooooo`03o`000?oooooooooo017ooooo0Ol0000002Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo013ooooo0Ol0000002Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3?ooooo`03o`000?oooooooooo013ooooo0Ol0
000002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooo
oooo00oooooo0Ol0000002Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Boooo
o`03o`000?oooooooooo00kooooo0Ol0000002Oooooo0_l0000=ooooo`03o`000?oooooooooo0=Co
oooo00?o0000ooooooooool03?ooool2o`0000009oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0=Cooooo00?o0000ooooooooool03Oooool1o`0000009oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool03Oooool1o`0000009oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooooooool03?ooool1
o`0000009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Kooooo00?o0000oooo
ooooool03?ooool1o`0000009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Oo
oooo00?o0000ooooooooool03?ooool1o`0000009oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0=Oooooo00?o0000ooooooooool03?ooool1o`0000009oooool2o`0000[ooooo00?o
0000ooooooooool0f?ooool00ol0003oooooooooo`0;ooooo`;o0000000Wooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`0;ooooo`7o0000000Woooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`0;oooo
o`7o0000000Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0f_ooool00ol0003o
ooooooooo`0;ooooo`7o00000008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
f_ooool00ol0003oooooooooo`0;ooooo`7o00000007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo00?o0000
ooooooooool02oooool1o`0000001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo00[ooooo
0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000oooo
ooooool0gOooool00ol0003oooooooooo`08ooooo`?o00000007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00001Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=gooooo00?o0000ooooooooool02_oo
ool1o`0000001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0g_ooool00ol0003oooooooooo`0:ooooo`7o00000008ooooo`;o00002_ooool2o`0000Co
oooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=ko
oooo00?o0000ooooooooool02_ooool1o`0000009oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0>3ooooo00?o0000ooooooooool02Oooool1o`0000009oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0>3ooooo00?o0000ooooooooool02Oooool1o`0000009oooool2
o`0000Gooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`08ooooo`;o0000000Woooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0hOooool00ol0003oooooooooo`09oooo
o`7o0000000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0hOooool00ol0003o
ooooooooo`09ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
hoooool00ol0003oooooooooo`08ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0hoooool00ol0003oooooooooo`08ooooo`7o0000000Wooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`08ooooo`7o0000000Woooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0hoooool00ol0003oooooooooo`08oooo
o`7o0000000Wooooo`;o00000oooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo00Ko
oooo0_l0000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`03o`00
0?oooooooooo00Oooooo0Ol0000002Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3Tooooo`03o`000?oooooooooo00Oooooo0Ol0000002Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3Tooooo`03o`000?oooooooooo00Oooooo0Ol0000002Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo00Oooooo0Ol0000002Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo00Ko
oooo0Ol0000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`03o`00
0?oooooooooo00Kooooo0Ol0000002Oooooo0_l00003ooooo`03o`000?oooooooooo0>Gooooo00?o
0000ooooooooool01Oooool2o`0000009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0>Gooooo00?o0000ooooooooool01_ooool1o`0000009oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool01_ooool1o`0000009oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool01Oooool1o`000000
9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo00?o0000ooooooooool0
1Oooool1o`0000009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo00?o
0000ooooooooool01Oooool1o`0000009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0>Kooooo00?o0000ooooooooool01Oooool1o`0000009oooool2o`0000?ooooo00?o0000oooo
ooooool0i_ooool00ol0003oooooooooo`04ooooo`;o0000000Wooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`04ooooo`7o0000000Wooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`04ooooo`7o0000
000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ioooool00ol0003ooooooooo
o`04ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ioooool0
0ol0003oooooooooo`04ooooo`7o0000000Pooooo`;o00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool01?ooool1o`0000007oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0j?ooool00ol0
003oooooooooo`03ooooo`7o0000000Oooooo`04o`000?ooooooooooo`0000Cooooo0_l00003oooo
o`03o`000?oooooooooo02;ooooo0_l9jPXMooooo`;o2NX:1Oooool2o`WZ2P;ooooo0_l9jPX<oooo
o`;o2NX:5Oooool2o`WZ2QCooooo0_l9jPX<ooooo`;o2NX:0oooool2o`WZ2PCooooo0_l9jPXNoooo
o`;o2NX:9_ooool01?l0003oooooooooooooool3o`0000007oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool2o`WZ2Qgooooo0_l9jPX5
ooooo`;o2NX:0_ooool2o`WZ2Pcooooo0_l9jPXEooooo`;o2NX:5?ooool2o`WZ2Pcooooo0_l9jPX3
ooooo`;o2NX:1?ooool2o`WZ2Qkooooo0_l9jPXVooooo`03o`000?oooooooooo00?ooooo0Ol00000
01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0>Sooooo00?o0000ooooooooool00oooool1o`0000007oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`04
ooooo`7o0000000Pooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0>Oooooo00?o0000ooooooooool01?ooool1o`0000009oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool01?ooool1o`0000009oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool01?ooool1o`0000009ooo
ool2o`0000?ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`03ooooo`;o0000000W
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`05
ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0i_ooool00ol0
003oooooooooo`05ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0i_ooool00ol0003oooooooooo`05ooooo`7o0000000Wooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0i_ooool00ol0003oooooooooo`05ooooo`7o0000000Wooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`05ooooo`7o0000000W
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`06
ooooo`7o0000000Wooooo`;o00000oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo
00Gooooo0_l0000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`03
o`000?oooooooooo00Kooooo0Ol0000002Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3Uooooo`03o`000?oooooooooo00Kooooo0Ol0000002Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3Uooooo`03o`000?oooooooooo00Kooooo0Ol0000002Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo00Oooooo0Ol00000
02Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo
00Oooooo0Ol0000002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Tooooo`03
o`000?oooooooooo00Oooooo0Ol0000002Oooooo0_l00003ooooo`03o`000?oooooooooo0>Cooooo
00?o0000ooooooooool01_ooool2o`0000009oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0>Cooooo00?o0000ooooooooool01oooool1o`0000009oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool02?ooool1o`0000009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0>?ooooo00?o0000ooooooooool02?ooool1o`00
00009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>?ooooo00?o0000oooooooo
ool02?ooool1o`0000009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>?ooooo
00?o0000ooooooooool02?ooool1o`0000009oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>7ooooo00?o0000ooooooooool02Oooool1o`0000009oooool2o`0000Cooooo00?o0000
ooooooooool0hOooool00ol0003oooooooooo`08ooooo`;o0000000Wooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`09ooooo`7o0000000Wooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`09ooooo`7o
0000000Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0h?ooool00ol0003ooooo
ooooo`09ooooo`7o00000008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g_oo
ool00ol0003oooooooooo`0:ooooo`7o00000007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=kooooo00?o0000oooo
ooooool02_ooool1o`0000001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`0:ooooo`7o00000007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo0=go
oooo00?o0000ooooooooool02?ooool3o`0000001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`3Looooo`03o`000?oooooooooo00[ooooo0Ol00000
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_o
oooo00?o0000ooooooooool02oooool1o`0000002?ooool2o`0000[ooooo0_l00004ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Jooooo`03o`00
0?oooooooooo00_ooooo0Ol0000002Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3Jooooo`03o`000?oooooooooo00_ooooo0Ol0000002Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`3Jooooo`03o`000?oooooooooo00_ooooo0Ol0000002Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo00_ooooo0Ol0000002Oo
oooo0_l0000:ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool02oooool2o`000000
9oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool0
3?ooool1o`0000009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Oooooo00?o
0000ooooooooool03?ooool1o`0000009oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo0=Kooooo00?o0000ooooooooool03?ooool1o`0000009oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0=Kooooo00?o0000ooooooooool03?ooool1o`0000009oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool03Oooool1o`000000
9oooool2o`0000gooooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`0<ooooo`;o0000
000Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0e?ooool00ol0003ooooooooo
o`0=ooooo`7o0000000Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0d_ooool0
0ol0003oooooooooo`0>ooooo`7o0000000Wooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0dOooool00ol0003oooooooooo`0?ooooo`7o0000000Wooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0@ooooo`7o0000000Wooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0@ooooo`7o0000
000Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0cOooool00ol0003ooooooooo
o`0Aooooo`7o0000000Wooooo`;o00004?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo017ooooo0_l0000002Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo01;ooooo0Ol0000002Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`3:ooooo`03o`000?oooooooooo01?ooooo0Ol0000002Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo01Cooooo0Ol0000002Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo01Gooooo0Ol0
000002Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooo
oooo01Gooooo0Ol0000002Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`35oooo
o`03o`000?oooooooooo01Kooooo0Ol0000002Oooooo0_l0000Cooooo`03o`000?oooooooooo0<Co
oooo00?o0000ooooooooool05_ooool2o`0000009oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0<;ooooo00?o0000ooooooooool06?ooool1o`0000009oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool06?ooool1o`0000009oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool06Oooool1
o`0000009oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ooooool06_ooool1o`0000003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0_oooool00ol0003o
ooooooooo`0Jooooo`7o0000000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0_Oooool00ol0003oooooooooo`0Kooooo`7o0000000=ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`;o00005_ooool0
0ol0003oooooooooo`2looooo`03o`000?oooooooooo01[ooooo0ol0000000gooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool05_ooool2o`000;_ooooo00?o0000ooooooooool07Oooool1o`0000003Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
7Oooool1o`0000003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo0_l00006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0]_ooool00ol0003o
ooooooooo`0Nooooo`7o0000000>ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0
7oooool1o`0000009oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;?ooooo00?o
0000ooooooooool07oooool1o`0000009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool08?ooool1o`0000009oooool2o`0001kooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`0Pooooo`;o0000000Wooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`0Rooooo`7o0000000Wooooo`03o`00
0?oooooooooo01oooooo0_l0002]ooooo`03o`000?oooooooooo02;ooooo0Ol0000002Oooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo02?ooooo0Ol0
000002Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooo
oooo02Cooooo0Ol0000002Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Uoooo
o`03o`000?oooooooooo02Gooooo0Ol0000002Oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2Tooooo`03o`000?oooooooooo02Gooooo0Ol0000002Oooooo0_l0000Vooooo`03o`00
0?oooooooooo0:;ooooo00?o0000ooooooooool09Oooool2o`0000009oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool09oooool1o`0000009oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool09oooool1
o`0000009oooool00ol0003oooooooooo`0Xooooo`;o0000W_ooool00ol0003oooooooooo`0Xoooo
o`7o0000000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`0Yooooo`7o0000000Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Uoooool2o`0002cooooo0Ol0000002Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`2Dooooo`;o0000;_ooool1o`0000009oooool2o`0002kooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`0]ooooo`;o0000000Wooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0Soooool2o`00037ooooo0Ol0000002Oooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`2<ooooo`;o0000<oooool1o`0000009oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool0<oooool1o`0000009oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo08Oooooo0_l0000fooooo`7o0000000Wooooo`03o`000?oooooo
oooo03;ooooo0_l00025ooooo`;o0000>?ooool1o`0000009oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo083ooooo0_l0000jooooo`7o0000000Wooooo`;o0000=_ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo03Wooooo0_l0000002Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`1kooooo`;o0000?Oooool1o`0000009oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo07Sooooo0_l0000oooooo`7o0000000Wooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0MOooool2o`00047ooooo0Ol0000000Sooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00000oooool3o`0000Gooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo047ooooo0Ol0000000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0L?ooool2o`0004Cooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0kooooo`?o0000KOooool2o`0004Kooooo0Ol0000000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool2o`0003oooooo0ol0001Yooooo`03o`000?oooooooooo04Co
oooo0ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`11ooooo`?o0000I?ooool2
o`0004Wooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo0ol0
001Oooooo`;o0000Boooool1o`0000002?ooool2o`0000[ooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00ol0003oooooooooo`17ooooo`?o0000F_ooool2o`0004gooooo0Ol0
000002Oooooo00?o0000ooooooooool0B_ooool3o`0005Kooooo00?o0000ooooooooool0COooool1
o`0000009oooool00ol0003oooooooooo`1=ooooo`?o0000DOooool2o`00053ooooo0Ol0000002Oo
oooo00?o0000ooooooooool0D?ooool4o`0004_ooooo0_l0001Booooo`7o0000000Wooooo`;o0000
EOooool3o`0004Oooooo00?o0000ooooooooool0DOooool2o`0000009oooool00ol0003ooooooooo
o`1Gooooo`?o0000@_ooool2o`0005Gooooo0Ol0000002Oooooo00?o0000ooooooooool0F_ooool3
o`0003Wooooo1_l0001Gooooo`7o0000000Wooooo`03o`000?oooooooooo05gooooo0ol0000/oooo
o`[o0000GOooool1o`0000009oooool00ol0003oooooooooo`1Pooooo`?o00007oooool:o`0006Oo
oooo0Ol0000002Oooooo00?o0000ooooooooool0Hoooool3o`0001?ooooo2Ol0001aooooo`7o0000
000Wooooo`;o0000Ioooool3o`0000Kooooo2_l0001iooooo`;o0000000Wooooo`03o`000?oooooo
oooo06Wooooo1_l00024ooooo`7o0000000Wooooo`03o`000?oooooooooo0??ooooo0Ol0000002Oo
oooo00?o0000ooooooooool0loooool1o`0000009oooool00ol0003oooooooooo`3cooooo`7o0000
000Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool1o`0000009oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool1o`0000009oooooog
o`000000oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00\
\>"],
  ImageRangeCache->{{{0, 285.375}, {286.938, 0}} -> {-0.0232918, -0.0216468, \
0.000144788, 0.000144788}}],

Cell[BoxData[
    \(0.02288017383624119`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally we can use ",
  StyleBox["OptimizeSystem", "Input"],
  " to determine values for the aspheric lens parameters that generate a \
better focus."
}], "Text"],

Cell[CellGroupData[{

Cell["?OptimizeSystem", "Input"],

Cell[BoxData[
    \("OptimizeSystem[system, options] optimizes the performance of an \
optical system for a specified set of input parameters. \n\nOptimizeSystem \
first calls ConstructMeritFunction to create a RayTraceFunction according to \
the MeritType option setting and then calls a minimization algorithm \
according to the MinimizationType option. MeritType is internally converted \
into particular settings for the ReportedParameter and ReportedFunction \
options. As an alternative to using the MeritType option, the user can \
instead work directly with the ReportedParameters and ReportedFunction \
options. In addition to accepting an optical system of light sources and \
components, one or more previously calculated results from \
ConstructMeritFunction may be directly passed to OptimizeSystem. If more than \
one ConstructMeritFunction result is passed, OptimizeSystem uses the combined \
merit results to perform the minimization. \n\nSee also: \
ConstructMeritFunction, MeritType, MinimizationType, TurboTrace, and \
RayTraceFunction."\)], "Print",
  CellTags->"Info3334476571-2350196"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sol = \
OptimizeSystem[{WedgeOfRays[20,NumberOfRays->11],Move[alens,2.5],Move[Screen[\
2.5],5]}]\
\>", "Input"],

Cell[BoxData[
    \({SymbolicValues \[Rule] {ca1 \[Rule] \(-0.016452348473720846`\), 
          ca2 \[Rule] 0.013424437603494528`, 
          ca3 \[Rule] \(-0.22642046419843814`\), 
          ca4 \[Rule] 0.041368818189323836`, 
          ca5 \[Rule] \(-0.08500283418257876`\), 
          cb1 \[Rule] \(-0.005616741712779055`\), 
          cb2 \[Rule] \(-0.0009687254518773811`\), 
          cb3 \[Rule] \(-0.05217454917173449`\), 
          cb4 \[Rule] \(-0.07759902827837696`\), 
          cb5 \[Rule] \(-0.8187315915069879`\), 
          curva \[Rule] 0.9076885727675713`, 
          curvb \[Rule] \(-0.8695167155425348`\), 
          ka \[Rule] \(-0.5167777337120107`\), 
          kb \[Rule] \(-6.106981297266017`\)}, NumberOfCycles \[Rule] 1720, 
      FinalMerit \[Rule] 0.000010689230844940347`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "After 1720 iterations, ",
  StyleBox["OptimizeSystem", "Input"],
  " has found better values the aspheric lens coefficients to minimize the \
spot size of the trace, as revealed by ",
  StyleBox["TurboPlot", "Input"],
  " and ",
  StyleBox["FindSpotSize", "Input"],
  " below."
}], "Text"],

Cell[CellGroupData[{

Cell["bestplot = TurboPlot[plot,PlotType->TopView,sol];", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.25 0.190476 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.53412 .12619 m
.67364 .14238 L
.68552 .17825 L
.51577 .16746 L
.53412 .12619 L
F
.51577 .16746 m
.68552 .17825 L
.69331 .21413 L
.50393 .20873 L
.51577 .16746 L
F
.50393 .20873 m
.69331 .21413 L
.69619 .25 L
.5 .25 L
.50393 .20873 L
F
.5 .25 m
.69619 .25 L
.69331 .28587 L
.50393 .29127 L
.5 .25 L
F
.50393 .29127 m
.69331 .28587 L
.68552 .32175 L
.51577 .33254 L
.50393 .29127 L
F
.51577 .33254 m
.68552 .32175 L
.67364 .35762 L
.53412 .37381 L
.51577 .33254 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.53412 .12619 m
.51577 .16746 L
.50393 .20873 L
.5 .25 L
.50393 .29127 L
.51577 .33254 L
.53412 .37381 L
.67364 .35762 L
.68552 .32175 L
.69331 .28587 L
.69619 .25 L
.69331 .21413 L
.68552 .17825 L
.67364 .14238 L
.53412 .12619 L
s
.5 g
.53412 .25 m
.67364 .25 L
.68552 .25 L
.51577 .25 L
.53412 .25 L
F
.51577 .25 m
.68552 .25 L
.69331 .25 L
.50393 .25 L
.51577 .25 L
F
.50393 .25 m
.69331 .25 L
.69619 .25 L
.5 .25 L
.50393 .25 L
F
.5 .25 m
.69619 .25 L
.69331 .25 L
.50393 .25 L
.5 .25 L
F
.50393 .25 m
.69331 .25 L
.68552 .25 L
.51577 .25 L
.50393 .25 L
F
.51577 .25 m
.68552 .25 L
.67364 .25 L
.53412 .25 L
.51577 .25 L
F
0 g
.53412 .25 m
.51577 .25 L
.50393 .25 L
.5 .25 L
.50393 .25 L
.51577 .25 L
.53412 .25 L
.67364 .25 L
.68552 .25 L
.69331 .25 L
.69619 .25 L
.69331 .25 L
.68552 .25 L
.67364 .25 L
.53412 .25 L
s
.53412 .37381 m
.53548 .47857 L
.53548 .47078 L
.53412 .36959 L
.53412 .37381 L
s
.53412 .36959 m
.53548 .47078 L
.53548 .44795 L
.53412 .35722 L
.53412 .36959 L
s
.53412 .35722 m
.53548 .44795 L
.53548 .41162 L
.53412 .33755 L
.53412 .35722 L
s
.53412 .33755 m
.53548 .41162 L
.53548 .36429 L
.53412 .3119 L
.53412 .33755 L
s
.53412 .3119 m
.53548 .36429 L
.53548 .30916 L
.53412 .28204 L
.53412 .3119 L
s
.53412 .28204 m
.53548 .30916 L
.53548 .25 L
.53412 .25 L
.53412 .28204 L
s
.53412 .25 m
.53548 .25 L
.53548 .19084 L
.53412 .21796 L
.53412 .25 L
s
.53412 .21796 m
.53548 .19084 L
.53548 .13571 L
.53412 .1881 L
.53412 .21796 L
s
.53412 .1881 m
.53548 .13571 L
.53548 .08838 L
.53412 .16245 L
.53412 .1881 L
s
.53412 .16245 m
.53548 .08838 L
.53548 .05205 L
.53412 .14278 L
.53412 .16245 L
s
.53412 .14278 m
.53548 .05205 L
.53548 .02922 L
.53412 .13041 L
.53412 .14278 L
s
.53412 .13041 m
.53548 .02922 L
.53548 .02143 L
.53412 .12619 L
.53412 .13041 L
s
.53412 .12619 m
.53548 .02143 L
.53548 .02922 L
.53412 .13041 L
.53412 .12619 L
s
.53412 .13041 m
.53548 .02922 L
.53548 .05205 L
.53412 .14278 L
.53412 .13041 L
s
.53412 .14278 m
.53548 .05205 L
.53548 .08838 L
.53412 .16245 L
.53412 .14278 L
s
.53412 .16245 m
.53548 .08838 L
.53548 .13571 L
.53412 .1881 L
.53412 .16245 L
s
.53412 .1881 m
.53548 .13571 L
.53548 .19084 L
.53412 .21796 L
.53412 .1881 L
s
.53412 .21796 m
.53548 .19084 L
.53548 .25 L
.53412 .25 L
.53412 .21796 L
s
.53412 .25 m
.53548 .25 L
.53548 .30916 L
.53412 .28204 L
.53412 .25 L
s
.53412 .28204 m
.53548 .30916 L
.53548 .36429 L
.53412 .3119 L
.53412 .28204 L
s
.53412 .3119 m
.53548 .36429 L
.53548 .41162 L
.53412 .33755 L
.53412 .3119 L
s
.53412 .33755 m
.53548 .41162 L
.53548 .44795 L
.53412 .35722 L
.53412 .33755 L
s
.53412 .35722 m
.53548 .44795 L
.53548 .47078 L
.53412 .36959 L
.53412 .35722 L
s
.53412 .36959 m
.53548 .47078 L
.53548 .47857 L
.53412 .37381 L
.53412 .36959 L
s
.53548 .47857 m
.67403 .47857 L
.67403 .47078 L
.53548 .47078 L
.53548 .47857 L
s
.53548 .47078 m
.67403 .47078 L
.67403 .44795 L
.53548 .44795 L
.53548 .47078 L
s
.53548 .44795 m
.67403 .44795 L
.67403 .41162 L
.53548 .41162 L
.53548 .44795 L
s
.53548 .41162 m
.67403 .41162 L
.67403 .36429 L
.53548 .36429 L
.53548 .41162 L
s
.53548 .36429 m
.67403 .36429 L
.67403 .30916 L
.53548 .30916 L
.53548 .36429 L
s
.53548 .30916 m
.67403 .30916 L
.67403 .25 L
.53548 .25 L
.53548 .30916 L
s
.53548 .25 m
.67403 .25 L
.67403 .19084 L
.53548 .19084 L
.53548 .25 L
s
.53548 .19084 m
.67403 .19084 L
.67403 .13571 L
.53548 .13571 L
.53548 .19084 L
s
.53548 .13571 m
.67403 .13571 L
.67403 .08838 L
.53548 .08838 L
.53548 .13571 L
s
.53548 .08838 m
.67403 .08838 L
.67403 .05205 L
.53548 .05205 L
.53548 .08838 L
s
.53548 .05205 m
.67403 .05205 L
.67403 .02922 L
.53548 .02922 L
.53548 .05205 L
s
.53548 .02922 m
.67403 .02922 L
.67403 .02143 L
.53548 .02143 L
.53548 .02922 L
s
.53548 .02143 m
.67403 .02143 L
.67403 .02922 L
.53548 .02922 L
.53548 .02143 L
s
.53548 .02922 m
.67403 .02922 L
.67403 .05205 L
.53548 .05205 L
.53548 .02922 L
s
.53548 .05205 m
.67403 .05205 L
.67403 .08838 L
.53548 .08838 L
.53548 .05205 L
s
.53548 .08838 m
.67403 .08838 L
.67403 .13571 L
.53548 .13571 L
.53548 .08838 L
s
.53548 .13571 m
.67403 .13571 L
.67403 .19084 L
.53548 .19084 L
.53548 .13571 L
s
.53548 .19084 m
.67403 .19084 L
.67403 .25 L
.53548 .25 L
.53548 .19084 L
s
.53548 .25 m
.67403 .25 L
.67403 .30916 L
.53548 .30916 L
.53548 .25 L
s
.53548 .30916 m
.67403 .30916 L
.67403 .36429 L
.53548 .36429 L
.53548 .30916 L
s
.53548 .36429 m
.67403 .36429 L
.67403 .41162 L
.53548 .41162 L
.53548 .36429 L
s
.53548 .41162 m
.67403 .41162 L
.67403 .44795 L
.53548 .44795 L
.53548 .41162 L
s
.53548 .44795 m
.67403 .44795 L
.67403 .47078 L
.53548 .47078 L
.53548 .44795 L
s
.53548 .47078 m
.67403 .47078 L
.67403 .47857 L
.53548 .47857 L
.53548 .47078 L
s
.53548 .37381 m
.67403 .35762 L
.67403 .35395 L
.53548 .36959 L
.53548 .37381 L
s
.53548 .36959 m
.67403 .35395 L
.67403 .3432 L
.53548 .35722 L
.53548 .36959 L
s
.53548 .35722 m
.67403 .3432 L
.67403 .3261 L
.53548 .33755 L
.53548 .35722 L
s
.53548 .33755 m
.67403 .3261 L
.67403 .30381 L
.53548 .3119 L
.53548 .33755 L
s
.53548 .3119 m
.67403 .30381 L
.67403 .27785 L
.53548 .28204 L
.53548 .3119 L
s
.53548 .28204 m
.67403 .27785 L
.67403 .25 L
.53548 .25 L
.53548 .28204 L
s
.53548 .25 m
.67403 .25 L
.67403 .22215 L
.53548 .21796 L
.53548 .25 L
s
.53548 .21796 m
.67403 .22215 L
.67403 .19619 L
.53548 .1881 L
.53548 .21796 L
s
.53548 .1881 m
.67403 .19619 L
.67403 .1739 L
.53548 .16245 L
.53548 .1881 L
s
.53548 .16245 m
.67403 .1739 L
.67403 .1568 L
.53548 .14278 L
.53548 .16245 L
s
.53548 .14278 m
.67403 .1568 L
.67403 .14605 L
.53548 .13041 L
.53548 .14278 L
s
.53548 .13041 m
.67403 .14605 L
.67403 .14238 L
.53548 .12619 L
.53548 .13041 L
s
.53548 .12619 m
.67403 .14238 L
.67403 .14605 L
.53548 .13041 L
.53548 .12619 L
s
.53548 .13041 m
.67403 .14605 L
.67403 .1568 L
.53548 .14278 L
.53548 .13041 L
s
.53548 .14278 m
.67403 .1568 L
.67403 .1739 L
.53548 .16245 L
.53548 .14278 L
s
.53548 .16245 m
.67403 .1739 L
.67403 .19619 L
.53548 .1881 L
.53548 .16245 L
s
.53548 .1881 m
.67403 .19619 L
.67403 .22215 L
.53548 .21796 L
.53548 .1881 L
s
.53548 .21796 m
.67403 .22215 L
.67403 .25 L
.53548 .25 L
.53548 .21796 L
s
.53548 .25 m
.67403 .25 L
.67403 .27785 L
.53548 .28204 L
.53548 .25 L
s
.53548 .28204 m
.67403 .27785 L
.67403 .30381 L
.53548 .3119 L
.53548 .28204 L
s
.53548 .3119 m
.67403 .30381 L
.67403 .3261 L
.53548 .33755 L
.53548 .3119 L
s
.53548 .33755 m
.67403 .3261 L
.67403 .3432 L
.53548 .35722 L
.53548 .33755 L
s
.53548 .35722 m
.67403 .3432 L
.67403 .35395 L
.53548 .36959 L
.53548 .35722 L
s
.53548 .36959 m
.67403 .35395 L
.67403 .35762 L
.53548 .37381 L
.53548 .36959 L
s
.67403 .47857 m
.67364 .35762 L
.67364 .35395 L
.67403 .47078 L
.67403 .47857 L
s
.67403 .47078 m
.67364 .35395 L
.67364 .3432 L
.67403 .44795 L
.67403 .47078 L
s
.67403 .44795 m
.67364 .3432 L
.67364 .3261 L
.67403 .41162 L
.67403 .44795 L
s
.67403 .41162 m
.67364 .3261 L
.67364 .30381 L
.67403 .36429 L
.67403 .41162 L
s
.67403 .36429 m
.67364 .30381 L
.67364 .27785 L
.67403 .30916 L
.67403 .36429 L
s
.67403 .30916 m
.67364 .27785 L
.67364 .25 L
.67403 .25 L
.67403 .30916 L
s
.67403 .25 m
.67364 .25 L
.67364 .22215 L
.67403 .19084 L
.67403 .25 L
s
.67403 .19084 m
.67364 .22215 L
.67364 .19619 L
.67403 .13571 L
.67403 .19084 L
s
.67403 .13571 m
.67364 .19619 L
.67364 .1739 L
.67403 .08838 L
.67403 .13571 L
s
.67403 .08838 m
.67364 .1739 L
.67364 .1568 L
.67403 .05205 L
.67403 .08838 L
s
.67403 .05205 m
.67364 .1568 L
.67364 .14605 L
.67403 .02922 L
.67403 .05205 L
s
.67403 .02922 m
.67364 .14605 L
.67364 .14238 L
.67403 .02143 L
.67403 .02922 L
s
.67403 .02143 m
.67364 .14238 L
.67364 .14605 L
.67403 .02922 L
.67403 .02143 L
s
.67403 .02922 m
.67364 .14605 L
.67364 .1568 L
.67403 .05205 L
.67403 .02922 L
s
.67403 .05205 m
.67364 .1568 L
.67364 .1739 L
.67403 .08838 L
.67403 .05205 L
s
.67403 .08838 m
.67364 .1739 L
.67364 .19619 L
.67403 .13571 L
.67403 .08838 L
s
.67403 .13571 m
.67364 .19619 L
.67364 .22215 L
.67403 .19084 L
.67403 .13571 L
s
.67403 .19084 m
.67364 .22215 L
.67364 .25 L
.67403 .25 L
.67403 .19084 L
s
.67403 .25 m
.67364 .25 L
.67364 .27785 L
.67403 .30916 L
.67403 .25 L
s
.67403 .30916 m
.67364 .27785 L
.67364 .30381 L
.67403 .36429 L
.67403 .30916 L
s
.67403 .36429 m
.67364 .30381 L
.67364 .3261 L
.67403 .41162 L
.67403 .36429 L
s
.67403 .41162 m
.67364 .3261 L
.67364 .3432 L
.67403 .44795 L
.67403 .41162 L
s
.67403 .44795 m
.67364 .3432 L
.67364 .35395 L
.67403 .47078 L
.67403 .44795 L
s
.67403 .47078 m
.67364 .35395 L
.67364 .35762 L
.67403 .47857 L
.67403 .47078 L
s
.97619 .0119 m
.97619 .09127 L
.97619 .17063 L
.97619 .25 L
.97619 .32937 L
.97619 .40873 L
.97619 .4881 L
.97619 .4881 L
.97619 .40873 L
.97619 .32937 L
.97619 .25 L
.97619 .17063 L
.97619 .09127 L
.97619 .0119 L
.97619 .0119 L
s
.97619 .25 m
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
.97619 .25 L
s
.97619 .4881 m
.97619 .47998 L
.97619 .4562 L
.97619 .41836 L
.97619 .36905 L
.97619 .31162 L
.97619 .25 L
.97619 .18838 L
.97619 .13095 L
.97619 .08164 L
.97619 .0438 L
.97619 .02002 L
.97619 .0119 L
.97619 .02002 L
.97619 .0438 L
.97619 .08164 L
.97619 .13095 L
.97619 .18838 L
.97619 .25 L
.97619 .31162 L
.97619 .36905 L
.97619 .41836 L
.97619 .4562 L
.97619 .47998 L
.97619 .4881 L
s
.039 .916 .04 r
.02381 .25 m
.51752 .33705 L
s
0 0 0 r
2.5 Mabswid
.51752 .33705 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51086 .31845 L
s
0 0 0 r
2.5 Mabswid
.51086 .31845 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50594 .30067 L
s
0 0 0 r
2.5 Mabswid
.50594 .30067 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50258 .28348 L
s
0 0 0 r
2.5 Mabswid
.50258 .28348 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50064 .26665 L
s
0 0 0 r
2.5 Mabswid
.50064 .26665 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.5 .25 L
s
0 0 0 r
2.5 Mabswid
.5 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50064 .23335 L
s
0 0 0 r
2.5 Mabswid
.50064 .23335 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50258 .21652 L
s
0 0 0 r
2.5 Mabswid
.50258 .21652 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.50594 .19933 L
s
0 0 0 r
2.5 Mabswid
.50594 .19933 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51086 .18155 L
s
0 0 0 r
2.5 Mabswid
.51086 .18155 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .25 m
.51752 .16295 L
s
0 0 0 r
2.5 Mabswid
.51752 .16295 Mdot
.039 .916 .04 r
.5 Mabswid
.51752 .33705 m
.68333 .3295 L
s
0 0 0 r
2.5 Mabswid
.68333 .3295 Mdot
.039 .916 .04 r
.5 Mabswid
.51086 .31845 m
.68799 .31218 L
s
0 0 0 r
2.5 Mabswid
.68799 .31218 Mdot
.039 .916 .04 r
.5 Mabswid
.50594 .30067 m
.69153 .29607 L
s
0 0 0 r
2.5 Mabswid
.69153 .29607 Mdot
.039 .916 .04 r
.5 Mabswid
.50258 .28348 m
.69409 .28053 L
s
0 0 0 r
2.5 Mabswid
.69409 .28053 Mdot
.039 .916 .04 r
.5 Mabswid
.50064 .26665 m
.69566 .26522 L
s
0 0 0 r
2.5 Mabswid
.69566 .26522 Mdot
.039 .916 .04 r
.5 Mabswid
.5 .25 m
.69619 .25 L
s
0 0 0 r
2.5 Mabswid
.69619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.50064 .23335 m
.69566 .23478 L
s
0 0 0 r
2.5 Mabswid
.69566 .23478 Mdot
.039 .916 .04 r
.5 Mabswid
.50258 .21652 m
.69409 .21947 L
s
0 0 0 r
2.5 Mabswid
.69409 .21947 Mdot
.039 .916 .04 r
.5 Mabswid
.50594 .19933 m
.69153 .20393 L
s
0 0 0 r
2.5 Mabswid
.69153 .20393 Mdot
.039 .916 .04 r
.5 Mabswid
.51086 .18155 m
.68799 .18782 L
s
0 0 0 r
2.5 Mabswid
.68799 .18782 Mdot
.039 .916 .04 r
.5 Mabswid
.51752 .16295 m
.68333 .1705 L
s
0 0 0 r
2.5 Mabswid
.68333 .1705 Mdot
.039 .916 .04 r
.5 Mabswid
.68333 .3295 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.68799 .31218 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69153 .29607 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69409 .28053 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69566 .26522 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69619 .25 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69566 .23478 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69409 .21947 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.69153 .20393 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.68799 .18782 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
.039 .916 .04 r
.5 Mabswid
.68333 .1705 m
.97619 .25 L
s
0 0 0 r
2.5 Mabswid
.97619 .25 Mdot
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{906, 453},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>:0001aB000`400?l00000o`00003ooooooooo
ooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooooooooooooooooon=ooooo`00
ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooooooooooooooooon=
ooooo`00ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooooooooooo
oooooon=ooooo`00ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooo
oooooooooooooomeooooo`;o00005_ooool00?ooooooooooooooooooogGooooo00?o0000oooooooo
ool05Oooool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?oooooooooo
ooooooooogGooooo00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo00?o0000
ooooooooool05Oooool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?oo
ooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo
00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Ooo
ool00?ooooooiOoooomno`000?oooooo4Oooool00ol0003oooooooooo`0Eooooo`00oooooooUoooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo
01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oo
oooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003o
ooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000
ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooogko0000oooooolAooooo`03
o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooU
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooo
oooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3ooooo
o`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo
003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo
3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool0
0?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0
003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOoo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?
ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00
oooooooUooooogko0000oooooolAooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Ooo
ool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool0
0ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000oooooooo
ool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oooooo
iOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooo
ooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0oooo
ool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eoooo
o`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooU
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooo
oooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3ooooo
o`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo
003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3o
ooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooo
ooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000
O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?oo
ool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003o
ooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0E
ooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo
3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003ooooooooo
o`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?oooomoo`000?oooooo4Oooool0
0ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3ooooo
o`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?oo
ool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2
o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003ooooo
onCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eoooo
o`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3o
ooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooo
ooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000
O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?oo
ool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003o
ooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0E
ooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo
3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003ooooooooo
o`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001loooo
o`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o
0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oooooo
i?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo
003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000
ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?oooo
o`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oo
oooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o
0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001l
ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooToooo
o`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oo
ooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Go
oooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooo
ooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?ooooooi?ooool6o`0007Sooooo00?o0000ooooooooool0ooooool?
ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l00004ogmoO`Wo0000Koooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oooooohoooool3o`0000go
Ogmo2Ol0001Vooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00
oooooooSooooo`Oo00004_moOgl9o`0005gooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooon;ooooo00Co0000ogmoOol0003o00001?moOgl9o`0001;oOgmo
2Ol0001Dooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooo
oooRooooo`04o`000?moOgoo0000o`0000goOgmo2?l0000CogmoO`Wo0000Boooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oooooohOooool00ol0003oOgmoogmo
O`02o`0001GoOgmo2?l0000DogmoO`Wo0000@_ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?oooooohOooool00ol0003oOgmoogmoO`02o`0001goOgmo2Ol0000D
ogmoO`Wo0000>Oooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool0
0?oooooohOooool00ol0003oOgmoogmoO`1oo`000?oooooo4Oooool00ol0003oooooooooo`0Eoooo
o`00oooooooPooooo`04o`000?moOgooOgmoogmoO`;o0000;_moOgl8o`0001KoOgmo2Ol0000Woooo
o`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooPooooo`04
o`000?moOgooOgmoogmoO`;o0000=_moOgl9o`0001KoOgmo2Ol0000Nooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooOooooo`03o`000?moOgooOgmo00;o
Ogmo0_l0000oogmoO`So00005omoOgl9o`0001Gooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooomoooooo00?o0000ogmoOomoOgl00_moOgl2o`0004OoOgmo
2?l0000HogmoO`Wo00003?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
5Oooool00?oooooog_ooool00ol0003oOgmoogmoO`03ogmoO`;o0000ComoOgl9o`0001SoOgmo2Ol0
0003ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooN
ooooo`03o`000?moOgooOgmo00?oOgmo0_l0001HogmoO`So00006OmoOgl4o`000?oooooo4Oooool0
0ol0003oooooooooo`0Eooooo`00oooooooMooooo`03o`000?moOgooOgmo00CoOgmo1ol0001Kogmo
O`So00005?moOgl00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oo
oooogOooool00ol0003oOgmoogmoO`04ogmoO`;o00001OmoOgl;o`0005SoOgmo2Ol0000;ogmoO`;o
0000ooooool@ooooo`03o`000?oooooooooo01Gooooo003oooooomcooooo00?o0000ogmoOomoOgl0
1OmoOgl2o`00013oOgmo2_l0001GogmoO`So00000omoOgl2o`000?oooooo4?ooool00ol0003ooooo
ooooo`0Eooooo`00oooooooLooooo`03o`000?moOgooOgmo00GoOgmo0_l0000JogmoO`[o0000EOmo
Ogl5o`000?oooooo4?ooool00ol0003oooooooooo`0Eooooo`00oooooooKooooo`03o`000?moOgoo
Ogmo00KoOgmo0_l0000TogmoO`_o0000COmoOgl00ol0003oOgmoo`00003oooooo`oooooo00?o0000
ooooooooool05Oooool00?oooooofoooool00ol0003oOgmoogmoO`06ogmoO`;o0000;omoOgl:o`00
04?oOgmo00?o0000ogmoOol00000ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooom_o
oooo00?o0000ogmoOomoOgl01_moOgl2o`0003WoOgmo2ol0000hogmoO`03o`000?moOgoo00000?oo
oooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooJooooo`03o`000?moOgooOgmo00OoOgmo
0_l00014ogmoO`[o0000;_moOgl01?l0003oOgmoogmoOol0003oooooo`kooooo00?o0000oooooooo
ool05Oooool00?oooooof_ooool00ol0003oOgmoogmoO`07ogmoO`;o0000C_moOgl;o`0002?oOgmo
00Co0000ogmoOomoOgoo0000ooooool>ooooo`03o`000?oooooooooo01Gooooo003oooooomWooooo
00?o0000ogmoOomoOgl02?moOgl2o`0005WoOgmo2_l0000IogmoO`04o`000?moOgooOgmoo`000?oo
oooo3_ooool00ol0003oooooooooo`0Eooooo`00oooooooIooooo`03o`000?moOgooOgmo00SoOgmo
0_l0001SogmoO`[o00003omoOgl01Ol0003oOgmoogmoOomoOgoo00000?oooooo3Oooool00ol0003o
ooooooooo`0Eooooo`00oooooooHooooo`03o`000?moOgooOgmo00WoOgmo0_l0001]ogmoO`_o0000
1?moOgl01Ol0003oOgmoogmoOomoOgoo00000?oooooo3Oooool00ol0003oooooooooo`0Eooooo`00
oooooooHooooo`03o`000?moOgooOgmo00WoOgmo0_l0001hogmoO`Go00000omoOgl00ol0003ooooo
ooooo`3oooooo`_ooooo00?o0000ooooooooool05Oooool00?ooooooeoooool00ol0003oOgmoogmo
O`0:ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`02ogmoO`03o`000?oooooooooo0?oooooo2_oo
ool00ol0003oooooooooo`0Eooooo`00oooooooGooooo`03o`000?moOgooOgmo00[oOgmo0_l0001l
ogmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooo
oooo01Gooooo003oooooomKooooo00?o0000ogmoOomoOgl02omoOgl2o`0007coOgmo00?o0000ogmo
OomoOgl00_moOgl00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool05Oooool00?oo
ooooe_ooool00ol0003oOgmoogmoO`0;ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`03ogmoO`03
o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`0Eooooo`00oooooooFooooo`03o`00
0?moOgooOgmo00_oOgmo2?l0001fogmoO`03o`000?moOgooOgmo00?oOgmo00?o0000ooooooooool0
ooooool9ooooo`03o`000?oooooooooo01Gooooo003oooooom;ooooo0_l9jPX00ol0003o2NX:o`WZ
2P0:o`WZ2P?oOgmo0_l00006ogmoO`_o0000JomoOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oo
oooooooo0?oooooo2Oooool00ol0003oooooooooo`0Eooooo`00ooooooo<ooooo`Ko2NX:0_ooool2
o`0000_oOgmo5Ol9jPX00omoOgoo0000o`000009o`00063oOgmo00?o0000ogmoOomoOgl01?moOgl0
0ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool05Oooool00?ooooooaoooool5o`WZ
2PSooooo00?o0000ogmoOomoOgl03OmoOgl2o`00013oOgmo5_l9jPX2o`0005CoOgmo00?o0000ogmo
OomoOgl01?moOgl00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool05Oooool00?oo
oooo`Oooool6o`WZ2Pgooooo00?o0000ogmoOomoOgl03OmoOgl2o`0002KoOgmo5Ol9jPY1ogmoO`03
o`000?moOgooOgmo00CoOgmo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo01Go
oooo003ooooook_ooooo1_l9jPXBooooo`03o`000?moOgooOgmo00koOgmo0_l0000cogmoO`So0000
5Ol9jPX/ogmoO`03o`000?moOgooOgmo00GoOgmo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo01Gooooo003ooooookKooooo1Ol9jPXHooooo`03o`000?moOgooOgmo00koOgmo0_l0
000oogmoO`_o00001_moOglFo`WZ2QKoOgmo00?o0000ogmoOomoOgl01OmoOgl00ol0003ooooooooo
o`3oooooo`Oooooo00?o0000ooooooooool05Oooool00?oooooo/?ooool6o`WZ2Qgooooo00?o0000
ogmoOomoOgl03_moOgl2o`0004[oOgmo2ol0000AogmoOaGo2NX:00?oOgmoo`000?moOgl01_moOgl2
o`000?oooooo2?ooool00ol0003oooooooooo`0Eooooo`00oooooonZooooo`Ko2NX:8_ooool00ol0
003oOgmoogmoO`0?ogmoO`;o0000EOmoOgl<o`0001[oOgmo2Ol9jPX01?l0003o2NX:o`WZ2_l9jP[o
ooooo`Kooooo00?o0000ooooooooool05Oooool00?ooooooY?ooool6o`WZ2RSooooo00?o0000ogmo
OomoOgl03omoOgl2o`00067oOgmo2ol0000@ogmoO`03o`000?moOgooOgmo00KoOgmo00?o0000oooo
ooooool01?l9jP[oooooo`;ooooo00?o0000ooooooooool05Oooool00?ooooooWoooool5o`WZ2Rko
oooo00?o0000ogmoOomoOgl03omoOgl2o`0006coOgmo2ol00005ogmoO`03o`000?moOgooOgmo00Ko
Ogmo00?o0000ooooooooool01?ooool3o`WZ2_kooooo00?o0000ooooooooool05Oooool00?oooooo
VOooool6o`WZ2S?ooooo00?o0000ogmoOomoOgl03omoOgl2o`0007OoOgmo1_l00009ogmoO`03o`00
0?oooooooooo00Kooooo1?l9jP[jooooo`03o`000?oooooooooo01Gooooo003ooooooi?ooooo1_l9
jPXhooooo`03o`000?moOgooOgmo013oOgmo0_l0001logmoO`03o`000?moOgooOgmo00OoOgmo00?o
0000ooooooooool02_ooool4o`WZ2_Kooooo00?o0000ooooooooool05Oooool00?ooooooS_ooool5
o`WZ2Skooooo00?o0000ogmoOomoOgl04?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl01omoOgl0
0ol0003oooooooooo`0>ooooo`?o2NX:loooool00ol0003oooooooooo`0Eooooo`00oooooon8oooo
o`Ko2NX:@oooool00ol0003oOgmoogmoO`0@ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`08ogmo
O`03o`000?oooooooooo013ooooo1?l9jP[_ooooo`03o`000?oooooooooo01Gooooo003ooooooh;o
oooo1_l9jPY8ooooo`03o`000?moOgooOgmo017oOgmo0_l0001logmoO`03o`000?moOgooOgmo00So
Ogmo00?o0000ooooooooool05?ooool4o`WZ2^_ooooo00?o0000ooooooooool05Oooool00?oooooo
O?ooool6o`WZ2Tkooooo00?o0000ogmoOomoOgl04OmoOgl2o`0007coOgmo00?o0000ogmoOomoOgl0
2?moOgl00ol0003oooooooooo`0Hooooo`Co2NX:ioooool00ol0003oooooooooo`0Eooooo`00oooo
oomgooooo`Go2NX:D_ooool3o`0001?oOgmo0_l0001logmoO`03o`000?moOgooOgmo00SoOgmo00?o
0000ooooooooool07?ooool3o`WZ2^Cooooo00?o0000ooooooooool05Oooool00?ooooooLOooool6
o`WZ2UCooooo0ol9jPX00ol0003o2NX:o`WZ2P0?o`WZ2PCoOgmo0_l0001logmoO`03o`000?moOgoo
Ogmo00WoOgmo00?o0000ooooooooool07_ooool4o`WZ2^3ooooo00?o0000ooooooooool05Oooool0
0?ooooooJoooool6o`WZ2U?ooooo1ol9jPX4ooooo`03o`000?moOgooOgmo00koOgmo8?l9jPYRogmo
O`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool08_ooool4o`WZ2]cooooo00?o0000oooo
ooooool05Oooool00?ooooooIOooool6o`WZ2U;ooooo1ol9jPX;ooooo`03o`000?moOgooOgmo01;o
Ogmo0_l0000JogmoOb3o2NX:@_moOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo02Ko
oooo0ol9jP[Iooooo`03o`000?oooooooooo01Gooooo003oooooof3ooooo1Ol9jPYAooooo`Oo2NX:
4_ooool00ol0003oOgmoogmoO`0BogmoO`;o0000>_moOglPo`WZ2R;oOgmo00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oooooooooo`0Yooooo`Co2NX:eOooool00ol0003oooooooooo`0Eooooo`00oooo
oomJooooo`Ko2NX:Coooool7o`WZ2QWooooo00?o0000ogmoOomoOgl04_moOgl2o`0005[oOgmo8?l9
jPX2ogmoO`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool0;Oooool4o`WZ2]7ooooo00?o
0000ooooooooool05Oooool00?ooooooE?ooool6o`WZ2Tgooooo2?l9jPXOooooo`03o`000?moOgoo
Ogmo01?oOgmo0_l0001jogmoO`ko2NX:00Co0000o`WZ2_l9jP[o2NX:<?ooool4o`WZ2/gooooo00?o
0000ooooooooool05Oooool00?ooooooCoooool5o`WZ2Tcooooo1ol9jPXWooooo`03o`000?moOgoo
Ogmo01?oOgmo2ol0001cogmoO`03o`000?moOgooOgmo00WoOgmo0_l00002ooooo`Go2NX:;oooool3
o`WZ2/[ooooo00?o0000ooooooooool05Oooool00?ooooooBOooool6o`WZ2T[ooooo1ol9jPX^oooo
o`03o`000?moOgooOgmo01?oOgmo0_l00009ogmoOa;o0000HOmoOgl00ol0003oOgmoogmoO`0:ogmo
O`03o`000?oooooooooo00Gooooo1Ol9jPX]ooooo`Co2NX:a_ooool00ol0003oooooooooo`0Eoooo
o`00oooooom3ooooo`Ko2NX:BOooool7o`WZ2SCooooo00?o0000ogmoOomoOgl05?moOgmoo`0000co
Ogmo00?o0000ooooooooool02_ooool4o`WZ2Rgooooo1?l9jP[2ooooo`03o`000?oooooooooo01Go
oooo003oooooocgooooo1_l9jPY7ooooo`So2NX:>oooool00ol0003oOgmoogmoO`0DogmoO`;o0000
;OmoOglBo`0003goOgmo00?o0000ogmoOomoOgl02omoOgl00ol0003oooooooooo`0=ooooo`Go2NX:
;?ooool4o`WZ2[kooooo00?o0000ooooooooool05Oooool00?oooooo>?ooool5o`WZ2TKooooo1ol9
jPY3ooooo`03o`000?moOgooOgmo01CoOgmo0_l0000oogmoOa7o0000;?moOgl00ol0003oOgmoogmo
O`0;ogmoO`03o`000?oooooooooo01;ooooo1Ol9jPX[ooooo`?o2NX:^oooool00ol0003ooooooooo
o`0Eooooo`00oooooolbooooo`Ko2NX:A?ooool7o`WZ2T[ooooo00?o0000ogmoOomoOgl05?moOgl2
o`00053oOgmo4_l0000JogmoO`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool05oooool4
o`WZ2R[ooooo1?l9jPZgooooo`03o`000?oooooooooo01Gooooo003oooooobcooooo1_l9jPY3oooo
o`Oo2NX:D?ooool00ol0003oOgmoogmoO`0EogmoO`;o0000H_moOglBo`0000SoOgmo00?o0000ogmo
OomoOgl02omoOgl00ol0003oooooooooo`0Kooooo`Go2NX::Oooool4o`WZ2[?ooooo00?o0000oooo
ooooool05Oooool00?oooooo9oooool5o`WZ2T;ooooo1ol9jPYGooooo`03o`000?moOgooOgmo01Go
Ogmo0_l0001dogmoO`Wo00003OmoOgl00ol0003oooooooooo`0Pooooo`Co2NX::Oooool3o`WZ2[3o
oooo00?o0000ooooooooool05Oooool00?oooooo8Oooool6o`WZ2Soooooo2?l9jPYNooooo`03o`00
0?moOgooOgmo01GoOgmo0_l0001logmoO`03o`000?moOgooOgmo00coOgmo00?o0000ooooooooool0
8oooool5o`WZ2ROooooo1?l9jPZ/ooooo`03o`000?oooooooooo01Gooooo003ooooooa_ooooo1_l9
jPXnooooo`Oo2NX:I?ooool3o`0001OoOgmo0_l0001logmoO`03o`000?moOgooOgmo00coOgmo00?o
0000ooooooooool0:?ooool5o`WZ2RKooooo1?l9jPZXooooo`03o`000?oooooooooo01Gooooo003o
oooooaGooooo1_l9jPXmooooo`Oo2NX:I_oooolKo`WZ2PCoOgmo0_l0001logmoO`03o`000?moOgoo
Ogmo00coOgmo00?o0000ooooooooool0;Oooool4o`WZ2RKooooo1?l9jPZTooooo`03o`000?oooooo
oooo01Gooooo003ooooooa3ooooo1Ol9jPXlooooo`Oo2NX:Hoooool:o`WZ2PKooooo00?o0000ogmo
OomoOgl04_moOglZo`WZ2USoOgmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`0aoooo
o`Go2NX:9Oooool3o`WZ2Z7ooooo00?o0000ooooooooool05Oooool00?oooooo2_ooool6o`WZ2S[o
oooo1ol9jPYQooooo`Wo2NX:4?ooool00ol0003oOgmoogmoO`0FogmoO`;o00009?moOglZo`WZ2Rko
Ogmo00?o0000ogmoOomoOgl03?moOgl00ol0003oooooooooo`0fooooo`Go2NX:8oooool4o`WZ2Ygo
oooo00?o0000ooooooooool05Oooool00?oooooo1?ooool6o`WZ2SSooooo2?l9jPYNooooo`[o2NX:
6?ooool00ol0003oOgmoogmoO`0GogmoO`;o0000C_moOglZo`WZ2PCoOgmo00?o0000ogmoOomoOgl0
3OmoOgl00ol0003oooooooooo`0jooooo`Co2NX:8oooool4o`WZ2YWooooo00?o0000ooooooooool0
5Oooool00?kooooo1Ol9jPXgooooo`Oo2NX:G?ooool:o`WZ2R;ooooo00?o0000ogmoOomoOgl05omo
Ogl2o`0007SoOgmo4ol9jPX00ol0003o2NX:o`WZ2P02o`WZ2Sgooooo1Ol9jPXRooooo`?o2NX:U_oo
ool00ol0003oooooooooo`0Eooooo`00n?ooool6o`WZ2SGooooo1ol9jPYJooooo`Wo2NX:;?ooool0
0ol0003oOgmoogmoO`0GogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0<ogmoO`;o00000oooool6
o`WZ2Scooooo1Ol9jPXPooooo`Co2NX:T_ooool00ol0003oooooooooo`0Eooooo`00l_ooool6o`WZ
2SCooooo1ol9jPYGooooo`[o2NX:=Oooool00ol0003oOgmoogmoO`0GogmoO`;o0000O?moOgl00ol0
003oOgmoogmoO`0=ogmoO`03o`000?oooooooooo00Oooooo1ol9jPXjooooo`Co2NX:8?ooool4o`WZ
2Xkooooo00?o0000ooooooooool05Oooool00>cooooo1_l9jPXbooooo`So2NX:E?ooool:o`WZ2Sko
oooo00?o0000ogmoOomoOgl06?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003o
ooooooooo`0=ooooo`Ko2NX:>?ooool5o`WZ2Qoooooo1?l9jPZ:ooooo`03o`000?oooooooooo01Go
oooo003Wooooo`Go2NX:<Oooool7o`WZ2U?ooooo2Ol9jPY8ooooo`03o`000?moOgooOgmo01SoOgmo
0_l0001logmoO`03o`000?moOgooOgmo00koOgmo00?o0000ooooooooool04oooool6o`WZ2SOooooo
1Ol9jPXNooooo`?o2NX:Qoooool00ol0003oooooooooo`0Eooooo`00hOooool6o`WZ2Roooooo1ol9
jPY@ooooo`[o2NX:DOooool00ol0003oOgmoogmoO`0HogmoO`;o0000O?moOgl00ol0003oOgmoogmo
O`0>ogmoO`03o`000?oooooooooo01Wooooo1_l9jPXfooooo`Co2NX:7Oooool4o`WZ2X?ooooo00?o
0000ooooooooool05Oooool00=_ooooo1_l9jPX^ooooo`Oo2NX:COooool:o`WZ2U_ooooo00?o0000
ogmoOomoOgl06?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`0O
ooooo`Oo2NX:<oooool5o`WZ2Qcooooo1?l9jPYoooooo`03o`000?oooooooooo01Gooooo003Foooo
o`Go2NX:;Oooool7o`WZ2T_ooooo2Ol9jPYUooooo`03o`000?moOgooOgmo01SoOgmo0_l0001logmo
O`03o`000?moOgooOgmo00koOgmo00?o0000ooooooooool09_ooool6o`WZ2S;ooooo1?l9jPXLoooo
o`?o2NX:O?ooool00ol0003oooooooooo`0Eooooo`00d?ooool6o`WZ2R[ooooo2?l9jPY8ooooo`[o
2NX:K_ooool00ol0003oOgmoogmoO`0HogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?oooooooooo02_ooooo1_l9jPX`ooooo`Go2NX:6_ooool4o`WZ2WSooooo00?o0000oooooooo
ool05Oooool00<[ooooo1_l9jPXYooooo`Oo2NX:A_ooool:o`WZ2WSooooo00?o0000ogmoOomoOgl0
6?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`0aooooo`Oo2NX:
;_ooool5o`WZ2QWooooo1?l9jPYdooooo`03o`000?oooooooooo01Gooooo0034ooooo`Ko2NX::?oo
ool7o`WZ2TCooooo2Ol9jPZ1ooooo`03o`000?moOgooOgmo01WoOgmo0_l0001logmoO`03o`000?mo
OgooOgmo00ooOgmo00?o0000ooooooooool0>?ooool6o`WZ2Rgooooo1?l9jPXIooooo`Co2NX:L?oo
ool00ol0003oooooooooo`0Eooooo`00_oooool5o`WZ2ROooooo1ol9jPY1ooooo`[o2NX:P_oooolU
o`WZ2P03o`000?moOgooOgmo07[oOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`0n
ooooo`Ko2NX::oooool5o`WZ2QSooooo0ol9jPY]ooooo`03o`000?oooooooooo01Gooooo002ioooo
o`Ko2NX:9Oooool7o`WZ2Skooooo2_l9jPYmooooo`oo2NX:1oooool2o`0001_oOgmo00?o0000o`WZ
2_l9jPX0>?l9jPY3ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0A?ooool6o`WZ
2R[ooooo1Ol9jPXFooooo`Co2NX:JOooool00ol0003oooooooooo`0Eooooo`00/oooool6o`WZ2R?o
oooo2?l9jPXlooooo`Wo2NX:NOooool>o`WZ2QOooooo00?o0000ogmoOomoOgl06OmoOglGo`0002Co
Ogmo>Ol9jPX:ogmoO`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0B_ooool7o`WZ2RSo
oooo1?l9jPXFooooo`Co2NX:IOooool00ol0003oooooooooo`0Eooooo`00[_ooool5o`WZ2R;ooooo
1ol9jPXjooooo`[o2NX:M?ooool>o`WZ2RGooooo00?o0000ogmoOomoOgl06OmoOgl2o`0001GoOgmo
:_l0000cogmoOb;o2NX:C_ooool6o`WZ2RKooooo1Ol9jPXEooooo`?o2NX:H_ooool00ol0003ooooo
ooooo`0Eooooo`00Z?ooool6o`WZ2R3ooooo1ol9jPXgooooo`[o2NX:Koooool?o`WZ2S?ooooo00?o
0000ogmoOomoOgl06OmoOgl2o`0003ooOgmo:Ol0000DogmoO`03o`000?moOgooOgmo00ooOgmo0_l0
0004ooooo`Wo2NX:Boooool6o`WZ2RGooooo1Ol9jPXCooooo`Co2NX:G_ooool00ol0003ooooooooo
o`0Eooooo`00X_ooool6o`WZ2Qoooooo1ol9jPXeooooo`Wo2NX:Joooool>o`WZ2T;ooooo00?o0000
ogmoOomoOgl06OmoOgl2o`0006SoOgmo5Ol0000AogmoO`03o`000?oooooooooo00cooooo2_l9jPY7
ooooo`Ko2NX:9?ooool4o`WZ2Q?ooooo1?l9jPYJooooo`03o`000?oooooooooo01Gooooo002Loooo
o`Ko2NX:7_ooool7o`WZ2S;ooooo2_l9jPYUooooo`oo2NX:D?ooool00ol0003oOgmoogmoO`0Iogmo
O`;o0000O?moOgl00ol0003oOgmoogmoO`0?ogmoO`03o`000?oooooooooo01Kooooo2Ol9jPY4oooo
o`Oo2NX:8Oooool5o`WZ2Q;ooooo1?l9jPYFooooo`03o`000?oooooooooo01Gooooo002Gooooo`Go
2NX:7?ooool8o`WZ2Roooooo2_l9jPYQooooo`ko2NX:Goooool00ol0003oOgmoogmoO`0IogmoO`;o
0000O?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo01kooooo2_l9jPY1ooooo`Ko
2NX:8?ooool5o`WZ2Q7ooooo0ol9jPYCooooo`03o`000?oooooooooo01Gooooo002Aooooo`Ko2NX:
6_ooool7o`WZ2Rkooooo2Ol9jPYMooooo`ko2NX:K?ooool00ol0003oOgmoogmoO`0JogmoO`;o0000
O?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo02Sooooo2Ol9jPXnooooo`Ko2NX:
7oooool4o`WZ2Q3ooooo1?l9jPY?ooooo`03o`000?oooooooooo01Gooooo002;ooooo`Ko2NX:6Ooo
ool7o`WZ2R_ooooo2_l9jPYGooooo`oo2NX:N_ooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?mo
Ogl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo037ooooo2Ol9jPXkooooo`Oo2NX:7?oo
ool5o`WZ2Poooooo1?l9jPY;ooooo`03o`000?oooooooooo01Gooooo0025ooooo`Ko2NX:6?ooool7
o`WZ2RSooooo2_l9jPYCooooo`ko2NX:ROooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?moOgl0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo03[ooooo2_l9jPXhooooo`Ko2NX:6oooool4
o`WZ2Poooooo0ol9jPY8ooooo`03o`000?oooooooooo01Gooooo0020ooooo`Go2NX:5_ooool8o`WZ
2RKooooo2Ol9jPY>ooooo`oo2NX:Uoooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?moOgl00ol0
003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo04Cooooo2Ol9jPXeooooo`Ko2NX:6Oooool5o`WZ
2Pgooooo1?l9jPY4ooooo`03o`000?oooooooooo01Gooooo001jooooo`Ko2NX:5?ooool7o`WZ2RCo
oooo2_l9jPY9ooooo`ko2NX:Y_ooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?moOgl00ol0003o
OgmoogmoO`0@ogmoO`03o`000?oooooooooo04gooooo2_l9jPXaooooo`Ko2NX:6?ooool5o`WZ2Pco
oooo1?l9jPY0ooooo`03o`000?oooooooooo01Gooooo001dooooo`Ko2NX:4oooool7o`WZ2R7ooooo
2_l9jPY5ooooo`ko2NX:]?ooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?moOgl00ol0003oOgmo
ogmoO`0@ogmoO`03o`000?oooooooooo05Oooooo2Ol9jPX^ooooo`Oo2NX:5_ooool4o`WZ2Pcooooo
1?l9jPXlooooo`03o`000?oooooooooo01Gooooo001_ooooo`Go2NX:4_ooool7o`WZ2Qoooooo2Ol9
jPY0ooooo`oo2NX:`_ooool00ol0003oOgmoogmoO`0JogmoO`;o0000O?moOgl00ol0003oOgmoogmo
O`0@ogmoO`03o`000?oooooooooo063ooooo2_l9jPX[ooooo`Ko2NX:5?ooool5o`WZ2P_ooooo0ol9
jPXiooooo`03o`000?oooooooooo01Gooooo001Yooooo`Ko2NX:4?ooool7o`WZ2Qcooooo2_l9jPXk
ooooo`ko2NX:`_ooool=o`WZ2P03o`000?l9jP[o2NX:02_o2NX:KomoOgl00ol0003oOgmoogmoO`0@
ogmoO`03o`000?oooooooooo06[ooooo2Ol9jPXXooooo`Ko2NX:4oooool5o`WZ2PWooooo1?l9jPXe
ooooo`03o`000?oooooooooo01Gooooo001Sooooo`Ko2NX:3_ooool8o`WZ2QWooooo2_l9jPXfoooo
o`oo2NX:/ooooolMo`WZ2Pgooooo0ol0000LogmoO`;o00003OmoOgmHo`WZ2QOoOgmo00?o0000ogmo
OomoOgl04?moOgl2o`0007Cooooo2_l9jPXTooooo`Ko2NX:4_ooool4o`WZ2PWooooo1?l9jPXaoooo
o`03o`000?oooooooooo01Gooooo001Mooooo`Ko2NX:3Oooool7o`WZ2QSooooo2Ol9jPXbooooo`ko
2NX:YOoooolMo`WZ2R_ooooo00?o0000ogmoOomoOgl06omoOgl2o`0006GoOgmo:_l9jPX00ol0003o
2NX:o`WZ2P09o`WZ2WCooooo2Ol9jPXQooooo`Oo2NX:3oooool5o`WZ2PSooooo1?l9jPX]ooooo`03
o`000?oooooooooo01Gooooo001Hooooo`Go2NX:3?ooool7o`WZ2QGooooo2_l9jPX]ooooo`ko2NX:
U_oooolMo`WZ2TSooooo00?o0000ogmoOomoOgl06omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl0
4?moOgl00ol0003oooooooooo`09oooooa?o2NX:J_ooool9o`WZ2Qoooooo1_l9jPX>ooooo`Go2NX:
1oooool3o`WZ2R[ooooo00?o0000ooooooooool05Oooool005;ooooo1_l9jPX:ooooo`Oo2NX:4_oo
ool:o`WZ2RSooooo3ol9jPZ8oooooaco2NX:IOooool00ol0003oOgmoogmoO`0KogmoO`;o0000O?mo
Ogl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo01cooooo5?l9jPYOooooo`[o2NX:6ooo
ool6o`WZ2Pgooooo1?l9jPX6ooooo`Co2NX:9_ooool00ol0003oooooooooo`0Eooooo`00C?ooool6
o`WZ2PWooooo1ol9jPX@ooooo`Wo2NX:9?ooool>o`WZ2W[ooooo7Ol9jPZ1ooooo`03o`000?moOgoo
Ogmo01_oOgmo0_l0001logmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool0<?oooolC
o`WZ2UKooooo2Ol9jPXHooooo`Ko2NX:2oooool5o`WZ2PGooooo1?l9jPXRooooo`03o`000?oooooo
oooo01Gooooo0017ooooo`Go2NX:1oooool8o`WZ2Pgooooo2_l9jPXNooooo`oo2NX:JooooolMo`WZ
2Ykooooo00?o0000ogmoOomoOgl06omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl00ol0
003oooooooooo`13oooooaCo2NX:Boooool:o`WZ2QCooooo1ol9jPX9ooooo`Go2NX:1?ooool3o`WZ
2Qoooooo00?o0000ooooooooool05Oooool0047ooooo1_l9jPX5ooooo`Oo2NX:2oooool:o`WZ2Q[o
oooo3_l9jPYMoooooago2NX:^oooool00ol0003oOgmoogmoO`0KogmoO`;o0000O?moOgl00ol0003o
OgmoogmoO`0@ogmoO`03o`000?oooooooooo05Oooooo4ol9jPY2ooooo`Wo2NX:4_ooool6o`WZ2PSo
oooo1?l9jPX3ooooo`Co2NX:6oooool00ol0003oooooooooo`0Eooooo`00>oooool6o`WZ2PCooooo
1ol9jPX9ooooo`Wo2NX:5_ooool>o`WZ2Toooooo7?l9jP[Hooooo`03o`000?moOgooOgmo01_oOgmo
0_l0001logmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0JOoooolDo`WZ2SOooooo
2_l9jPX>ooooo`Ko2NX:1_ooool5o`WZ2P;ooooo1?l9jPXGooooo`03o`000?oooooooooo01Gooooo
000eooooo`Ko2NX:0oooool7o`WZ2PKooooo2_l9jPX@ooooo`oo2NX:@?oooolMo`WZ2_Cooooo00?o
0000ogmoOomoOgl06omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003ooooooooo
o`1moooooa?o2NX:;_ooool9o`WZ2P_ooooo1ol9jPX4ooooo`Co2NX:0_ooool4o`WZ2Q?ooooo00?o
0000ooooooooool05Oooool0033ooooo1Ol9jPX00ooooooo2NX:o`WZ2P06o`WZ2P?ooooo2_l9jPX<
ooooo`ko2NX:<_oooolMo`WZ2_oooooo4_ooool00ol0003oOgmoogmoO`0KogmoO`;o0000O?moOgl0
0ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo093ooooo4ol9jPXTooooo`[o2NX:2?ooool6
o`WZ2P;ooooo1Ol9jPX01?oooooo2NX:o`WZ2_l9jPX@ooooo`03o`000?oooooooooo01Gooooo000Z
ooooo`co2NX:0_ooool9o`WZ2POooooo3ol9jPXToooooaco2NX:ooooool^ooooo`03o`000?moOgoo
Ogmo01coOgmo0_l0001logmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0XooooolD
o`WZ2Q[ooooo2Ol9jPX5ooooo`Ko2NX:00?oooooo`WZ2_l9jPX01_l9jPX<ooooo`03o`000?oooooo
oooo01Gooooo000ToooooaCo2NX:0_ooool>o`WZ2QKooooo7Ol9jP[ooooood[ooooo00?o0000ogmo
OomoOgl07?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0003oooooooooo`2goooo
oa?o2NX:4?ooool9o`WZ2P;ooooo3Ol9jPX8ooooo`03o`000?oooooooooo01Gooooo000Ooooooa_o
2NX:1ooooolMo`WZ2_ooooooIoooool00ol0003oOgmoogmoO`0LogmoO`;o0000O?moOgl00ol0003o
OgmoogmoO`0AogmoO`03o`000?oooooooooo0<[ooooo5?l9jPX5oooooa;o2NX:1Oooool00ol0003o
ooooooooo`0Eooooo`006OoooolXo`WZ2_ooooooQ?ooool00ol0003oOgmoogmoO`0LogmoO`;o0000
O?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo0=kooooo6ol9jPX00ooooooo0000
ooooo`0Fooooo`005_ooooooo`WZ2Zko2NX:00?o0000o`WZ2_l9jPX0ool9jPZ]o`WZ2P;o00005_oo
ool001[ooooo9Ol9jP[oooooohGooooo0_l0000NogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0A
ogmoO`;o0000h?oooolIo`WZ2P;ooooo0_l0000Fooooo`007ooooolKo`WZ2PGooooo6ol9jP[ooooo
of_ooooo00?o0000ogmoOomoOgl07?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04OmoOgl00ol0
003oooooooooo`3=oooooa;o2NX:1?oooolAo`WZ2PKooooo00?o0000ooooooooool05Oooool002Go
oooo4ol9jPX2ooooo`ko2NX:4_oooolKo`WZ2_ooooooD?ooool00ol0003oOgmoogmoO`0LogmoO`;o
0000O?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo0;_ooooo4_l9jPX=ooooo`Wo
2NX:0_ooool<o`WZ2PWooooo00?o0000ooooooooool05Oooool002_ooooo3?l9jPX00ooooooo2NX:
o`WZ2P08o`WZ2PKooooo3_l9jPXOoooooa_o2NX:ooooooleooooo`03o`000?moOgooOgmo01coOgmo
0_l0001logmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0ZOoooolBo`WZ2QKooooo
2Ol9jPX4ooooo`oo2NX:3Oooool00ol0003oooooooooo`0Eooooo`00<?ooool6o`WZ2P03ooooool9
jP[o2NX:00Go2NX:1?ooool9o`WZ2P_ooooo3_l9jPX/oooooa_o2NX:oooooolJooooo`03o`000?mo
OgooOgmo01coOgmo0_l0001logmoO`03o`000?moOgooOgmo017oOgmo00?o0000ooooooooool0Uooo
oolBo`WZ2Qoooooo2Ol9jPX7ooooo`Ko2NX:0oooool4o`WZ2P04ooooool9jP[o2NX:o`WZ2Q7ooooo
00?o0000ooooooooool05Oooool003Kooooo1_l9jPX2ooooo`Oo2NX:1_ooool9o`WZ2Q3ooooo3_l9
jPXioooooa_o2NX:ooooool00ol0003oOgmoogmoO`0KogmoO`;o0000O?moOgl00ol0003oOgmoogmo
O`0AogmoO`03o`000?oooooooooo08Gooooo4_l9jPXXooooo`Wo2NX:2_ooool6o`WZ2PCooooo1Ol9
jPX00ooooooo2NX:o`WZ2P02o`WZ2QCooooo00?o0000ooooooooool05Oooool003cooooo1Ol9jPX4
ooooo`Oo2NX:2?ooool:o`WZ2QCooooo3_l9jPY6oooooa_o2NX:i?ooool00ol0003oOgmoogmoO`0K
ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0AogmoO`03o`000?oooooooooo07;ooooo4ol9jPXa
ooooo`Wo2NX:3Oooool6o`WZ2PKooooo1?l9jPX2ooooo`Co2NX:6?ooool00ol0003oooooooooo`0E
ooooo`00@Oooool6o`WZ2PGooooo1ol9jPX;ooooo`Wo2NX:6Oooool=o`WZ2UCooooo6ol9jP[9oooo
o`03o`000?moOgooOgmo01_oOgmo0_l0001logmoO`03o`000?moOgooOgmo017oOgmo00?o0000oooo
ooooool0H?oooolBo`WZ2S_ooooo2Ol9jPX@ooooo`Ko2NX:1oooool5o`WZ2P?ooooo0ol9jPXLoooo
o`03o`000?oooooooooo01Gooooo0017ooooo`Ko2NX:1_ooool7o`WZ2Pgooooo2_l9jPXLooooo`ko
2NX:HOoooolKo`WZ2Zkooooo00?o0000ogmoOomoOgl06omoOgl2o`0007coOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`1?oooooa;o2NX:@oooool:o`WZ2Q?ooooo1_l9jPX9ooooo`Co
2NX:1?ooool4o`WZ2Qoooooo00?o0000ooooooooool05Oooool004gooooo1Ol9jPX8ooooo`So2NX:
3oooool9o`WZ2R7ooooo3_l9jPY^oooooa_o2NX:Toooool00ol0003oOgmoogmoO`0KogmoO`;o0000
O?moOgl00ol0003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo03gooooo4_l9jPY<ooooo`Wo2NX:
5oooool6o`WZ2P[ooooo1Ol9jPX4ooooo`Co2NX:8oooool00ol0003oooooooooo`0Eooooo`00D_oo
ool6o`WZ2P[ooooo1ol9jPXAooooo`[o2NX:9Oooool>o`WZ2W_ooooo6ol9jPYhooooo`03o`000?mo
OgooOgmo01_oOgmo0_l0001logmoO`03o`000?moOgooOgmo013oOgmo00?o0000ooooooooool0:ooo
oolBo`WZ2UGooooo2Ol9jPXJooooo`Ko2NX:3?ooool4o`WZ2PKooooo0ol9jPXWooooo`03o`000?oo
oooooooo01Gooooo001Hooooo`Ko2NX:2oooool7o`WZ2QCooooo2Ol9jPXZooooo`ko2NX:R?oooolK
o`WZ2Ugooooo00?o0000ogmoOomoOgl06omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl0
0ol0003oooooooooo`0Ioooooa;o2NX:G_ooool9o`WZ2Qgooooo1_l9jPX=ooooo`Go2NX:1_ooool4
o`WZ2R[ooooo00?o0000ooooooooool05Oooool005kooooo1Ol9jPX=ooooo`Oo2NX:5_ooool:o`WZ
2Rkooooo3_l9jPZEoooooa_o2NX:@_ooool00ol0003oOgmoogmoO`0KogmoO`;o0000O?moOgl00ol0
003oOgmoogmoO`0@ogmoO`03o`000?oooooooooo00Oooooo4_l9jPYWooooo`Wo2NX:7oooool7o`WZ
2Pkooooo1Ol9jPX7ooooo`Co2NX:;_ooool00ol0003oooooooooo`0Eooooo`00Hoooool6o`WZ2Pko
oooo1ol9jPXIooooo`Wo2NX:<oooool>o`WZ2Z;ooooo6ol9jPXWooooo`03o`000?moOgooOgmo01_o
Ogmo0_l0001TogmoOb_o2NX:00?o0000o`WZ2_l9jPX01ol9jPY`ooooo`Wo2NX:8_ooool6o`WZ2Q7o
oooo1?l9jPX9ooooo`?o2NX:<_ooool00ol0003oooooooooo`0Eooooo`00JOooool6o`WZ2Poooooo
1ol9jPXKooooo`[o2NX:=oooool>o`WZ2Zoooooo6ol9jPX;ooooo`?o00007?moOgl2o`0000coOgmo
F?l9jPXHogmoO`03o`000?moOgooOgmo013oOgmo0_l0001_ooooo`Wo2NX:9Oooool6o`WZ2Q;ooooo
1Ol9jPX9ooooo`Co2NX:=Oooool00ol0003oooooooooo`0Eooooo`00Koooool5o`WZ2Q7ooooo1ol9
jPXNooooo`Wo2NX:??ooool>o`WZ2[cooooo2ol9jPX00ol0003o2NX:o`WZ2P0Zo`WZ2W3oOgmo00?o
0000ogmoOomoOgl04?moOgl00ol0003oooooooooo`1Uooooo`Wo2NX::?ooool6o`WZ2QCooooo1?l9
jPX:ooooo`Co2NX:>Oooool00ol0003oooooooooo`0Eooooo`00M?ooool6o`WZ2Q;ooooo1ol9jPXP
ooooo`Wo2NX:@Oooool>o`WZ2[_ooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000
ogmoOomoOgl04?moOgl00ol0003oooooooooo`1Looooo`Wo2NX::oooool6o`WZ2QGooooo1Ol9jPX;
ooooo`?o2NX:?Oooool00ol0003oooooooooo`0Eooooo`00N_ooool5o`WZ2QCooooo1ol9jPXRoooo
o`[o2NX:AOooool>o`WZ2Zgooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmo
OomoOgl04?moOgl00ol0003oooooooooo`1Cooooo`Wo2NX:;_ooool6o`WZ2QOooooo1?l9jPX<oooo
o`Co2NX:@?ooool00ol0003oooooooooo`0Eooooo`00Ooooool6o`WZ2QGooooo1ol9jPXUooooo`Wo
2NX:B_ooool>o`WZ2Yoooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomo
Ogl04?moOgl00ol0003oooooooooo`19ooooo`[o2NX:<Oooool6o`WZ2QSooooo1Ol9jPX<ooooo`Co
2NX:A?ooool00ol0003oooooooooo`0Eooooo`00QOooool6o`WZ2QKooooo1ol9jPXWooooo`[o2NX:
C_ooool>o`WZ2Y7ooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomoOgl0
4?moOgl00ol0003oooooooooo`10ooooo`Wo2NX:=Oooool6o`WZ2QWooooo1Ol9jPX>ooooo`?o2NX:
B?ooool00ol0003oooooooooo`0Eooooo`00Roooool5o`WZ2QSooooo2?l9jPXYooooo`Wo2NX:Dooo
ool>o`WZ2X?ooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?mo
Ogl00ol0003oooooooooo`0gooooo`Wo2NX:=oooool7o`WZ2Q_ooooo1?l9jPX?ooooo`Co2NX:Booo
ool00ol0003oooooooooo`0Eooooo`00T?ooool6o`WZ2Q[ooooo1ol9jPX[ooooo`[o2NX:Eoooool>
o`WZ2WGooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl0
0ol0003oooooooooo`0^ooooo`Wo2NX:>_ooool6o`WZ2Qgooooo1Ol9jPX?ooooo`Co2NX:Coooool0
0ol0003oooooooooo`0Eooooo`00U_ooool6o`WZ2Q_ooooo1ol9jPX^ooooo`Wo2NX:G?ooool=o`WZ
2VSooooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl00ol0
003oooooooooo`0Uooooo`Wo2NX:?Oooool6o`WZ2Qoooooo1?l9jPXAooooo`?o2NX:Doooool00ol0
003oooooooooo`0Eooooo`00W?ooool5o`WZ2Qgooooo1ol9jPX`ooooo`[o2NX:Goooool>o`WZ2U[o
oooo00?o0000ogmoOomoOgl06_moOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003o
ooooooooo`0Looooo`Wo2NX:@?ooool6o`WZ2R3ooooo1Ol9jPXAooooo`Co2NX:E_ooool00ol0003o
ooooooooo`0Eooooo`00XOooool6o`WZ2Qkooooo1ol9jPXcooooo`Wo2NX:I?ooool>o`WZ2Tgooooo
00?o0000ogmoOomoOgl06OmoOgl2o`0007coOgmo00?o0000ogmoOomoOgl04?moOgl00ol0003ooooo
ooooo`0Cooooo`Wo2NX:@oooool6o`WZ2R;ooooo1?l9jPXBooooo`Co2NX:F_ooool00ol0003ooooo
ooooo`0Eooooo`00Yoooool6o`WZ2Qoooooo1ol9jPXeooooo`[o2NX:J?ooool>o`WZ2Soooooo00?o
0000ogmoOomoOgl06OmoOgl2o`0006OoOgmo5_l0000AogmoO`03o`000?oooooooooo00_ooooo2Ol9
jPY6ooooo`Ko2NX:8oooool5o`WZ2Q?ooooo0ol9jPYNooooo`03o`000?oooooooooo01Gooooo002]
ooooo`Go2NX:8Oooool7o`WZ2SSooooo2Ol9jPY]ooooo`ko2NX:<Oooool00ol0003oOgmoogmoO`0I
ogmoO`;o0000?OmoOglZo`0001GoOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`02
ooooo`Wo2NX:BOooool6o`WZ2RGooooo1?l9jPXDooooo`Co2NX:HOooool00ol0003oooooooooo`0E
ooooo`00/_ooool6o`WZ2R;ooooo1ol9jPXjooooo`[o2NX:LOooool>o`WZ2R?ooooo00?o0000ogmo
OomoOgl06OmoOgl2o`0001CoOgmo:Ol0000dogmoOb;o2NX:C?ooool6o`WZ2RKooooo1Ol9jPXDoooo
o`Co2NX:IOooool00ol0003oooooooooo`0Eooooo`00^?ooool6o`WZ2R?ooooo1ol9jPXmooooo`Wo
2NX:M_ooool>o`WZ2QGooooo00?o0000ogmoOomoOgl06OmoOglFo`0002?oOgmo>_l9jPX;ogmoO`03
o`000?moOgooOgmo00ooOgmo0_l00018ooooo`Oo2NX:9oooool5o`WZ2QKooooo0ol9jPYYooooo`03
o`000?oooooooooo01Gooooo002nooooo`Go2NX:9Oooool7o`WZ2Soooooo2Ol9jPYkooooo`ko2NX:
1oooool00ol0003oOgmoogmoO`0IogmoOcWo2NX:AOmoOgl00ol0003oOgmoogmoO`0?ogmoO`03o`00
0?oooooooooo047ooooo1_l9jPXZooooo`Co2NX:5oooool4o`WZ2Vcooooo00?o0000ooooooooool0
5Oooool00<?ooooo1_l9jPXVooooo`So2NX:@?ooool:o`WZ2Woooooo8ol9jPX2o`0007coOgmo00?o
0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`0kooooo`Ko2NX::oooool5o`WZ2QOooooo1?l9
jPY`ooooo`03o`000?oooooooooo01Gooooo0039ooooo`Go2NX::Oooool7o`WZ2T?ooooo2Ol9jPYl
ooooo`;o00006omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`0e
ooooo`Ko2NX:;Oooool4o`WZ2QWooooo0ol9jPYdooooo`03o`000?oooooooooo01Gooooo003>oooo
o`Ko2NX::_ooool7o`WZ2TGooooo2_l9jPYcooooo`03o`000?moOgooOgmo01WoOgmo0_l0001logmo
O`03o`000?moOgooOgmo00ooOgmo00?o0000ooooooooool0;oooool6o`WZ2Rkooooo1Ol9jPXIoooo
o`Co2NX:Moooool00ol0003oooooooooo`0Eooooo`00e?ooool6o`WZ2R_ooooo1ol9jPY8ooooo`Wo
2NX:Joooool00ol0003oOgmoogmoO`0HogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0?ogmoO`03
o`000?oooooooooo02Wooooo1_l9jPX`ooooo`Co2NX:6_ooool4o`WZ2W_ooooo00?o0000oooooooo
ool05Oooool00=[ooooo1Ol9jPX]ooooo`Oo2NX:B_ooool:o`WZ2V7ooooo00?o0000ogmoOomoOgl0
6?moOgl2o`0007coOgmo00?o0000ogmoOomoOgl03omoOgl00ol0003oooooooooo`0Sooooo`Ko2NX:
<Oooool5o`WZ2Q_ooooo0ol9jPYoooooo`03o`000?oooooooooo01Gooooo003Oooooo`Ko2NX:;_oo
ool7o`WZ2Tgooooo2Ol9jPYHooooo`03o`000?moOgooOgmo01SoOgmo0_l0001logmoO`03o`000?mo
OgooOgmo00koOgmo00?o0000ooooooooool07_ooool6o`WZ2S?ooooo1?l9jPXLooooo`Co2NX:P_oo
ool00ol0003oooooooooo`0Eooooo`00iOooool6o`WZ2Roooooo1ol9jPY?ooooo`[o2NX:C_ooool0
0ol0003oOgmoogmoO`0HogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooo
oooo01Sooooo1_l9jPXdooooo`Go2NX:7?ooool4o`WZ2XKooooo00?o0000ooooooooool05Oooool0
0>_ooooo1Ol9jPXaooooo`Oo2NX:D_ooool9o`WZ2TGooooo00?o0000ogmoOomoOgl06?moOgl2o`00
07coOgmo00?o0000ogmoOomoOgl03_moOgl00ol0003oooooooooo`0Aooooo`Oo2NX:=Oooool5o`WZ
2Qkooooo0ol9jPZ:ooooo`03o`000?oooooooooo01Gooooo003`ooooo`Ko2NX:<_ooool7o`WZ2UCo
oooo2_l9jPXkooooo`03o`000?moOgooOgmo01SoOgmo0_l0001logmoO`03o`000?moOgooOgmo00ko
Ogmo00?o0000ooooooooool02oooool6o`WZ2SSooooo1?l9jPXOooooo`Co2NX:SOooool00ol0003o
ooooooooo`0Eooooo`00m_ooool6o`WZ2S?ooooo1ol9jPYGooooo`Wo2NX:<_ooool00ol0003oOgmo
ogmoO`0HogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0>ogmoO`03o`000?oooooooooo00Gooooo
1_l9jPXiooooo`Go2NX:7oooool4o`WZ2Y7ooooo00?o0000ooooooooool05Oooool00?cooooo1Ol9
jPXeooooo`So2NX:F?ooool9o`WZ2R[ooooo00?o0000ogmoOomoOgl05omoOgl2o`0007coOgmo00?o
0000ogmoOomoOgl03OmoOgl00ol0003oooooooooo`06o`WZ2S_ooooo1?l9jPXQooooo`?o2NX:UOoo
ool00ol0003oooooooooo`0Eooooo`00ooooool2ooooo`Ko2NX:=oooool7o`WZ2U[ooooo2_l9jPXP
ooooo`03o`000?moOgooOgmo01OoOgmo0_l0001gogmoOaCo2NX:00Co0000o`WZ2_l9jP[o2NX:??oo
ool5o`WZ2R7ooooo1?l9jPZHooooo`03o`000?oooooooooo01Gooooo003oooooo`Sooooo1_l9jPXh
ooooo`Oo2NX:GOooool9o`WZ2QOooooo00?o0000ogmoOomoOgl05omoOgl2o`0004goOgmo:_l9jPX5
ogmoO`03o`000?moOgooOgmo00coOgmo0_l0000jooooo`Co2NX:8_ooool4o`WZ2Ycooooo00?o0000
ooooooooool05Oooool00?oooooo3_ooool5o`WZ2S[ooooo1ol9jPYOooooo`[o2NX:3Oooool00ol0
003oOgmoogmoO`0GogmoO`;o00008omoOglZo`WZ2RooOgmo00?o0000ogmoOomoOgl03OmoOgl00ol0
003oooooooooo`0cooooo`Go2NX:8oooool3o`WZ2Z3ooooo00?o0000ooooooooool05Oooool00?oo
oooo4oooool6o`WZ2S_ooooo1ol9jPYRooooo`Wo2NX:1Oooool00ol0003oOgmoogmoO`0AogmoOb[o
2NX:FOmoOgl00ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo02oooooo1Ol9jPXTooooo`Co
2NX:Xoooool00ol0003oooooooooo`0Eooooo`00oooooolIooooo`Ko2NX:??ooool7o`WZ2VCooooo
6Ol9jPX5ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0<ogmoO`03o`000?oooooooooo02_ooooo
1?l9jPXUooooo`Co2NX:Yoooool00ol0003oooooooooo`0Eooooo`00oooooolOooooo`Go2NX:?_oo
ool7o`WZ2V7ooooo0_l0000HogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`0<ogmoO`03o`000?oo
oooooooo02Kooooo1Ol9jPXVooooo`?o2NX:Zoooool00ol0003oooooooooo`0Eooooo`00oooooolT
ooooo`Ko2NX:?oooool7o`WZ2Ucooooo00?o0000ogmoOomoOgl05OmoOgl2o`0007coOgmo00?o0000
ogmoOomoOgl03?moOgl00ol0003oooooooooo`0Rooooo`Co2NX:9oooool4o`WZ2Zkooooo00?o0000
ooooooooool05Oooool00?oooooo:_ooool5o`WZ2T7ooooo1ol9jPYEooooo`03o`000?moOgooOgmo
01GoOgmo0_l0001cogmoO`[o00003_moOgl00ol0003oooooooooo`0Mooooo`Go2NX:9oooool4o`WZ
2[;ooooo00?o0000ooooooooool05Oooool00?oooooo;oooool6o`WZ2T;ooooo1ol9jPY>ooooo`03
o`000?moOgooOgmo01GoOgmo0_l0001QogmoOa;o00002OmoOgl00ol0003oOgmoogmoO`0;ogmoO`03
o`000?oooooooooo01[ooooo1?l9jPXYooooo`?o2NX:]_ooool00ol0003oooooooooo`0Eooooo`00
ooooooleooooo`Ko2NX:@oooool7o`WZ2TOooooo00?o0000ogmoOomoOgl05OmoOgl2o`0004ooOgmo
4_l0000KogmoO`03o`000?moOgooOgmo00_oOgmo00?o0000ooooooooool05Oooool5o`WZ2RWooooo
1?l9jPZiooooo`03o`000?oooooooooo01Gooooo003ooooooc_ooooo1Ol9jPY5ooooo`So2NX:@?oo
ool00ol0003oOgmoogmoO`0DogmoO`;o0000?OmoOglBo`0002goOgmo00?o0000ogmoOomoOgl02omo
Ogl00ol0003oooooooooo`0Aooooo`Co2NX::_ooool4o`WZ2[gooooo00?o0000ooooooooool05Ooo
ool00?oooooo@?ooool6o`WZ2TOooooo1ol9jPXiooooo`03o`000?moOgooOgmo01CoOgmo0_l0000/
ogmoOa7o0000?omoOgl00ol0003oOgmoogmoO`0;ogmoO`03o`000?oooooooooo00cooooo1Ol9jPX[
ooooo`?o2NX:`Oooool00ol0003oooooooooo`0Eooooo`00oooooom6ooooo`Ko2NX:B?ooool7o`WZ
2S;ooooo00?o0000ogmoOomoOgl05?moOgmoo`0000goOgmo00?o0000ooooooooool01oooool5o`WZ
2Rcooooo1?l9jP[4ooooo`03o`000?oooooooooo01Gooooo003oooooodcooooo1Ol9jPY:ooooo`Oo
2NX::oooool00ol0003oOgmoogmoO`0DogmoO`;o00002?moOglBo`0006;oOgmo00?o0000ogmoOomo
Ogl02_moOgl00ol0003oooooooooo`04ooooo`Co2NX:;Oooool4o`WZ2/Sooooo00?o0000oooooooo
ool05Oooool00?ooooooDOooool6o`WZ2T_ooooo1ol9jPXUooooo`03o`000?moOgooOgmo01?oOgmo
2_l0001dogmoO`03o`000?moOgooOgmo00WoOgmo0_l000000ooooooo2NX:o`WZ2P03o`WZ2Rkooooo
0ol9jP[<ooooo`03o`000?oooooooooo01Gooooo003ooooooeOooooo1_l9jPY<ooooo`Oo2NX:7_oo
ool00ol0003oOgmoogmoO`0CogmoO`;o0000NOmoOgl?o`WZ2P03o`000?l9jP[o2NX:02oooooo1?l9
jP[?ooooo`03o`000?oooooooooo01Gooooo003ooooooegooooo1Ol9jPY>ooooo`Oo2NX:5oooool0
0ol0003oOgmoogmoO`0CogmoO`;o0000FOmoOglPo`WZ2P?oOgmo00?o0000ogmoOomoOgl02_moOgl0
0ol0003oooooooooo`0Zooooo`Co2NX:doooool00ol0003oooooooooo`0Eooooo`00oooooomRoooo
o`Ko2NX:Coooool7o`WZ2Q7ooooo00?o0000ogmoOomoOgl04_moOgl2o`0003WoOgmo8?l9jPXSogmo
O`03o`000?moOgooOgmo00WoOgmo00?o0000ooooooooool0:?ooool3o`WZ2]Oooooo00?o0000oooo
ooooool05Oooool00?ooooooJ?ooool6o`WZ2U3ooooo1ol9jPX:ooooo`03o`000?moOgooOgmo01;o
Ogmo0_l0000IogmoOb3o2NX:@omoOgl00ol0003oOgmoogmoO`09ogmoO`03o`000?oooooooooo02Co
oooo1?l9jP[Jooooo`03o`000?oooooooooo01Gooooo003oooooofkooooo1Ol9jPYBooooo`Oo2NX:
0oooool00ol0003oOgmoogmoO`0=ogmoOb3o2NX:HomoOgl00ol0003oOgmoogmoO`09ogmoO`03o`00
0?oooooooooo023ooooo1?l9jP[Nooooo`03o`000?oooooooooo01Gooooo003oooooog?ooooo1_l9
jPYCooooo`;o2NX:00?o0000o`WZ2_l9jPX03_l9jPX5ogmoO`;o0000O?moOgl00ol0003oOgmoogmo
O`09ogmoO`03o`000?oooooooooo01gooooo0ol9jP[Rooooo`03o`000?oooooooooo01Gooooo003o
ooooogWooooo1Ol9jPY@ooooo`?o00004omoOgl2o`0007coOgmo00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oooooooooo`0Iooooo`Co2NX:iOooool00ol0003oooooooooo`0Eooooo`00oooooomnoooo
o`Ko2NX:C?ooool00ol0003oOgmoogmoO`0AogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`08ogmo
O`03o`000?oooooooooo01Kooooo1?l9jP[Yooooo`03o`000?oooooooooo01Gooooo003oooooohCo
oooo1_l9jPY6ooooo`03o`000?moOgooOgmo017oOgmo0_l0001logmoO`03o`000?moOgooOgmo00So
Ogmo00?o0000ooooooooool04oooool3o`WZ2^gooooo00?o0000ooooooooool05Oooool00?oooooo
R_ooool5o`WZ2T7ooooo00?o0000ogmoOomoOgl04OmoOgl2o`0007coOgmo00?o0000ogmoOomoOgl0
2?moOgl00ol0003oooooooooo`0?ooooo`Co2NX:l?ooool00ol0003oooooooooo`0Eooooo`00oooo
oon?ooooo`Ko2NX:??ooool00ol0003oOgmoogmoO`0@ogmoO`;o0000O?moOgl00ol0003oOgmoogmo
O`07ogmoO`03o`000?oooooooooo00cooooo1?l9jP[dooooo`03o`000?oooooooooo01Gooooo003o
oooooiGooooo1_l9jPXfooooo`03o`000?moOgooOgmo013oOgmo0_l0001logmoO`03o`000?moOgoo
Ogmo00OoOgmo00?o0000ooooooooool02Oooool3o`WZ2_Sooooo00?o0000ooooooooool05Oooool0
0?ooooooVoooool5o`WZ2S7ooooo00?o0000ogmoOomoOgl04?moOgl2o`0007KoOgmo1ol00009ogmo
O`03o`000?oooooooooo00Gooooo1?l9jP[kooooo`03o`000?oooooooooo01Gooooo003ooooooj3o
oooo1_l9jPX/ooooo`03o`000?moOgooOgmo00ooOgmo0_l0001[ogmoO`_o00001_moOgl00ol0003o
OgmoogmoO`06ogmoO`03o`000?oooooooooo00;ooooo1?l9jP[oooooo`03o`000?oooooooooo01Go
oooo003oooooojKooooo1_l9jPXVooooo`03o`000?moOgooOgmo00ooOgmo0_l0001PogmoO`_o0000
4OmoOgl00ol0003oOgmoogmoO`06ogmoO`03o`000?oooooo2NX:00;o2NX:ooooool4ooooo`03o`00
0?oooooooooo01Gooooo003oooooojcooooo1Ol9jPXQooooo`03o`000?moOgooOgmo00ooOgmo0_l0
001DogmoO`co00006_moOgl:o`WZ2P03o`000?l9jP[o2NX:0?oooooo1oooool00ol0003ooooooooo
o`0Eooooo`00oooooonaooooo`Ko2NX:6oooool00ol0003oOgmoogmoO`0?ogmoO`;o0000BOmoOgl;
o`00017oOgmo5Ol9jPX2ogmoO`03o`000?moOgooOgmo00GoOgmo0_l0003oooooo`Sooooo00?o0000
ooooooooool05Oooool00?oooooo]oooool6o`WZ2QKooooo00?o0000ogmoOomoOgl03_moOgl2o`00
03goOgmo3?l00006ogmoOaKo2NX:5omoOgl00ol0003oOgmoogmoO`05ogmoO`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`0Eooooo`00oooooonmooooo`Go2NX:4Oooool00ol0003o
OgmoogmoO`0>ogmoO`;o0000<_moOgl8o`0001Go2NX:;OmoOgl00ol0003oOgmoogmoO`05ogmoO`03
o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`0Eooooo`00ooooooo2ooooo`Ko2NX:
2oooool00ol0003oOgmoogmoO`0>ogmoO`;o00009OmoOglEo`WZ2T;oOgmo00?o0000ogmoOomoOgl0
1?moOgl00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool05Oooool00?oooooob?oo
ool6o`WZ2PKooooo00?o0000ogmoOomoOgl03OmoOgl2o`0000ooOgmo5_l9jPX2o`0005GoOgmo00?o
0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool05Ooo
ool00?ooooooc_ooool5o`WZ2P03ooooool0003oOgmo00[oOgmo5Ol9jPX00omoOgoo0000o`000009
o`00067oOgmo00?o0000ogmoOomoOgl01?moOgl00ol0003oooooooooo`3oooooo`Sooooo00?o0000
ooooooooool05Oooool00?oooooodoooool00ol9jP[o0000o`WZ2P0:o`WZ2PCoOgmo0_l00005ogmo
O`_o0000K?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`000?oooooooooo0?oooooo2Oooool00ol0
003oooooooooo`0Eooooo`00oooooooDooooo`;o00003_moOgl7o`0007OoOgmo00?o0000ogmoOomo
Ogl00omoOgl00ol0003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool05Oooool00?oooooo
e_ooool00ol0003oOgmoogmoO`0;ogmoO`;o0000O?moOgl00ol0003oOgmoogmoO`03ogmoO`03o`00
0?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`0Eooooo`00oooooooFooooo`03o`000?mo
OgooOgmo00_oOgmo0_l0001logmoO`03o`000?moOgooOgmo00;oOgmo00?o0000ooooooooool0oooo
ool:ooooo`03o`000?oooooooooo01Gooooo003oooooomKooooo00?o0000ogmoOomoOgl02omoOgl2
o`0007coOgmo00?o0000ogmoOomoOgl00_moOgl00ol0003oooooooooo`3oooooo`[ooooo00?o0000
ooooooooool05Oooool00?ooooooeoooool00ol0003oOgmoogmoO`0:ogmoO`;o0000O?moOgl00ol0
003oOgmoogmoO`02ogmoO`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0Eoooo
o`00oooooooGooooo`03o`000?moOgooOgmo00[oOgmo0_l0001gogmoO`Ko00000omoOgl00ol0003o
ooooooooo`3oooooo`_ooooo00?o0000ooooooooool05Oooool00?oooooof?ooool00ol0003oOgmo
ogmoO`09ogmoO`;o0000K?moOgl;o`0000GoOgmo00Go0000ogmoOomoOgooOgmoo`00003oooooo`go
oooo00?o0000ooooooooool05Oooool00?oooooof?ooool00ol0003oOgmoogmoO`09ogmoO`;o0000
H_moOgl:o`00013oOgmo00Go0000ogmoOomoOgooOgmoo`00003oooooo`gooooo00?o0000oooooooo
ool05Oooool00?oooooofOooool00ol0003oOgmoogmoO`08ogmoO`;o0000F?moOgl:o`0001[oOgmo
00Co0000ogmoOomoOgoo0000ooooool>ooooo`03o`000?oooooooooo01Gooooo003oooooomWooooo
00?o0000ogmoOomoOgl02?moOgl2o`0004goOgmo2ol0000TogmoO`04o`000?moOgooOgmoo`000?oo
oooo3_ooool00ol0003oooooooooo`0Eooooo`00oooooooJooooo`03o`000?moOgooOgmo00OoOgmo
0_l00013ogmoO`[o0000;omoOgl01?l0003oOgmoogmoOol0003oooooo`kooooo00?o0000oooooooo
ool05Oooool00?oooooof_ooool00ol0003oOgmoogmoO`07ogmoO`;o0000>?moOgl;o`0003WoOgmo
00?o0000ogmoOol00000ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooom_ooooo00?o
0000ogmoOomoOgl01_moOgl2o`0002koOgmo2_l00014ogmoO`03o`000?moOgoo00000?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooKooooo`03o`000?moOgooOgmo00KoOgmo0_l0000S
ogmoO`_o0000C_moOgl00ol0003oOgmoo`00003oooooo`oooooo00?o0000ooooooooool05Oooool0
0?oooooog?ooool00ol0003oOgmoogmoO`05ogmoO`;o00006OmoOgl:o`0005GoOgmo1_l0003ooooo
oa3ooooo00?o0000ooooooooool05Oooool00?oooooog?ooool00ol0003oOgmoogmoO`05ogmoO`;o
00003omoOgl:o`0005KoOgmo2Ol00004ogmoO`;o0000ooooool@ooooo`03o`000?oooooooooo01Go
oooo003oooooomcooooo00?o0000ogmoOomoOgl01OmoOgl2o`0000CoOgmo2ol0001HogmoO`So0000
3OmoOgl2o`000?oooooo4?ooool00ol0003oooooooooo`0Eooooo`00oooooooMooooo`03o`000?mo
OgooOgmo00CoOgmo1_l0001KogmoO`So00005OmoOgl00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?oooooogOooool00ol0003oOgmoogmoO`04ogmoO`;o0000E_moOgl9
o`0001WoOgmo1Ol0003ooooooa7ooooo00?o0000ooooooooool05Oooool00?oooooog_ooool00ol0
003oOgmoogmoO`03ogmoO`;o0000C_moOgl8o`0001WoOgmo2Ol00004ooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooNooooo`03o`000?moOgooOgmo00?o
Ogmo0_l00016ogmoO`So00006?moOgl9o`0000gooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooomoooooo00?o0000ogmoOomoOgl00_moOgl2o`0003goOgmo
2Ol0000GogmoO`Wo00005_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
5Oooool00?oooooogoooool00ol0003oOgmoogmoO`02ogmoO`;o0000=OmoOgl8o`0001OoOgmo2Ol0
000Oooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooP
ooooo`04o`000?moOgooOgmoogmoO`;o0000;OmoOgl8o`0001KoOgmo2Ol0000Xooooo`03o`000?oo
oooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooPooooo`04o`000?moOgoo
OgmoogmoOgoo0000oooooolAooooo`03o`000?oooooooooo01Gooooo003oooooon7ooooo00?o0000
ogmoOomoOgl00_l0000LogmoO`So00005OmoOgl9o`0003[ooooo00?o0000ooooooooool0ooooool?
ooooo`03o`000?oooooooooo01Gooooo003oooooon7ooooo00?o0000ogmoOomoOgl00_l0000Dogmo
O`So00005?moOgl9o`0004?ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo
01Gooooo003oooooon7ooooo00?o0000ogmoOomoOgl00_l0000;ogmoO`Wo00004omoOgl9o`0004co
oooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooon;ooooo
00Co0000ogmoOol0003o00000omoOgl8o`0001?oOgmo2Ol0001Eooooo`03o`000?oooooooooo0?oo
oooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooRooooo`03o`000?moOgoo000000Co0000
4_moOgl9o`0005kooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo
003oooooon?ooooo0ol0000<ogmoO`Wo0000Ioooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?oooooohoooool3o`0000?oOgmo2Ol0001`ooooo`03o`000?oooooo
oooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`Go0000NOooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007co
oooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo
0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooo
oooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Ooo
ool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooo
oooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0
003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oo
oooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0
ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oo
oooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool0
0ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`00
07cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCo
oooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00
oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
5Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oo
oooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool0
0ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3ooooo
o`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?oo
ool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2
o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003ooooo
onCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eoooo
o`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3o
ooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooo
ooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000
O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?oo
ool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003o
ooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0E
ooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo
3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003ooooooooo
o`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCoooooOol0003ooooo
oa7ooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?oo
ool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2
o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003ooooo
onCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eoooo
o`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03o`000?oooooooooo0?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000O?ooool00ol0003oooooooooo`3o
ooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooi?ooool2o`0007cooooo00?o0000oooo
ooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonCooooo0_l0001looooo`03
o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooTooooo`;o0000
O?ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOoo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?
ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00
oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUoooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo
01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oo
oooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003o
ooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000
ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
5Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3ooo
ool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?oo
ooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003o
ooooooooo`0Eooooo`00oooooooUooooogko0000oooooolAooooo`03o`000?oooooooooo01Gooooo
003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooo
oooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGo
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooooooo
ool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo
3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool0
0?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0
003oooooooooo`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOoo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0Eooooo`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?
ooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00
oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`00
0?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUoooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo
01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`3oooooo`oo
oooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooUooooogko0000oooo
oolAooooo`03o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eoooo
o`00oooooooUooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03
o`000?oooooooooo01Gooooo003oooooonGooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool05Oooool00?ooooooiOooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0Eooooo`00oooooooU
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooo
oooo01Gooooo003oooooonGoooooO_l0003ooooooa7ooooo00?o0000ooooooooool05Oooool00?oo
ooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo
00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Ooo
ool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?oooooooooooooooooo
ogGooooo00?o0000ooooooooool05Oooool00?ooooooooooooooooooogGooooo00?o0000oooooooo
ool05Oooool00?ooooooooooooooooooogGooooo00?o0000ooooooooool05Oooool00?oooooooooo
ooooooooogGooooo0_l0000Fooooo`00ooooooooooooooooooooMOooool00ol0003oooooooooo`0E
ooooo`00ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooooooooooo
oooooon=ooooo`00ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo003ooooo
oooooooooooooon=ooooo`00ooooooooooooooooooooSOooool00?ooooooooooooooooooohgooooo
003ooooooooooooooooooon=ooooo`00ooooooooooooooooooooSOooool00001\
\>"],
  ImageRangeCache->{{{0, 905}, {452, 0}} -> {-0.12793, -1.31251, 0.00580759, \
0.00580759}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["SpotSize/.FindSpotSize[bestplot]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00551 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49474 18779.4 0.502754 18779.4 [
[.11915 -0.0125 -24 -9 ]
[.11915 -0.0125 24 0 ]
[.30695 -0.0125 -24 -9 ]
[.30695 -0.0125 24 0 ]
[.49474 -0.0125 -3 -9 ]
[.49474 -0.0125 3 0 ]
[.68253 -0.0125 -21 -9 ]
[.68253 -0.0125 21 0 ]
[.87033 -0.0125 -21 -9 ]
[.87033 -0.0125 21 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12717 -48 -4.5 ]
[-0.0125 .12717 0 4.5 ]
[-0.0125 .31496 -48 -4.5 ]
[-0.0125 .31496 0 4.5 ]
[-0.0125 .50275 -6 -4.5 ]
[-0.0125 .50275 0 4.5 ]
[-0.0125 .69055 -42 -4.5 ]
[-0.0125 .69055 0 4.5 ]
[-0.0125 .87834 -42 -4.5 ]
[-0.0125 .87834 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1.00551 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.00551 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11915 0 m
.11915 .00625 L
s
[(-0.00002)] .11915 -0.0125 0 1 Mshowa
.30695 0 m
.30695 .00625 L
s
[(-0.00001)] .30695 -0.0125 0 1 Mshowa
.49474 0 m
.49474 .00625 L
s
[(0)] .49474 -0.0125 0 1 Mshowa
.68253 0 m
.68253 .00625 L
s
[(0.00001)] .68253 -0.0125 0 1 Mshowa
.87033 0 m
.87033 .00625 L
s
[(0.00002)] .87033 -0.0125 0 1 Mshowa
.125 Mabswid
.15671 0 m
.15671 .00375 L
s
.19427 0 m
.19427 .00375 L
s
.23183 0 m
.23183 .00375 L
s
.26939 0 m
.26939 .00375 L
s
.3445 0 m
.3445 .00375 L
s
.38206 0 m
.38206 .00375 L
s
.41962 0 m
.41962 .00375 L
s
.45718 0 m
.45718 .00375 L
s
.5323 0 m
.5323 .00375 L
s
.56986 0 m
.56986 .00375 L
s
.60742 0 m
.60742 .00375 L
s
.64498 0 m
.64498 .00375 L
s
.72009 0 m
.72009 .00375 L
s
.75765 0 m
.75765 .00375 L
s
.79521 0 m
.79521 .00375 L
s
.83277 0 m
.83277 .00375 L
s
.08159 0 m
.08159 .00375 L
s
.04403 0 m
.04403 .00375 L
s
.00647 0 m
.00647 .00375 L
s
.90789 0 m
.90789 .00375 L
s
.94545 0 m
.94545 .00375 L
s
.98301 0 m
.98301 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12717 m
.00625 .12717 L
s
[(-0.00002)] -0.0125 .12717 1 0 Mshowa
0 .31496 m
.00625 .31496 L
s
[(-0.00001)] -0.0125 .31496 1 0 Mshowa
0 .50275 m
.00625 .50275 L
s
[(0)] -0.0125 .50275 1 0 Mshowa
0 .69055 m
.00625 .69055 L
s
[(0.00001)] -0.0125 .69055 1 0 Mshowa
0 .87834 m
.00625 .87834 L
s
[(0.00002)] -0.0125 .87834 1 0 Mshowa
.125 Mabswid
0 .16472 m
.00375 .16472 L
s
0 .20228 m
.00375 .20228 L
s
0 .23984 m
.00375 .23984 L
s
0 .2774 m
.00375 .2774 L
s
0 .35252 m
.00375 .35252 L
s
0 .39008 m
.00375 .39008 L
s
0 .42764 m
.00375 .42764 L
s
0 .4652 m
.00375 .4652 L
s
0 .54031 m
.00375 .54031 L
s
0 .57787 m
.00375 .57787 L
s
0 .61543 m
.00375 .61543 L
s
0 .65299 m
.00375 .65299 L
s
0 .72811 m
.00375 .72811 L
s
0 .76567 m
.00375 .76567 L
s
0 .80323 m
.00375 .80323 L
s
0 .84078 m
.00375 .84078 L
s
0 .08961 m
.00375 .08961 L
s
0 .05205 m
.00375 .05205 L
s
0 .01449 m
.00375 .01449 L
s
0 .9159 m
.00375 .9159 L
s
0 .95346 m
.00375 .95346 L
s
0 .99102 m
.00375 .99102 L
s
.25 Mabswid
0 0 m
0 1.00551 L
s
.11915 .99926 m
.11915 1.00551 L
s
.30695 .99926 m
.30695 1.00551 L
s
.49474 .99926 m
.49474 1.00551 L
s
.68253 .99926 m
.68253 1.00551 L
s
.87033 .99926 m
.87033 1.00551 L
s
.125 Mabswid
.15671 1.00176 m
.15671 1.00551 L
s
.19427 1.00176 m
.19427 1.00551 L
s
.23183 1.00176 m
.23183 1.00551 L
s
.26939 1.00176 m
.26939 1.00551 L
s
.3445 1.00176 m
.3445 1.00551 L
s
.38206 1.00176 m
.38206 1.00551 L
s
.41962 1.00176 m
.41962 1.00551 L
s
.45718 1.00176 m
.45718 1.00551 L
s
.5323 1.00176 m
.5323 1.00551 L
s
.56986 1.00176 m
.56986 1.00551 L
s
.60742 1.00176 m
.60742 1.00551 L
s
.64498 1.00176 m
.64498 1.00551 L
s
.72009 1.00176 m
.72009 1.00551 L
s
.75765 1.00176 m
.75765 1.00551 L
s
.79521 1.00176 m
.79521 1.00551 L
s
.83277 1.00176 m
.83277 1.00551 L
s
.08159 1.00176 m
.08159 1.00551 L
s
.04403 1.00176 m
.04403 1.00551 L
s
.00647 1.00176 m
.00647 1.00551 L
s
.90789 1.00176 m
.90789 1.00551 L
s
.94545 1.00176 m
.94545 1.00551 L
s
.98301 1.00176 m
.98301 1.00551 L
s
.25 Mabswid
0 1.00551 m
1 1.00551 L
s
.99375 .12717 m
1 .12717 L
s
.99375 .31496 m
1 .31496 L
s
.99375 .50275 m
1 .50275 L
s
.99375 .69055 m
1 .69055 L
s
.99375 .87834 m
1 .87834 L
s
.125 Mabswid
.99625 .16472 m
1 .16472 L
s
.99625 .20228 m
1 .20228 L
s
.99625 .23984 m
1 .23984 L
s
.99625 .2774 m
1 .2774 L
s
.99625 .35252 m
1 .35252 L
s
.99625 .39008 m
1 .39008 L
s
.99625 .42764 m
1 .42764 L
s
.99625 .4652 m
1 .4652 L
s
.99625 .54031 m
1 .54031 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .61543 m
1 .61543 L
s
.99625 .65299 m
1 .65299 L
s
.99625 .72811 m
1 .72811 L
s
.99625 .76567 m
1 .76567 L
s
.99625 .80323 m
1 .80323 L
s
.99625 .84078 m
1 .84078 L
s
.99625 .08961 m
1 .08961 L
s
.99625 .05205 m
1 .05205 L
s
.99625 .01449 m
1 .01449 L
s
.99625 .9159 m
1 .9159 L
s
.99625 .95346 m
1 .95346 L
s
.99625 .99102 m
1 .99102 L
s
.25 Mabswid
1 0 m
1 1.00551 L
s
.039 .916 .04 r
2.5 Mabswid
.49134 .50275 Mdot
.53154 .50275 Mdot
.33845 .50275 Mdot
.81571 .50275 Mdot
.19008 .50275 Mdot
.49474 .50275 Mdot
.7994 .50275 Mdot
.17377 .50275 Mdot
.65103 .50275 Mdot
.45794 .50275 Mdot
.49814 .50275 Mdot
0 0 0 r
.0002 w
.97619 .50275 m
.93457 .69858 L
.81689 .86054 L
.64352 .96064 L
.44441 .98157 L
.25401 .9197 L
.10524 .78574 L
.02381 .60285 L
.02381 .40265 L
.10524 .21976 L
.25401 .08581 L
.44441 .02394 L
.64352 .04487 L
.81689 .14497 L
.93457 .30693 L
.97619 .50275 L
s
0 0 m
1 0 L
1 1.00551 L
0 1.00551 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{286.375, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N00017b000`400?l00000o`00003ooooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolO
ooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00oooooolOooooo`00?_ooool2
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000;ooooo1Ol00005ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0001Gooooo0_l0000Hooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3
o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l00002ooooo`Go00003?ooool003gooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo01?ooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
3?ooool003Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
5_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool03?ooool003gooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
2oooool003gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04oooool01?l0003ooooo
ooooool0000Fooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00[ooooo000mooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`;o00005Oooool01?l0003oooooooooool0000Fooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000Kooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool02_ooool003kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004
ooooo`;o00000oooool3o`0000Kooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004
ooooo`;o00001?ooool00ol0003oooooooooo`0Dooooo`;o00006?ooool2o`0000[ooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l0000:
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0000gooooo003ooooo
oaoooooo003ooooooaoooooo003ooooooaoooooo003ooooooaoooooo000booooonco0000000boooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool1
o`000000<_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool07?ooool1o`000000<_ooool00ol0003oooooooooo`3Xooooo`7o0000000booooo`;o0000
j?ooool2o`000000<_ooool00ol0003oooooooooo`3Xooooo`7o0000000booooo`03o`000?oooooo
oooo06Cooooo2?l0001looooo`7o0000000booooo`03o`000?oooooooooo067ooooo0ol00008oooo
o`Wo0000Loooool1o`000000<_ooool00ol0003oooooooooo`1Nooooo`?o00005?ooool9o`0006[o
oooo0Ol0000003;ooooo00?o0000ooooooooool0Foooool3o`00023ooooo2Ol0001Qooooo`7o0000
000booooo`03o`000?oooooooooo05Sooooo0ol0000/ooooo`Wo0000F?ooool1o`000000<_ooool0
0ol0003oooooooooo`1Dooooo`Co0000>?ooool6o`0005;ooooo0Ol0000003;ooooo0_l0001Boooo
o`?o0000@_ooool2o`0004oooooo0_l0000003;ooooo00?o0000ooooooooool0C_ooool3o`0004Oo
oooo00?o0000ooooooooool0COooool1o`000000<_ooool00ol0003oooooooooo`1;ooooo`?o0000
Boooool2o`0004gooooo0Ol0000003;ooooo00?o0000ooooooooool0Aoooool4o`00053ooooo0_l0
001;ooooo`7o0000000booooo`03o`000?oooooooooo04Cooooo0ol0001Fooooo`;o0000BOooool1
o`000000<_ooool00ol0003oooooooooo`11ooooo`?o0000Foooool2o`0004Oooooo0Ol0000003;o
oooo00?o0000ooooooooool0?_ooool3o`00063ooooo00?o0000ooooooooool0A?ooool1o`000000
<_ooool00ol0003oooooooooo`0kooooo`?o0000I?ooool2o`0004Cooooo0Ol0000003;ooooo00?o
0000ooooooooool0>?ooool3o`0006Wooooo0_l00012ooooo`7o0000000booooo`;o0000>?ooool0
0ol0003oooooooooo`1/ooooo`;o0000?oooool2o`000000<_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo06oooooo0_l0000nooooo`7o0000000booooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0kooooo`7o0000000booooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0M?ooool2o`0003_ooooo0Ol0000003;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`1gooooo`;o0000>Oooool1o`000000<_ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo07[ooooo0_l0000gooooo`7o00000008oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00000_ooool5o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo03Cooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1oooooo`;o0000=?ooool1o`0000001Ol00002ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0P_ooool2o`0003;o
oooo0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00;ooooo0ol0000^ooooo`03o`000?oooooooooo08Gooooo
0_l0000^ooooo`?o00000007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool00000;_ooool2o`0008[o
oooo0_l0000^ooooo`7o00000007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo02_ooooo0Ol0000000Sooooo0_l0000:ooooo`;o
00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0000Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`2>ooooo`;o0000:oooool1o`000000<_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0:?ooool1o`000000<_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0:?oo
ool1o`000000<_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09Cooooo00?o0000
ooooooooool09oooool1o`000000<_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool09_ooool1o`000000<_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool09_ooool1o`000000<_ooool2o`0002Gooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Tooooo`;o0000000booooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Tooooo`7o0000000b
ooooo`03o`000?oooooooooo027ooooo0_l0002Oooooo`03o`000?oooooooooo02?ooooo0Ol00000
03;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo
02?ooooo0Ol0000003;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2Qooooo`03
o`000?oooooooooo02;ooooo0Ol0000003;ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2Sooooo`03o`000?oooooooooo027ooooo0Ol0000003;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo027ooooo0Ol0000003;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo023ooooo0Ol00000
03;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
01oooooo0Ol0000003;ooooo0_l0000Kooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool07Oooool2o`000000<_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0:_ooooo
00?o0000ooooooooool07_ooool1o`000000<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo0:gooooo00?o0000ooooooooool07Oooool1o`000000<_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool07?ooool1o`000000<_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool07?ooool1o`00
0000<_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool06oooool1o`000000<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;?ooooo
00?o0000ooooooooool06_ooool1o`000000<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0;Cooooo00?o0000ooooooooool06Oooool1o`000000<_ooool2o`0001Gooooo00?o0000
ooooooooool0]Oooool00ol0003oooooooooo`0Hooooo`;o0000000booooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0Hooooo`7o0000000booooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`0Gooooo`7o
0000000booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^?ooool00ol0003ooooo
ooooo`0Gooooo`7o0000000booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^Ooo
ool00ol0003oooooooooo`0Fooooo`7o0000000booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0^oooool00ol0003oooooooooo`0Eooooo`7o0000000booooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0Dooooo`7o0000000booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`0Dooooo`7o
0000000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0__ooool00ol0003ooooo
ooooo`0Cooooo`7o0000000booooo`;o00004Oooool00ol0003oooooooooo`30ooooo`03o`000?oo
oooooooo017ooooo0_l0000003;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`30
ooooo`03o`000?oooooooooo01;ooooo0Ol0000003;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`31ooooo`03o`000?oooooooooo017ooooo0Ol0000003;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo013ooooo0Ol0000003;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo00oooooo
0Ol0000003;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`35ooooo`03o`000?oo
oooooooo00oooooo0Ol0000000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool03_ooool1o`0000001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Sooooo00?o0000oooo
ooooool03Oooool1o`0000001Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`0=ooooo`7o00000007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`?o00003?ooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00_ooooo
0ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`3:ooooo`03o`000?oooooooooo00cooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`;o00001Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool03?ooool1o`0000002?ooool2o`00
00[ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
00cooooo0Ol0000003;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo00cooooo0Ol0000003;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00cooooo0Ol0000003;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo00_ooooo0Ol0000003;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo00_ooooo0Ol00000
03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo
00_ooooo0Ol0000003;ooooo0_l0000:ooooo`03o`000?oooooooooo0<kooooo00?o0000oooooooo
ool02_ooool2o`000000<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=3ooooo
00?o0000ooooooooool02_ooool1o`000000<_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0=3ooooo00?o0000ooooooooool02_ooool1o`000000<_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool02_ooool1o`000000<_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool02_ooool1o`00
0000<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=;ooooo00?o0000oooooooo
ool02_ooool1o`000000<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=?ooooo
00?o0000ooooooooool02Oooool1o`000000<_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0=Cooooo00?o0000ooooooooool02Oooool1o`000000<_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool02Oooool1o`000000<_ooool2o`00
00Kooooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`08ooooo`;o0000000booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0eOooool00ol0003oooooooooo`09ooooo`7o
0000000booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0e_ooool00ol0003ooooo
ooooo`08ooooo`7o0000000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0eooo
ool00ol0003oooooooooo`08ooooo`7o0000000booooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0eoooool00ol0003oooooooooo`08ooooo`7o0000000booooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`08ooooo`7o0000000booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`07ooooo`7o
0000000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0f?ooool00ol0003ooooo
ooooo`07ooooo`7o0000000booooo`;o00001?ooool00ol0003oooooooooo`3Hooooo`03o`000?oo
oooooooo00Kooooo0_l0000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3H
ooooo`03o`000?oooooooooo00Oooooo0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3Hooooo`03o`000?oooooooooo00Oooooo0Ol0000003;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo00Kooooo0Ol0000003;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo00Kooooo
0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Iooooo`03o`000?oo
oooooooo00Kooooo0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3I
ooooo`03o`000?oooooooooo00Kooooo0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3Jooooo`03o`000?oooooooooo00Gooooo0Ol0000003;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo00Gooooo0Ol0000003;ooooo
0_l00004ooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool01?ooool2o`000000<_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool01Ooo
ool1o`000000<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=[ooooo00?o0000
ooooooooool01Oooool1o`000000<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0=_ooooo00?o0000ooooooooool01?ooool1o`000000<_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000<_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000;?oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Kooooo`03o`000?oo
oooooooo00Cooooo0Ol0000002_ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000:oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0g?oo
ool00ol0003oooooooooo`03ooooo`7o0000000[ooooo`04o`000?ooooooooooo`0000?ooooo0ol0
0003ooooo`03o`000?oooooooooo01oooooo0_l9jPX2ooooo`;o2NX:8Oooool2o`WZ2Q[ooooo0_l9
jPX6ooooo`?o2NX:1_ooool2o`WZ2Q[ooooo0_l9jPXQooooo`;o2NX:0_ooool2o`WZ2RCooooo00Co
0000oooooooooooooooo0ol0000002_ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01oooooo0_l9jPX2ooooo`;o2NX:8Oooool2o`WZ2Q[ooooo
0_l9jPX6ooooo`?o2NX:1_ooool2o`WZ2Q[ooooo0_l9jPXQooooo`;o2NX:0_ooool2o`WZ2RCooooo
00?o0000ooooooooool00oooool1o`000000:oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0g?ooool00ol0003oooooooooo`03ooooo`7o0000
000/ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=_ooooo00?o
0000ooooooooool01?ooool1o`000000<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000<_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000<_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool01?ooool1o`000000
<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool0
1?ooool1o`000000<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=[ooooo00?o
0000ooooooooool01Oooool1o`000000<_ooool2o`0000Cooooo00?o0000ooooooooool0f_ooool0
0ol0003oooooooooo`04ooooo`;o0000000booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0f_ooool00ol0003oooooooooo`05ooooo`7o0000000booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0f_ooool00ol0003oooooooooo`05ooooo`7o0000000booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`06ooooo`7o0000
000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0fOooool00ol0003ooooooooo
o`06ooooo`7o0000000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0fOooool0
0ol0003oooooooooo`06ooooo`7o0000000booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0fOooool00ol0003oooooooooo`06ooooo`7o0000000booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`06ooooo`7o0000000booooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`07ooooo`7o0000
000booooo`;o00001?ooool00ol0003oooooooooo`3Hooooo`03o`000?oooooooooo00Kooooo0_l0
000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Hooooo`03o`000?oooooo
oooo00Oooooo0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Hoooo
o`03o`000?oooooooooo00Oooooo0Ol0000003;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Hooooo`03o`000?oooooooooo00Oooooo0Ol0000003;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3Gooooo`03o`000?oooooooooo00Sooooo0Ol0000003;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3Gooooo`03o`000?oooooooooo00Sooooo0Ol0
000003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Gooooo`03o`000?oooooo
oooo00Sooooo0Ol0000003;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Foooo
o`03o`000?oooooooooo00Sooooo0Ol0000003;ooooo0_l00005ooooo`03o`000?oooooooooo0=Go
oooo00?o0000ooooooooool02?ooool2o`000000<_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0=Cooooo00?o0000ooooooooool02Oooool1o`000000<_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool02Oooool1o`000000<_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool02Oooool1
o`000000<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=?ooooo00?o0000oooo
ooooool02Oooool1o`000000<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=;o
oooo00?o0000ooooooooool02_ooool1o`000000<_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0=7ooooo00?o0000ooooooooool02_ooool1o`000000<_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool02_ooool1o`000000<_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool02_ooool1
o`000000<_ooool2o`0000Wooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0:oooo
o`;o0000000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0c_ooool00ol0003o
ooooooooo`0;ooooo`7o0000000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
c_ooool00ol0003oooooooooo`0;ooooo`7o0000000booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0c_ooool00ol0003oooooooooo`0;ooooo`7o0000000booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`0;ooooo`7o0000000boooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0<oooo
o`7o00000008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00000oooool3o`0000Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo00cooooo0Ol0000000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo00cooooo
0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`3:ooooo`03o`000?oooooooooo00cooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo0ol0000<
ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooooooool02_ooool3o`0000001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Sooooo00?o0000oooo
ooooool03Oooool1o`0000001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0b?ooool00ol0003oooooooooo`0=ooooo`7o00000008ooooo`;o00002_ooool2o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool03Oooool1o`000000<_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool03_oo
ool1o`000000<_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Gooooo00?o0000
ooooooooool03oooool1o`000000<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0<Cooooo00?o0000ooooooooool03oooool1o`000000<_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0<?ooooo00?o0000ooooooooool04?ooool1o`000000<_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool04Oooool1o`000000<_oo
ool2o`00017ooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0Aooooo`;o0000000b
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0B
ooooo`7o0000000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0__ooool00ol0
003oooooooooo`0Cooooo`7o0000000booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0_Oooool00ol0003oooooooooo`0Dooooo`7o0000000booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0Dooooo`7o0000000booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0Eooooo`7o0000000b
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0F
ooooo`7o0000000booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0^?ooool00ol0
003oooooooooo`0Gooooo`7o0000000booooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0]oooool00ol0003oooooooooo`0Gooooo`7o0000000booooo`;o00005Oooool00ol0003ooooo
ooooo`2fooooo`03o`000?oooooooooo01Oooooo0_l0000003;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo01Wooooo0Ol0000003;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo01Wooooo0Ol00000
03;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo
01[ooooo0Ol0000003;ooooo00?o0000ooooooooool05_ooool2o`000;;ooooo00?o0000oooooooo
ool06oooool1o`000000<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0:kooooo
00?o0000ooooooooool07?ooool1o`000000<_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo0:gooooo00?o0000ooooooooool07?ooool1o`000000<_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool07Oooool1o`000000<_ooool2o`00
01cooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0Mooooo`;o0000000booooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0Nooooo`7o
0000000booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`0Oooooo`7o0000000booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Y?oo
ool00ol0003oooooooooo`0Pooooo`7o0000000booooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0X_ooool00ol0003oooooooooo`0Qooooo`7o0000000booooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0Qooooo`7o0000000booooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`7o
0000000booooo`03o`000?oooooooooo02;ooooo0_l0002Nooooo`03o`000?oooooooooo02?ooooo
0Ol0000003;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo02?ooooo0Ol0000003;ooooo0_l0000Vooooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool08oooool2o`000000<_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool09Oooool1o`000000<_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool09_ooool1o`000000<_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool09_ooool1o`000000<_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool09ooo
ool1o`000000<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08oooooo0_l0000Z
ooooo`7o0000000booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0S?ooool2o`00
02cooooo0Ol0000000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
00001?ooool2o`0000Cooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool0;?ooool1o`0000001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0]ooooo`;o0000R?ooool2o`0002oooooo0Ol0000000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo0ol0000_ooooo`03o`000?oooooooooo08?ooooo0_l0000_ooooo`?o0000
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0P?oo
ool2o`0003?ooooo0Ol0000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo07gooooo0_l0000eooooo`7o00000007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool0
0000=?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo03Gooooo0Ol0000000Sooooo
0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0000Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`1hooooo`;o0000>?ooool1o`000000<_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Gooooo0_l0000jooooo`7o0000000b
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0L_ooool2o`0003cooooo0Ol00000
03;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1_ooooo`;o0000?_ooool1o`00
0000<_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0?_ooool1o`000000<_ooool2o`0003Wooooo00?o0000ooooooooool0J_ooool2o`00043ooooo
0_l0000003;ooooo00?o0000ooooooooool0>Oooool3o`0006Oooooo0_l00013ooooo`7o0000000b
ooooo`03o`000?oooooooooo03cooooo0ol0001Rooooo`;o0000AOooool1o`000000<_ooool00ol0
003oooooooooo`0oooooo`?o0000G_ooool00ol0003oooooooooo`15ooooo`7o0000000booooo`03
o`000?oooooooooo04;ooooo0ol0001Iooooo`;o0000B?ooool1o`000000<_ooool00ol0003ooooo
ooooo`15ooooo`?o0000E?ooool2o`0004[ooooo0Ol0000003;ooooo00?o0000ooooooooool0B?oo
ool4o`0004kooooo0_l0001<ooooo`7o0000000booooo`03o`000?oooooooooo04cooooo0ol00019
ooooo`;o0000C_ooool1o`000000<_ooool00ol0003oooooooooo`1?ooooo`?o0000AOooool00ol0
003oooooooooo`1>ooooo`7o0000000booooo`;o0000Doooool3o`00043ooooo0_l0001@ooooo`;o
0000000booooo`03o`000?oooooooooo05Gooooo1?l0000fooooo`Ko0000Doooool1o`000000<_oo
ool00ol0003oooooooooo`1Iooooo`?o0000:_ooool9o`0005Wooooo0Ol0000003;ooooo00?o0000
ooooooooool0G?ooool3o`0001kooooo2Ol0001Rooooo`7o0000000booooo`03o`000?oooooooooo
05oooooo0ol0000Booooo`Wo0000Joooool1o`000000<_ooool00ol0003oooooooooo`1Rooooo`?o
00001_ooool9o`0007Cooooo0Ol0000003;ooooo00?o0000ooooooooool0IOooool6o`0007gooooo
0Ol0000003;ooooo00?o0000ooooooooool0j?ooool1o`000000<_ooool2o`000>Sooooo0_l00000
03;ooooo00?o0000ooooooooool0j?ooool1o`000000<_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool1o`000000<_ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0Ol0000003;ooooo
k?l000000?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo
7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo
7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo
7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00?oooooo7oooool00001\
\>"],
  ImageRangeCache->{{{0, 285.375}, {286.938, 0}} -> {-3.79189*^-5, \
-3.39592*^-5, 2.27254*^-7, 2.27254*^-7}}],

Cell[BoxData[
    \(0.00003418282793654637`\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1603, 1106},
WindowMargins->{{42, Automatic}, {Automatic, 14}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3334666517-6198462"->{
    Cell[2917, 93, 1475, 21, 165, "Print",
      CellTags->"Info3334666517-6198462"]},
  "Info3334672378-7410168"->{
    Cell[102638, 2325, 599, 9, 69, "Print",
      CellTags->"Info3334672378-7410168"]},
  "Info3334476571-2350196"->{
    Cell[234422, 5364, 1107, 16, 133, "Print",
      CellTags->"Info3334476571-2350196"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3334666517-6198462", 351354, 8122},
  {"Info3334672378-7410168", 351471, 8125},
  {"Info3334476571-2350196", 351589, 8128}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 42, 0, 28, "Input"],
Cell[1821, 55, 42, 0, 21, "Print"],
Cell[1866, 57, 139, 2, 21, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2042, 64, 54, 0, 52, "Section"],
Cell[2099, 66, 710, 19, 41, "Text"],

Cell[CellGroupData[{
Cell[2834, 89, 80, 2, 28, "Input"],
Cell[2917, 93, 1475, 21, 165, "Print",
  CellTags->"Info3334666517-6198462"]
}, Open  ]],
Cell[4407, 117, 277, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[4709, 128, 68, 1, 28, "Input"],
Cell[4780, 131, 85, 2, 21, "Print"],
Cell[4868, 135, 892, 23, 25, "Output"]
}, Open  ]],
Cell[5775, 161, 297, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[6097, 170, 56, 1, 28, "Input"],
Cell[6156, 173, 93704, 2071, 352, 14165, 1084, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[99875, 2247, 422, 7, 40, "Text"],

Cell[CellGroupData[{
Cell[100322, 2258, 322, 8, 45, "Input"],
Cell[100647, 2268, 630, 15, 41, "Output"]
}, Open  ]],
Cell[101292, 2286, 211, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[101528, 2295, 93, 1, 28, "Input"],
Cell[101624, 2298, 627, 10, 92, "Output"]
}, Open  ]],
Cell[102266, 2311, 262, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[102553, 2321, 82, 2, 28, "Input"],
Cell[102638, 2325, 599, 9, 69, "Print",
  CellTags->"Info3334672378-7410168"]
}, Open  ]],
Cell[103252, 2337, 132, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[103409, 2347, 50, 0, 28, "Input"],
Cell[103462, 2349, 425, 7, 25, "Output"]
}, Open  ]],
Cell[103902, 2359, 154, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[104081, 2366, 136, 4, 28, "Input"],
Cell[104220, 2372, 89076, 1979, 514, 13621, 1043, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[193311, 4354, 221, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[193557, 4363, 45, 0, 28, "Input"],
Cell[193605, 4365, 40504, 982, 294, 6899, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[234112, 5349, 54, 1, 25, "Output"]
}, Open  ]],
Cell[234181, 5353, 181, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[234387, 5362, 32, 0, 28, "Input"],
Cell[234422, 5364, 1107, 16, 133, "Print",
  CellTags->"Info3334476571-2350196"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235566, 5385, 121, 4, 28, "Input"],
Cell[235690, 5391, 816, 15, 41, "Output"]
}, Open  ]],
Cell[236521, 5409, 308, 9, 25, "Text"],

Cell[CellGroupData[{
Cell[236854, 5422, 66, 0, 28, "Input"],
Cell[236923, 5424, 74941, 1805, 459, 13567, 1043, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[311901, 7234, 49, 0, 28, "Input"],
Cell[311953, 7236, 38608, 861, 294, 5546, 449, "GraphicsData", "PostScript", \
"Graphics"],
Cell[350564, 8099, 57, 1, 25, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

